@@ -42,11 +42,9 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aiplayer.h"
-#include "ailog.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daicity.h"
+#include "daiplayer.h"
 
 #include "aiair.h"
 
@@ -162,7 +160,8 @@ static bool dai_should_we_air_attack_tile(struct ai_type *ait,
   Returns an estimate for the profit gained through attack.
   Assumes that the victim is within one day's flight
 **********************************************************************/
-static adv_want dai_evaluate_tile_for_air_attack(struct unit *punit,
+static adv_want dai_evaluate_tile_for_air_attack(const struct civ_map *nmap,
+                                                 struct unit *punit,
                                                  struct tile *dst_tile)
 {
   struct unit *pdefender;
@@ -174,12 +173,11 @@ static adv_want dai_evaluate_tile_for_air_attack(struct unit *punit,
   adv_want profit;
   /* Time spent in the air */
   int sortie_time;
-  struct civ_map *nmap = &(wld.map);
 
 #define PROB_MULTIPLIER 100 /* Should unify with those in combat.c */
 
   if (!can_unit_attack_tile(punit, NULL, dst_tile)
-      || !(pdefender = get_defender(nmap, punit, dst_tile))) {
+      || !(pdefender = get_defender(nmap, punit, dst_tile, NULL))) {
     return 0;
   }
 
@@ -204,7 +202,7 @@ static adv_want dai_evaluate_tile_for_air_attack(struct unit *punit,
   }
 
   unit_attack = (int) (PROB_MULTIPLIER
-                       * unit_win_chance(nmap, punit, pdefender));
+                       * unit_win_chance(nmap, punit, pdefender, NULL));
 
   victim_defense = PROB_MULTIPLIER - unit_attack;
 
@@ -246,15 +244,16 @@ static adv_want dai_evaluate_tile_for_air_attack(struct unit *punit,
   TODO: make separate handicaps for air units seeing targets
         IMO should be more restrictive than general H_MAP, H_FOG
 **********************************************************************/
-static adv_want find_something_to_bomb(struct ai_type *ait, struct unit *punit,
-                                       struct pf_path **path, struct tile **pptile)
+static adv_want find_something_to_bomb(struct ai_type *ait,
+                                       const struct civ_map *nmap,
+                                       struct unit *punit, struct pf_path **path,
+                                       struct tile **pptile)
 {
   struct player *pplayer = unit_owner(punit);
   struct pf_parameter parameter;
   struct pf_map *pfm;
   struct tile *best_tile = NULL;
   adv_want best = 0;
-  const struct civ_map *nmap = &(wld.map);
 
   pft_fill_unit_parameter(&parameter, nmap, punit);
   parameter.omniscience = !has_handicap(pplayer, H_MAP);
@@ -281,7 +280,8 @@ static adv_want find_something_to_bomb(struct ai_type *ait, struct unit *punit,
     if (is_enemy_unit_tile(ptile, pplayer)
         && dai_should_we_air_attack_tile(ait, punit, ptile)
         && can_unit_attack_tile(punit, NULL, ptile)) {
-      adv_want new_best = dai_evaluate_tile_for_air_attack(punit, ptile);
+      adv_want new_best = dai_evaluate_tile_for_air_attack(nmap, punit,
+                                                           ptile);
 
       if (new_best > best) {
         best_tile = ptile;
@@ -444,13 +444,14 @@ static struct tile *dai_find_strategic_airbase(struct ai_type *ait,
         adv_want start_worth;
 
         unit_tile_set(pvirtual, unit_tile(punit));
-        start_worth = find_something_to_bomb(ait, pvirtual, NULL, NULL);
+        start_worth = find_something_to_bomb(ait, nmap, pvirtual,
+                                             NULL, NULL);
         best_worth = MAX(start_worth, 0);
       }
     }
 
     unit_tile_set(pvirtual, ptile);
-    target_worth = find_something_to_bomb(ait, pvirtual, NULL, NULL);
+    target_worth = find_something_to_bomb(ait, nmap, pvirtual, NULL, NULL);
     if (target_worth > best_worth) {
       /* It's either a first find or it's better than the previous. */
       best_worth = target_worth;
@@ -483,7 +484,7 @@ static struct tile *dai_find_strategic_airbase(struct ai_type *ait,
   } else {
     try to attack something
   } 
-  TODO: distant target selection, support for fuel > 2
+  TODO: Distant target selection, support for fuel > 2
 **********************************************************************/
 void dai_manage_airunit(struct ai_type *ait, struct player *pplayer,
                         struct unit *punit)
@@ -495,13 +496,14 @@ void dai_manage_airunit(struct ai_type *ait, struct player *pplayer,
   struct pf_parameter parameter;
   struct pf_map *pfm;
   struct pf_path *path;
+  const struct civ_map *nmap = &(wld.map);
 
   CHECK_UNIT(punit);
 
   if (!is_unit_being_refueled(punit)) {
     /* We are out in the open, what shall we do? */
     if (punit->activity == ACTIVITY_GOTO
-        /* We are on a GOTO.  Check if it will get us anywhere */
+        /* We are on a GOTO. Check if it will get us anywhere */
         && NULL != punit->goto_tile
         && !same_pos(unit_tile(punit), punit->goto_tile)
         && is_refuel_point(punit->goto_tile, pplayer, punit)) {
@@ -537,7 +539,7 @@ void dai_manage_airunit(struct ai_type *ait, struct player *pplayer,
   } else if (punit->fuel == unit_type_get(punit)->fuel) {
     /* We only leave a refuel point when we are on full fuel */
 
-    if (find_something_to_bomb(ait, punit, &path, &dst_tile) > 0) {
+    if (find_something_to_bomb(ait, nmap, punit, &path, &dst_tile) > 0) {
       /* Found target, coordinates are in punit's goto_dest.
        * TODO: separate attacking into a function, check for the best 
        * tile to attack from */
@@ -581,12 +583,12 @@ void dai_manage_airunit(struct ai_type *ait, struct player *pplayer,
   The interface is somewhat different from other ai_choose, but
   that's what it should be like, I believe -- GB
 **********************************************************************/
-bool dai_choose_attacker_air(struct ai_type *ait, struct player *pplayer,
+bool dai_choose_attacker_air(struct ai_type *ait, const struct civ_map *nmap,
+                             struct player *pplayer,
                              struct city *pcity, struct adv_choice *choice,
                              bool allow_gold_upkeep)
 {
   bool want_something = FALSE;
-  const struct civ_map *nmap = &(wld.map);
 
   /* This AI doesn't know how to build planes */
   if (has_handicap(pplayer, H_NOPLANES)) {
@@ -624,7 +626,8 @@ bool dai_choose_attacker_air(struct ai_type *ait, struct player *pplayer,
        unit_virtual_create(
           pplayer, pcity, punittype,
           city_production_unit_veteran_level(pcity, punittype));
-      adv_want profit = find_something_to_bomb(ait, virtual_unit, NULL, NULL);
+      adv_want profit = find_something_to_bomb(ait, nmap, virtual_unit,
+                                               NULL, NULL);
 
       if (profit > choice->want) {
         /* Update choice */
