@@ -30,6 +30,7 @@
 #include "government.h"
 #include "map.h"
 #include "movement.h"
+#include "nation.h"
 #include "packets.h"
 #include "player.h"
 #include "research.h"
@@ -60,16 +61,15 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
 #include "aiguard.h"
 #include "aihand.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daiactions.h"
 #include "daicity.h"
+#include "daidata.h"
+#include "dailog.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 
 #include "aidiplomat.h"
 
@@ -146,12 +146,14 @@ void dai_choose_diplomat_defensive(struct ai_type *ait,
       if (ut) {
         struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
 
-        plr_data->tech_want[advance_index(ut->require_advance)]
-          += DIPLO_DEFENSE_WANT;
-        TECH_LOG(ait, LOG_DEBUG, pplayer, ut->require_advance,
-                 "ai_choose_diplomat_defensive() + %d for %s",
-                 DIPLO_DEFENSE_WANT,
-                 utype_rule_name(ut));
+        unit_tech_reqs_iterate(ut, padv) {
+          plr_data->tech_want[advance_index(padv)]
+            += DIPLO_DEFENSE_WANT;
+          TECH_LOG(ait, LOG_DEBUG, pplayer, padv,
+                   "ai_choose_diplomat_defensive() + %d for %s",
+                   DIPLO_DEFENSE_WANT,
+                   utype_rule_name(ut));
+        } unit_tech_reqs_iterate_end;
       }
     }
   }
@@ -162,6 +164,7 @@ void dai_choose_diplomat_defensive(struct ai_type *ait,
   values in choice.
 ******************************************************************************/
 void dai_choose_diplomat_offensive(struct ai_type *ait,
+                                   const struct civ_map *nmap,
                                    struct player *pplayer,
                                    struct city *pcity,
                                    struct adv_choice *choice)
@@ -169,7 +172,6 @@ void dai_choose_diplomat_offensive(struct ai_type *ait,
   struct unit_type *ut = best_role_unit(pcity, UTYF_DIPLOMAT);
   struct ai_plr *ai = def_ai_player_data(pplayer, ait);
   int expenses;
-  const struct civ_map *nmap = &(wld.map);
 
   dai_calc_data(pplayer, NULL, &expenses, NULL);
 
