@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,8 +22,9 @@ void dai_choose_diplomat_defensive(struct ai_type *ait,
                                    struct city *pcity,
                                    struct adv_choice *choice, int def);
 void dai_choose_diplomat_offensive(struct ai_type *ait,
+                                   const struct civ_map *nmap,
                                    struct player *pplayer,
                                    struct city *pcity,
                                    struct adv_choice *choice);
 
-#endif  /* FC__AIDIPLOMAT_H */
+#endif /* FC__AIDIPLOMAT_H */
