@@ -46,13 +46,11 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
 #include "aiguard.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daicity.h"
+#include "daidata.h"
+#include "daiplayer.h"
 
 #include "aiferry.h"
 
@@ -840,11 +838,13 @@ bool aiferry_gobyboat(struct ai_type *ait, struct player *pplayer,
     }
 
     action_by_result_iterate(paction, ACTRES_TRANSPORT_BOARD) {
-      if (action_prob_possible(action_prob_vs_unit(nmap, punit, paction->id,
+      enum gen_action act_id = action_id(paction);
+
+      if (action_prob_possible(action_prob_vs_unit(nmap, punit, act_id,
                                                    ferryboat))) {
         if (unit_perform_action(pplayer,
                                 punit->id, ferryboat->id, 0, "",
-                                paction->id, ACT_REQ_PLAYER)) {
+                                act_id, ACT_REQ_PLAYER)) {
           board_success = TRUE;
           break;
         }
@@ -904,12 +904,14 @@ bool aiferry_gobyboat(struct ai_type *ait, struct player *pplayer,
 
         /* Bodyguard either uses the same boat or none at all. */
         action_by_result_iterate(paction, ACTRES_TRANSPORT_BOARD) {
+          enum gen_action act_id = action_id(paction);
+
           if (action_prob_possible(action_prob_vs_unit(nmap, bodyguard,
-                                                       paction->id,
+                                                       act_id,
                                                        ferryboat))) {
             if (unit_perform_action(pplayer,
                                     bodyguard->id, ferryboat->id, 0, "",
-                                    paction->id, ACT_REQ_PLAYER)) {
+                                    act_id, ACT_REQ_PLAYER)) {
               break;
             }
           }
