@@ -54,15 +54,14 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitech.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daicity.h"
+#include "daidata.h"
 #include "daidiplomacy.h"
+#include "dailog.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 
 #include "aihand.h"
 
@@ -233,7 +232,7 @@ static void dai_manage_taxes(struct ai_type *ait, struct player *pplayer)
   const struct civ_map *nmap = &(wld.map);
 
 #ifdef DEBUG_TIMERS
-  struct timer *taxtimer= NULL;
+  struct timer *taxtimer = NULL;
 #endif
 
   struct cm_parameter cmp;
@@ -249,9 +248,9 @@ static void dai_manage_taxes(struct ai_type *ait, struct player *pplayer)
   }
 
 #ifdef DEBUG_TIMERS
-  taxtimer = timer_new(TIMER_CPU, TIMER_DEBUG);
+  taxtimer = timer_new(TIMER_CPU, TIMER_DEBUG, "AI tax");
   timer_start(taxtimer);
-#endif
+#endif /* DEBUG_TIMERS */
 
   /* City parameters needed for celebrations. */
   cm_init_parameter(&cmp);
