@@ -36,12 +36,12 @@
 #include "advdata.h"
 
 /* ai/default */
-#include "aidata.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitools.h"
 #include "daicity.h"
+#include "daidata.h"
 #include "daieffects.h"
+#include "dailog.h"
+#include "daiplayer.h"
 
 #include "aitech.h"
 
@@ -78,7 +78,7 @@ static void dai_select_tech(struct ai_type *ait,
   int values[MAX(A_ARRAY_SIZE, A_UNSET + 1)];
   int goal_values[MAX(A_ARRAY_SIZE, A_UNSET + 1)];
   struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
-  size_t acount = advance_count();
+  Tech_type_id ac = advance_count();
 
   memset(values, 0, sizeof(values));
   values[A_UNSET] = -1;
@@ -91,7 +91,7 @@ static void dai_select_tech(struct ai_type *ait,
   if (is_future_tech(presearch->researching)) {
     bool real_found = FALSE;
 
-    advance_index_iterate_max(A_FIRST, i, acount) {
+    advance_index_iterate_max(A_FIRST, i, ac) {
       if (research_invention_state(presearch, i) == TECH_PREREQS_KNOWN) {
         real_found = TRUE;
         break;
@@ -115,38 +115,38 @@ static void dai_select_tech(struct ai_type *ait,
 
   /* Fill in values for the techs: want of the tech
    * + average want of those we will discover en route */
-  advance_index_iterate_max(A_FIRST, i, acount) {
+  advance_index_iterate_max(A_FIRST, i, ac) {
     if (valid_advance_by_number(i)) {
       int steps = research_goal_unknown_techs(presearch, i);
 
       /* We only want it if we haven't got it (so AI is human after all) */
-      if (steps > 0) { 
+      if (steps > 0) {
         values[i] += plr_data->tech_want[i];
-	advance_index_iterate_max(A_FIRST, k, acount) {
+        advance_index_iterate_max(A_FIRST, k, ac) {
           if (research_goal_tech_req(presearch, i, k)) {
             values[k] += plr_data->tech_want[i] / steps;
-	  }
-	} advance_index_iterate_max_end;
+          }
+        } advance_index_iterate_max_end;
       }
     }
   } advance_index_iterate_max_end;
 
   /* Fill in the values for the tech goals */
-  advance_index_iterate_max(A_FIRST, i, acount) {
+  advance_index_iterate_max(A_FIRST, i, ac) {
     if (valid_advance_by_number(i)) {
       int steps = research_goal_unknown_techs(presearch, i);
 
       if (steps == 0) {
         /* Can't be set as a goal any more */
         goal_values[i] = -1;
-	continue;
+        continue;
       }
 
-      goal_values[i] = values[i];      
-      advance_index_iterate_max(A_FIRST, k, acount) {
+      goal_values[i] = values[i];
+      advance_index_iterate_max(A_FIRST, k, ac) {
         if (research_goal_tech_req(presearch, i, k)) {
-	  goal_values[i] += values[k];
-	}
+          goal_values[i] += values[k];
+        }
       } advance_index_iterate_max_end;
 
       /* This is the best I could do. It still sometimes does freaky stuff
@@ -166,7 +166,7 @@ static void dai_select_tech(struct ai_type *ait,
 
   newtech = A_UNSET;
   newgoal = A_UNSET;
-  advance_index_iterate_max(A_FIRST, i, acount) {
+  advance_index_iterate_max(A_FIRST, i, ac) {
     if (valid_advance_by_number(i)) {
       if (values[i] > values[newtech]
           && research_invention_gettable(presearch, i, TRUE)) {
@@ -174,17 +174,17 @@ static void dai_select_tech(struct ai_type *ait,
       }
       if (goal_values[i] > goal_values[newgoal]
           && research_invention_reachable(presearch, i)) {
-	newgoal = i;
+        newgoal = i;
       }
     }
   } advance_index_iterate_max_end;
 
 #ifdef REALLY_DEBUG_THIS
-  advance_index_iterate_max(A_FIRST, id, acount) {
+  advance_index_iterate_max(A_FIRST, id, ac) {
     if (values[id] > 0
         && research_invention_state(presearch, id) == TECH_PREREQS_KNOWN) {
       TECH_LOG(ait, LOG_DEBUG, pplayer, advance_by_number(id),
-              "turn end want: %d", values[id]);
+               "turn end want: %d", values[id]);
     }
   } advance_index_iterate_max_end;
 #endif /* REALLY_DEBUG_THIS */
@@ -266,7 +266,7 @@ static void dai_tech_effect_values(struct ai_type *ait, struct player *pplayer)
     }
   } players_iterate_end;
 
-  advance_iterate(A_FIRST, padv) {
+  advance_iterate(padv) {
     if (research_invention_state(research_get(pplayer), advance_number(padv))
         != TECH_KNOWN) {
       struct universal source = { .kind = VUT_ADVANCE, .value.advance = padv };
@@ -337,7 +337,9 @@ void dai_manage_tech(struct ai_type *ait, struct player *pplayer)
   struct ai_tech_choice choice, goal;
   struct research *research = research_get(pplayer);
   /* Penalty for switching research */
-  int penalty = (research->got_tech ? 0 : research->bulbs_researched);
+  /* FIXME: get real penalty with game.server.techpenalty and multiresearch */
+  int penalty = research->bulbs_researched - research->free_bulbs;
+  penalty = MAX(penalty, 0);
 
   /* Even when we let human to do the final decision, we keep our
    * wants correctly calculated. Add effect values in */
@@ -386,6 +388,7 @@ void dai_manage_tech(struct ai_type *ait, struct player *pplayer)
   cheapest to research.
 **************************************************************************/
 struct unit_type *dai_wants_defender_against(struct ai_type *ait,
+                                             const struct civ_map *nmap,
                                              struct player *pplayer,
                                              struct city *pcity,
                                              const struct unit_type *att, int want)
@@ -401,7 +404,6 @@ struct unit_type *dai_wants_defender_against(struct ai_type *ait,
   int att_idx = utype_index(att);
   int defbonus = 100
     + get_unittype_bonus(pplayer, ptile, att, NULL, EFT_DEFEND_BONUS);
-  const struct civ_map *nmap = &(wld.map);
 
   unit_type_iterate(deftype) {
     int mp_pct = deftype->cache.defense_mp_bonuses_pct[att_idx] + 100;
@@ -431,17 +433,25 @@ struct unit_type *dai_wants_defender_against(struct ai_type *ait,
       /* It would be better than current best. Consider researching tech */
       const struct impr_type *building;
       int cost = 0;
-      struct advance *itech = deftype->require_advance;
+      struct advance *itech = A_NEVER;
       bool impossible_to_get = FALSE;
 
-      if (A_NEVER != itech
-          && research_invention_state(presearch,
-                                      advance_number(itech)) != TECH_KNOWN) {
-        /* See if we want to invent this. */
-        cost = research_goal_bulbs_required(presearch,
-                                            advance_number(itech));
-      }
-      if (((building = utype_needs_improvement(deftype, pcity)))
+      unit_tech_reqs_iterate(deftype, padv) {
+        if (research_invention_state(presearch,
+                                     advance_number(padv)) != TECH_KNOWN) {
+          /* See if we want to invent this. */
+          int ucost = research_goal_bulbs_required(presearch,
+                                                   advance_number(padv));
+
+          if (cost == 0 || ucost < cost) {
+            cost = ucost;
+            itech = padv;
+          }
+        }
+      } unit_tech_reqs_iterate_end;
+
+      building = utype_needs_improvement(deftype, pcity);
+      if (building != NULL
           && !can_player_build_improvement_direct(pplayer, building)) {
         const struct req_context context = {
           .player = pplayer,
@@ -464,9 +474,8 @@ struct unit_type *dai_wants_defender_against(struct ai_type *ait,
                  * or the building's tech is cheaper,
                  * go for the building's required tech. */
                 itech = preq->source.value.advance;
-                cost = 0;
+                cost = imprcost;
               }
-              cost += imprcost;
             } else if (!dai_can_requirement_be_met_in_city(preq, pplayer,
                                                            pcity)) {
               impossible_to_get = TRUE;
@@ -475,7 +484,7 @@ struct unit_type *dai_wants_defender_against(struct ai_type *ait,
         } requirement_vector_iterate_end;
       }
 
-      if (cost < best_cost && !impossible_to_get
+      if (cost < best_cost && !impossible_to_get && itech != A_NEVER
           && research_invention_reachable(presearch, advance_number(itech))) {
         best_tech = itech;
         best_cost = cost;
@@ -505,8 +514,8 @@ struct unit_type *dai_wants_defender_against(struct ai_type *ait,
 }
 
 /**********************************************************************//**
-  Returns the best unit we can build, or NULL if none.  "Best" here
-  means last in the unit list as defined in the ruleset.  Assigns tech
+  Returns the best unit we can build, or NULL if none. "Best" here
+  means last in the unit list as defined in the ruleset. Assigns tech
   wants for techs to get better units with given role, but only for the
   cheapest to research "next" unit up the "chain".
 **************************************************************************/
@@ -524,23 +533,31 @@ struct unit_type *dai_wants_role_unit(struct ai_type *ait, struct player *pplaye
   n = num_role_units(role);
   for (i = n - 1; i >= 0; i--) {
     struct unit_type *iunit = get_role_unit(role, i);
-    struct advance *itech = iunit->require_advance;
 
     if (can_city_build_unit_now(nmap, pcity, iunit)) {
       build_unit = iunit;
       break;
     } else if (can_city_build_unit_later(nmap, pcity, iunit)) {
       const struct impr_type *building;
+      struct advance *itech = A_NEVER;
       int cost = 0;
 
-      if (A_NEVER != itech
-       && research_invention_state(presearch,
-                                   advance_number(itech)) != TECH_KNOWN) {
-        /* See if we want to invent this. */
-        cost = research_goal_bulbs_required(presearch,
-                                            advance_number(itech));
-      }
-      if (((building = utype_needs_improvement(iunit, pcity)))
+      unit_tech_reqs_iterate(iunit, padv) {
+        if (research_invention_state(presearch,
+                                     advance_number(padv)) != TECH_KNOWN) {
+          /* See if we want to invent this. */
+          int ucost = research_goal_bulbs_required(presearch,
+                                                   advance_number(padv));
+
+          if (cost == 0 || ucost < cost) {
+            cost = ucost;
+            itech = padv;
+          }
+        }
+      } unit_tech_reqs_iterate_end;
+
+      building = utype_needs_improvement(iunit, pcity);
+      if (building != NULL
           && !can_player_build_improvement_direct(pplayer, building)) {
         requirement_vector_iterate(&building->reqs, preq) {
           if (VUT_ADVANCE == preq->source.kind && preq->present) {
@@ -556,15 +573,14 @@ struct unit_type *dai_wants_role_unit(struct ai_type *ait, struct player *pplaye
                  * or the building's tech is cheaper,
                  * go for the building's required tech. */
                 itech = preq->source.value.advance;
-                cost = 0;
+                cost = imprcost;
               }
-              cost += imprcost;
             }
           }
         } requirement_vector_iterate_end;
       }
 
-      if (cost < best_cost
+      if (cost < best_cost && itech != A_NEVER
           && research_invention_reachable(presearch, advance_number(itech))) {
         best_tech = itech;
         best_cost = cost;
