@@ -28,6 +28,7 @@
 #include "government.h"
 #include "map.h"
 #include "movement.h"
+#include "nation.h"
 #include "packets.h"
 #include "player.h"
 #include "unit.h"
@@ -59,14 +60,13 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
 #include "aiferry.h"
 #include "aiguard.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitech.h"
-#include "aiunit.h"
+#include "daidata.h"
+#include "dailog.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 
 #include "aitools.h"
 
@@ -548,7 +548,7 @@ void dai_fill_unit_param(struct ai_type *ait, struct pf_parameter *parameter,
   if (unit_has_type_flag(punit, UTYF_SETTLERS)) {
     parameter->get_TB = no_fights;
   } else if (long_path && unit_is_cityfounder(punit)) {
-    /* Default tile behaviour;
+    /* Default tile behavior;
      * move as far along the path to the destination as we can;
      * that is, ignore the presence of enemy units when computing the
      * path.
@@ -564,7 +564,7 @@ void dai_fill_unit_param(struct ai_type *ait, struct pf_parameter *parameter,
     parameter->get_TB = no_fights;
   } else if (is_losing_hp(punit)) {
     /* Losing hitpoints over time (helicopter in default rules) */
-    /* Default tile behaviour */
+    /* Default tile behavior */
   } else if (utype_may_act_at_all(unit_type_get(punit))) {
     switch (unit_data->task) {
     case AIUNIT_AUTO_SETTLER:
@@ -585,7 +585,7 @@ void dai_fill_unit_param(struct ai_type *ait, struct pf_parameter *parameter,
       parameter->get_TB = no_fights;
       break;
     case AIUNIT_NONE:
-      /* Default tile behaviour */
+      /* Default tile behavior */
       break;
     }
   } else {
@@ -832,27 +832,32 @@ bool dai_unit_attack(struct ai_type *ait, struct unit *punit, struct tile *ptile
   /* FIXME: try the next action if the unit tried to do an illegal action.
    * That would allow the AI to stop using the omniscient
    * is_action_enabled_unit_on_*() functions. */
-  if (is_action_enabled_unit_on_units(nmap, ACTION_CAPTURE_UNITS,
+  if (is_action_enabled_unit_on_stack(nmap, ACTION_CAPTURE_UNITS,
                                       punit, ptile)) {
     /* Choose capture. */
     unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
                    0, "", ACTION_CAPTURE_UNITS);
-  } else if (is_action_enabled_unit_on_units(nmap, ACTION_BOMBARD,
+  } else if (is_action_enabled_unit_on_stack(nmap, ACTION_BOMBARD_LETHAL,
+                                             punit, ptile)) {
+    /* Choose "Bombard Lethal". */
+    unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
+                   0, "", ACTION_BOMBARD_LETHAL);
+  } else if (is_action_enabled_unit_on_stack(nmap, ACTION_BOMBARD,
                                              punit, ptile)) {
     /* Choose "Bombard". */
     unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
                    0, "", ACTION_BOMBARD);
-  } else if (is_action_enabled_unit_on_units(nmap, ACTION_BOMBARD2,
+  } else if (is_action_enabled_unit_on_stack(nmap, ACTION_BOMBARD2,
                                              punit, ptile)) {
     /* Choose "Bombard 2". */
     unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
                    0, "", ACTION_BOMBARD2);
-  } else if (is_action_enabled_unit_on_units(nmap, ACTION_BOMBARD3,
+  } else if (is_action_enabled_unit_on_stack(nmap, ACTION_BOMBARD3,
                                              punit, ptile)) {
     /* Choose "Bombard 3". */
     unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
                    0, "", ACTION_BOMBARD3);
-  } else if (is_action_enabled_unit_on_units(nmap, ACTION_NUKE_UNITS,
+  } else if (is_action_enabled_unit_on_stack(nmap, ACTION_NUKE_UNITS,
                                              punit, ptile)) {
     /* Choose "Nuke Units". */
     unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
@@ -883,12 +888,12 @@ bool dai_unit_attack(struct ai_type *ait, struct unit *punit, struct tile *ptile
     /* Choose "Nuke City". */
     unit_do_action(unit_owner(punit), punit->id, tcity->id,
                    0, "", ACTION_NUKE_CITY);
-  } else if (is_action_enabled_unit_on_units(nmap, ACTION_ATTACK,
+  } else if (is_action_enabled_unit_on_stack(nmap, ACTION_ATTACK,
                                              punit, ptile)) {
     /* Choose regular attack. */
     unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
                    0, "", ACTION_ATTACK);
-  } else if (is_action_enabled_unit_on_units(nmap, ACTION_SUICIDE_ATTACK,
+  } else if (is_action_enabled_unit_on_stack(nmap, ACTION_SUICIDE_ATTACK,
                                              punit, ptile)) {
     /* Choose suicide attack (explode missile). */
     unit_do_action(unit_owner(punit), punit->id, tile_index(ptile),
@@ -938,6 +943,13 @@ bool dai_unit_attack(struct ai_type *ait, struct unit *punit, struct tile *ptile
     /* "Transport Embark 3". */
     unit_do_action(unit_owner(punit), punit->id, ptrans->id,
                    0, "", ACTION_TRANSPORT_EMBARK3);
+  } else if (!can_unit_survive_at_tile(nmap, punit, ptile)
+             && ((ptrans = transporter_for_unit_at(punit, ptile)))
+             && is_action_enabled_unit_on_unit(nmap, ACTION_TRANSPORT_EMBARK4,
+                                               punit, ptrans)) {
+    /* "Transport Embark 4". */
+    unit_do_action(unit_owner(punit), punit->id, ptrans->id,
+                   0, "", ACTION_TRANSPORT_EMBARK4);
   } else if (is_action_enabled_unit_on_tile(nmap, ACTION_TRANSPORT_DISEMBARK1,
                                             punit, ptile, NULL)) {
     /* "Transport Disembark". */
@@ -1130,6 +1142,12 @@ bool dai_unit_move(struct ai_type *ait, struct unit *punit, struct tile *ptile)
                                                punit, ptrans)) {
     /* "Transport Embark 3". */
     paction = action_by_number(ACTION_TRANSPORT_EMBARK3);
+  } else if (!can_unit_survive_at_tile(nmap, punit, ptile)
+             && ptrans != NULL
+             && is_action_enabled_unit_on_unit(nmap, ACTION_TRANSPORT_EMBARK4,
+                                               punit, ptrans)) {
+    /* "Transport Embark 4". */
+    paction = action_by_number(ACTION_TRANSPORT_EMBARK4);
   } else if (is_action_enabled_unit_on_tile(nmap, ACTION_TRANSPORT_DISEMBARK1,
                                             punit, ptile, NULL)) {
     /* "Transport Disembark". */
