@@ -56,13 +56,12 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
-#include "ailog.h"
-#include "aiplayer.h"
-#include "aiunit.h"
 #include "aitools.h"
 #include "daicity.h"
+#include "daidata.h"
+#include "dailog.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 
 #include "daidiplomacy.h"
 
@@ -304,12 +303,13 @@ static int dai_goldequiv_clause(struct ai_type *ait,
 {
   bool close_here;
   struct ai_plr *ai;
-  int worth = 0; /* worth for pplayer of what aplayer gives */
+  int worth = 0; /* Worth for pplayer of what aplayer gives */
   bool give = (pplayer == pclause->from);
   struct player *giver;
   const struct player *penemy;
   struct ai_dip_intel *adip = dai_diplomacy_get(ait, pplayer, aplayer);
   bool is_dangerous;
+  const struct civ_map *nmap = &(wld.map);
 
   ai = dai_plr_data_get(ait, pplayer, &close_here);
 
@@ -531,7 +531,7 @@ static int dai_goldequiv_clause(struct ai_type *ait,
       DIPLO_LOG(ait, LOG_DEBUG, pplayer, aplayer, "city destroyed during negotiations");
     } else if (give) {
       /* AI must be crazy to trade away its cities */
-      worth -= city_gold_worth(offer);
+      worth -= city_gold_worth(nmap, offer);
       if (is_capital(offer)) {
         worth = -BIG_NUMBER; /* Never! Ever! */
       } else {
@@ -542,7 +542,7 @@ static int dai_goldequiv_clause(struct ai_type *ait,
         worth /= 2;
       }
     } else {
-      worth = city_gold_worth(offer);
+      worth = city_gold_worth(nmap, offer);
     }
     if (offer != NULL) {
       DIPLO_LOG(ait, LOG_DEBUG, pplayer, aplayer, "worth of %s is %d", 
@@ -591,6 +591,20 @@ static int dai_goldequiv_clause(struct ai_type *ait,
     DIPLO_LOG(ait, LOG_DIPL, pplayer, aplayer, "embassy clause worth %d",
               worth);
     break;
+  case CLAUSE_SHARED_TILES:
+    if (give) {
+      if (ds_after == DS_ALLIANCE) {
+        worth = 0;
+      } else {
+        /* Here we assume that number of cities correlate with number of tiles. */
+        worth = -3 * (city_list_size(pplayer->cities) + 1);
+      }
+    } else {
+      int cities = city_list_size(aplayer->cities);
+
+      worth = MIN(cities, 3);
+    }
+    break;
   case CLAUSE_COUNT:
     fc_assert(pclause->type != CLAUSE_COUNT);
     break;
@@ -1161,11 +1175,11 @@ static void suggest_tech_exchange(struct ai_type *ait,
       if (research_invention_state(presearch2, tech) != TECH_KNOWN
           && research_invention_gettable(presearch2, tech, game.info.tech_trade_allow_holes)) {
         worth[tech] = -compute_tech_sell_price(ait, player1, player2, tech,
-	                                       &is_dangerous);
-	if (is_dangerous) {
-	  /* Don't try to exchange */
-	  worth[tech] = 0;
-	}
+                                               &is_dangerous);
+        if (is_dangerous) {
+          /* Don't try to exchange */
+          worth[tech] = 0;
+        }
       } else {
         worth[tech] = 0;
       }
@@ -1174,11 +1188,11 @@ static void suggest_tech_exchange(struct ai_type *ait,
           && research_invention_gettable(presearch1, tech,
                                          game.info.tech_trade_allow_holes)) {
         worth[tech] = compute_tech_sell_price(ait, player2, player1, tech,
-	                                      &is_dangerous);
-	if (is_dangerous) {
-	  /* Don't try to exchange */
-	  worth[tech] = 0;
-	}
+                                              &is_dangerous);
+        if (is_dangerous) {
+          /* Don't try to exchange */
+          worth[tech] = 0;
+        }
       } else {
         worth[tech] = 0;
       }
@@ -1195,7 +1209,7 @@ static void suggest_tech_exchange(struct ai_type *ait,
       if (worth[tech2] >= 0) {
         continue;
       }
-      /* tech2 is given by player1, tech is given by player2 */
+      /* Tech2 is given by player1, tech is given by player2 */
       diff = worth[tech] + worth[tech2];
       if ((diff > 0 && player1->economic.gold >= diff)
           || (diff < 0 && player2->economic.gold >= -diff)
@@ -1290,6 +1304,41 @@ static void dai_share(struct ai_type *ait, struct player *pplayer,
   }
 }
 
+/******************************************************************//**
+  AI to declare war.
+
+  @param ait     AI type of the player declaring war
+  @param pplayer Player declaring war
+  @param target  Player to declare war to
+**********************************************************************/
+static void dai_declare_war(struct ai_type *ait, struct player *pplayer,
+                            struct player *target)
+{
+  struct ai_dip_intel *adip = dai_diplomacy_get(ait, pplayer, target);
+
+  /* This will take us straight to war. */
+  while (player_diplstate_get(pplayer, target)->type != DS_WAR) {
+    if (pplayer_can_cancel_treaty(pplayer, target) != DIPL_OK) {
+      DIPLO_LOG(ait, LOG_ERROR, pplayer, target,
+                "Wanted to cancel treaty but was unable to.");
+      adip->countdown = -1; /* War declaration aborted */
+
+      return;
+    }
+    handle_diplomacy_cancel_pact(pplayer, player_number(target), clause_type_invalid());
+  }
+
+  /* Throw a tantrum */
+  if (pplayer->ai_common.love[player_index(target)] > 0) {
+    pplayer->ai_common.love[player_index(target)] = -1;
+  }
+  pplayer->ai_common.love[player_index(target)] -= MAX_AI_LOVE / 8;
+
+  fc_assert(!gives_shared_vision(pplayer, target));
+
+  DIPLO_LOG(ait, LOG_DIPL, pplayer, target, "war declared");
+}
+
 /******************************************************************//**
   Go to war. Explain to target why we did it, and set countdown to
   some negative value to make us a bit stubborn to avoid immediate
@@ -1309,7 +1358,7 @@ static void dai_go_to_war(struct ai_type *ait, struct player *pplayer,
                      player_name(pplayer));
     adip->countdown = -10;
     break;
-  case DAI_WR_BEHAVIOUR:
+  case DAI_WR_BEHAVIOR:
     dai_diplo_notify(target,
                      _("*%s (AI)* I have tolerated your vicious antics "
                        "long enough! To war!"),
@@ -1371,6 +1420,8 @@ static void dai_go_to_war(struct ai_type *ait, struct player *pplayer,
       pplayer->government = real_gov;
       handle_player_change_government(pplayer,
                                       game.info.government_during_revolution_id);
+      def_ai_player_data(pplayer, ait)->diplomacy.war_target = target;
+      return;
     } else {
       /* There would be Senate even during revolution. Better not to revolt for nothing */
       pplayer->government = real_gov;
@@ -1383,26 +1434,28 @@ static void dai_go_to_war(struct ai_type *ait, struct player *pplayer,
     }
   }
 
-  /* This will take us straight to war. */
-  while (player_diplstate_get(pplayer, target)->type != DS_WAR) {
-    if (pplayer_can_cancel_treaty(pplayer, target) != DIPL_OK) {
-      DIPLO_LOG(ait, LOG_ERROR, pplayer, target,
-                "Wanted to cancel treaty but was unable to.");
-      adip->countdown = -1; /* War declaration aborted */
+  dai_declare_war(ait, pplayer, target);
+}
 
-      return;
+/******************************************************************//**
+  Revolution start callback for default AI.
+
+  @param ait     AI type of the player revolting
+  @param pplayer Player revolting
+**********************************************************************/
+void dai_revolution_start(struct ai_type *ait, struct player *pplayer)
+{
+  struct ai_plr *data = def_ai_player_data(pplayer, ait);
+
+  if (data->diplomacy.war_target != NULL) {
+    if (gives_shared_vision(pplayer, data->diplomacy.war_target)) {
+      remove_shared_vision(pplayer, data->diplomacy.war_target);
     }
-    handle_diplomacy_cancel_pact(pplayer, player_number(target), clause_type_invalid());
-  }
 
-  /* Throw a tantrum */
-  if (pplayer->ai_common.love[player_index(target)] > 0) {
-    pplayer->ai_common.love[player_index(target)] = -1;
-  }
-  pplayer->ai_common.love[player_index(target)] -= MAX_AI_LOVE / 8;
+    dai_declare_war(ait, pplayer, data->diplomacy.war_target);
 
-  fc_assert(!gives_shared_vision(pplayer, target));
-  DIPLO_LOG(ait, LOG_DIPL, pplayer, target, "war declared");
+    data->diplomacy.war_target = NULL;
+  }
 }
 
 /******************************************************************//**
@@ -1456,7 +1509,7 @@ static void war_countdown(struct ai_type *ait, struct player *pplayer,
                          "Long live our glorious alliance!"),
                        player_name(pplayer));
       break;
-    case DAI_WR_BEHAVIOUR:
+    case DAI_WR_BEHAVIOR:
     case DAI_WR_EXCUSE:
       dai_diplo_notify(ally,
                        PL_("*%s (AI)* %s has grossly violated their treaties "
@@ -1571,7 +1624,7 @@ void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer)
         && dai_diplomacy_get(ait, pplayer, aplayer)->countdown == -1) {
       DIPLO_LOG(ait, LOG_DIPL2, pplayer, aplayer, "Plans war in revenge");
       war_countdown(ait, pplayer, aplayer, map_size_checked(),
-                    DAI_WR_BEHAVIOUR);
+                    DAI_WR_BEHAVIOR);
     }
   } players_iterate_end;
 
@@ -1986,7 +2039,9 @@ void dai_incident(struct ai_type *ait, enum incident_type type,
     case ACTRES_CAPTURE_UNITS:
     case ACTRES_BOMBARD:
     case ACTRES_ATTACK:
+    case ACTRES_WIPE_UNITS:
     case ACTRES_SPY_ATTACK:
+    case ACTRES_COLLECT_RANSOM:
       /* Unit loss */
       dai_incident_simple(receiver, violator, victim, scope, 5);
       break;
@@ -2019,6 +2074,9 @@ void dai_incident(struct ai_type *ait, enum incident_type type,
       dai_incident_simple(receiver, violator, victim, scope, 2);
       break;
     case ACTRES_UNIT_MOVE:
+    case ACTRES_TELEPORT:
+    case ACTRES_TELEPORT_CONQUER:
+    case ACTRES_SPY_ESCAPE:
     case ACTRES_TRADE_ROUTE:
     case ACTRES_MARKETPLACE:
     case ACTRES_HELP_WONDER:
@@ -2029,31 +2087,34 @@ void dai_incident(struct ai_type *ait, enum incident_type type,
     case ACTRES_HOMELESS:
     case ACTRES_UPGRADE_UNIT:
     case ACTRES_PARADROP:
-    case ACTRES_PARADROP_CONQUER: /* TODO: bigger incident */
+    case ACTRES_PARADROP_CONQUER: /* TODO: Bigger incident */
     case ACTRES_AIRLIFT:
     case ACTRES_HEAL_UNIT:
     case ACTRES_TRANSFORM_TERRAIN:
     case ACTRES_CULTIVATE:
     case ACTRES_PLANT:
-    case ACTRES_CLEAN_POLLUTION:
-    case ACTRES_CLEAN_FALLOUT:
+    case ACTRES_CLEAN:
     case ACTRES_FORTIFY:
     case ACTRES_ROAD:
     case ACTRES_CONVERT:
     case ACTRES_BASE:
     case ACTRES_MINE:
     case ACTRES_IRRIGATE:
-    case ACTRES_TRANSPORT_ALIGHT:
+    case ACTRES_TRANSPORT_DEBOARD:
     case ACTRES_TRANSPORT_UNLOAD:
     case ACTRES_TRANSPORT_DISEMBARK:
     case ACTRES_TRANSPORT_BOARD:
+    case ACTRES_TRANSPORT_LOAD:
     case ACTRES_TRANSPORT_EMBARK:
     case ACTRES_HUT_ENTER:
     case ACTRES_HUT_FRIGHTEN:
+    case ACTRES_ENABLER_CHECK:
     case ACTRES_NONE:
       /* Various */
       dai_incident_simple(receiver, violator, victim, scope, 1);
       break;
+
+    ASSERT_UNUSED_ACTRES_CASES;
     }
     break;
   case INCIDENT_WAR:
