@@ -53,14 +53,12 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitech.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daicity.h"
+#include "daidata.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 
 #include "daidomestic.h"
 
@@ -373,6 +371,7 @@ static void dai_choose_trade_route(struct ai_type *ait, struct city *pcity,
                                      .player = pplayer,
                                      .city = pcity,
                                      .tile = city_tile(pcity),
+                                     .unittype = unit_type,
                                      .action =
                                        action_by_number(trade_action),
                                    },
