@@ -37,7 +37,7 @@
 #include "infracache.h"
 
 /* ai/default */
-#include "aidata.h"
+#include "daidata.h"
 
 /* ai/tex */
 #include "texaimsg.h"
@@ -160,6 +160,7 @@ static void texai_tile_worker_task_select(struct player *pplayer,
 {
   int orig_value;
   bool potential_worst_worked = FALSE;
+  const struct civ_map *nmap = &(wld.map);
 
   if (!city_can_work_tile(pcity, ptile)) {
     return;
@@ -206,7 +207,7 @@ static void texai_tile_worker_task_select(struct player *pplayer,
       }
 
       if (action_prob_possible(
-            action_speculate_unit_on_tile(act,
+            action_speculate_unit_on_tile(nmap, act,
                                           punit, unit_home(punit), ptile,
                                           TRUE,
                                           ptile, tgt))) {
@@ -228,7 +229,7 @@ static void texai_tile_worker_task_select(struct player *pplayer,
           if (limit == TWTL_BUILDABLE_UNITS) {
             unit_list_iterate(units, punit) {
               if (action_prob_possible(
-                    action_speculate_unit_on_tile(act,
+                    action_speculate_unit_on_tile(nmap, act,
                                                   punit, unit_home(punit),
                                                   ptile,
                                                   TRUE,
@@ -255,7 +256,7 @@ static void texai_tile_worker_task_select(struct player *pplayer,
           if (limit == TWTL_BUILDABLE_UNITS) {
             unit_list_iterate(units, punit) {
               if (action_prob_possible(
-                    action_speculate_unit_on_tile(act,
+                    action_speculate_unit_on_tile(nmap, act,
                                                   punit, unit_home(punit),
                                                   ptile,
                                                   TRUE,
@@ -279,7 +280,7 @@ static void texai_tile_worker_task_select(struct player *pplayer,
           struct action *taction = action_by_number(try_act);
           if (is_extra_removed_by_action(tgt, taction)
               && action_prob_possible(
-                action_speculate_unit_on_tile(try_act,
+                action_speculate_unit_on_tile(nmap, try_act,
                                               punit,
                                               unit_home(punit), ptile,
                                               TRUE,
@@ -293,7 +294,7 @@ static void texai_tile_worker_task_select(struct player *pplayer,
           struct action *taction = action_by_number(try_act);
           if (is_extra_caused_by_action(tgt, taction)
               && action_prob_possible(
-                action_speculate_unit_on_tile(try_act,
+                action_speculate_unit_on_tile(nmap, try_act,
                                               punit,
                                               unit_home(punit), ptile,
                                               TRUE,
@@ -316,7 +317,7 @@ static void texai_tile_worker_task_select(struct player *pplayer,
       unit_list_iterate(ptile->units, punit) {
         if (unit_owner(punit) == pplayer
             && unit_has_type_flag(punit, UTYF_SETTLERS)
-            && punit->activity == actres_get_activity(paction->result)) {
+            && punit->activity == action_get_activity(paction)) {
           consider = FALSE;
           break;
         }
@@ -383,14 +384,14 @@ static void texai_tile_worker_task_select(struct player *pplayer,
         if ((value - orig_value) * TWMP > worked->want) {
           worked->want       = TWMP * (value - orig_value);
           worked->ptile      = ptile;
-          worked->act        = actres_get_activity(paction->result);
+          worked->act        = action_get_activity(paction);
           worked->tgt        = tgt;
           if (limit == TWTL_BUILDABLE_UNITS) {
             unit_list_iterate(units, punit) {
               fc_assert_action(action_get_target_kind(paction) == ATK_TILE,
                                break);
               if (action_prob_possible(action_speculate_unit_on_tile(
-                                           paction->id,
+                                           nmap, paction->id,
                                            punit, unit_home(punit), ptile,
                                            TRUE,
                                            ptile, tgt))) {
@@ -411,14 +412,14 @@ static void texai_tile_worker_task_select(struct player *pplayer,
           state->uw_max_base   = base_value;
           unworked->want       = TWMP * (value - orig_value);
           unworked->ptile      = ptile;
-          unworked->act        = actres_get_activity(paction->result);
+          unworked->act        = action_get_activity(paction);
           unworked->tgt        = tgt;
           if (limit == TWTL_BUILDABLE_UNITS) {
             unit_list_iterate(units, punit) {
               fc_assert_action(action_get_target_kind(paction) == ATK_TILE,
                                break);
               if (action_prob_possible(action_speculate_unit_on_tile(
-                                         paction->id,
+                                         nmap, paction->id,
                                          punit, unit_home(punit), ptile,
                                          TRUE,
                                          ptile, tgt))) {
