@@ -30,8 +30,8 @@
 #include "infracache.h"
 
 /* ai/default */
-#include "aiplayer.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 
 /* ai/tex */
 #include "texaicity.h"
@@ -93,7 +93,7 @@ static void texai_thread_start(void *arg)
   }
 
   /* Just wait until we are signaled to shutdown */
-  fc_allocate_mutex(&exthrai.msgs_to.mutex);
+  fc_mutex_allocate(&exthrai.msgs_to.mutex);
   while (!finished) {
     fc_thread_cond_wait(&exthrai.msgs_to.thr_cond, &exthrai.msgs_to.mutex);
 
@@ -101,7 +101,7 @@ static void texai_thread_start(void *arg)
       finished = TRUE;
     }
   }
-  fc_release_mutex(&exthrai.msgs_to.mutex);
+  fc_mutex_release(&exthrai.msgs_to.mutex);
 
   texai_world_close();
 
@@ -165,7 +165,7 @@ struct unit_list *texai_player_units(struct player *pplayer)
 **************************************************************************/
 static enum texai_abort_msg_class texai_check_messages(struct ai_type *ait)
 {
-  enum texai_abort_msg_class ret_abort= TEXAI_ABORT_NONE;
+  enum texai_abort_msg_class ret_abort = TEXAI_ABORT_NONE;
 
   texaimsg_list_allocate_mutex(exthrai.msgs_to.msglist);
   while (texaimsg_list_size(exthrai.msgs_to.msglist) > 0) {
@@ -180,7 +180,7 @@ static enum texai_abort_msg_class texai_check_messages(struct ai_type *ait)
 
     switch (msg->type) {
     case TEXAI_MSG_FIRST_ACTIVITIES:
-      fc_allocate_mutex(&game.server.mutexes.city_list);
+      fc_mutex_allocate(&game.server.mutexes.city_list);
 
       initialize_infrastructure_cache(msg->plr);
 
@@ -207,16 +207,16 @@ static enum texai_abort_msg_class texai_check_messages(struct ai_type *ait)
 
         /* Release mutex for a second in case main thread
          * wants to do something to city list. */
-        fc_release_mutex(&game.server.mutexes.city_list);
+        fc_mutex_release(&game.server.mutexes.city_list);
 
         /* Recursive message check in case phase is finished. */
         new_abort = texai_check_messages(ait);
-        fc_allocate_mutex(&game.server.mutexes.city_list);
+        fc_mutex_allocate(&game.server.mutexes.city_list);
         if (new_abort < TEXAI_ABORT_NONE) {
           break;
         }
       } city_list_iterate_safe_end;
-      fc_release_mutex(&game.server.mutexes.city_list);
+      fc_mutex_release(&game.server.mutexes.city_list);
 
       texai_send_req(TEXAI_REQ_TURN_DONE, msg->plr, NULL);
 
@@ -323,7 +323,7 @@ void texai_control_gained(struct ai_type *ait, struct player *pplayer)
     exthrai.thread_running = TRUE;
  
     fc_thread_cond_init(&exthrai.msgs_to.thr_cond);
-    fc_init_mutex(&exthrai.msgs_to.mutex);
+    fc_mutex_init(&exthrai.msgs_to.mutex);
     fc_thread_start(&exthrai.ait, texai_thread_start, ait);
 
     players_iterate(oplayer) {
@@ -354,7 +354,7 @@ void texai_control_lost(struct ai_type *ait, struct player *pplayer)
     exthrai.thread_running = FALSE;
 
     fc_thread_cond_destroy(&exthrai.msgs_to.thr_cond);
-    fc_destroy_mutex(&exthrai.msgs_to.mutex);
+    fc_mutex_destroy(&exthrai.msgs_to.mutex);
     texaimsg_list_destroy(exthrai.msgs_to.msglist);
     texaireq_list_destroy(exthrai.reqs_from.reqlist);
   }
@@ -413,10 +413,10 @@ void texai_refresh(struct ai_type *ait, struct player *pplayer)
 **************************************************************************/
 void texai_msg_to_thr(struct texai_msg *msg)
 {
-  fc_allocate_mutex(&exthrai.msgs_to.mutex);
+  fc_mutex_allocate(&exthrai.msgs_to.mutex);
   texaimsg_list_append(exthrai.msgs_to.msglist, msg);
   fc_thread_cond_signal(&exthrai.msgs_to.thr_cond);
-  fc_release_mutex(&exthrai.msgs_to.mutex);
+  fc_mutex_release(&exthrai.msgs_to.mutex);
 }
 
 /**********************************************************************//**
