@@ -34,8 +34,9 @@
 #include "audio_none.h"
 #ifdef AUDIO_SDL
 #include "audio_sdl.h"
-#endif
+#endif /* AUDIO_SDL */
 #include "client_main.h"
+#include "music.h"
 #include "options.h"
 
 #include "audio.h"
@@ -44,8 +45,8 @@
 #define SNDSPEC_SUFFIX		".soundspec"
 #define MUSICSPEC_SUFFIX        ".musicspec"
 
-#define SOUNDSPEC_CAPSTR "+Freeciv-3.1-soundset"
-#define MUSICSPEC_CAPSTR "+Freeciv-2.6-musicset"
+#define SOUNDSPEC_CAPSTR "+Freeciv-3.2-soundset"
+#define MUSICSPEC_CAPSTR "+Freeciv-3.2-musicspec"
 
 /* Keep them open throughout */
 static struct section_file *ss_tagfile = NULL;
@@ -283,7 +284,9 @@ void audio_real_init(const char *const soundset_name,
     /* We explicitly choose none plugin, silently skip the code below */
     log_verbose("Proceeding with sound support disabled.");
     ss_tagfile = NULL;
+    musicspec_close(ms_tagfile);
     ms_tagfile = NULL;
+
     return;
   }
   if (num_plugins_used == 1) {
@@ -293,7 +296,9 @@ void audio_real_init(const char *const soundset_name,
     log_normal(_("For sound support, install SDL2_mixer"));
     log_normal("https://github.com/libsdl-org/SDL_mixer");
     ss_tagfile = NULL;
+    musicspec_close(ms_tagfile);
     ms_tagfile = NULL;
+
     return;
   }
   if (!soundset_name) {
@@ -316,7 +321,9 @@ void audio_real_init(const char *const soundset_name,
                "https://www.freeciv.org/wiki/Sounds");
     log_normal(_("Proceeding with sound support disabled."));
     ss_tagfile = NULL;
+    musicspec_close(ms_tagfile);
     ms_tagfile = NULL;
+
     return;
   }
   if (!(ss_tagfile = secfile_load(ss_filename, TRUE))) {
@@ -324,7 +331,7 @@ void audio_real_init(const char *const soundset_name,
               secfile_error());
     exit(EXIT_FAILURE);
   }
-  if (!(ms_tagfile = secfile_load(ms_filename, TRUE))) {
+  if (!(ms_tagfile = musicspec_load(ms_filename))) {
     log_fatal(_("Could not load music spec-file '%s':\n%s"), ms_filename,
               secfile_error());
     exit(EXIT_FAILURE);
@@ -518,19 +525,24 @@ static int audio_play_music_tag(const char *tag, bool repeat,
 /**********************************************************************//**
   Play an audio sample as suggested by sound tags
 **************************************************************************/
-void audio_play_sound(const char *const tag, const char *const alt_tag)
+void audio_play_sound(const char *const tag, const char *const alt_tag,
+                      const char *const alt_tag2)
 {
   const char *pretty_alt_tag = alt_tag ? alt_tag : "(null)";
+  const char *pretty_alt2_tag = alt_tag2 ? alt_tag2 : "(null)";
 
   if (gui_options.sound_enable_effects) {
     fc_assert_ret(tag != NULL);
 
-    log_debug("audio_play_sound('%s', '%s')", tag, pretty_alt_tag);
+    log_debug("audio_play_sound('%s', '%s', '%s')",
+              tag, pretty_alt_tag, pretty_alt2_tag);
 
-    /* try playing primary tag first, if not go to alternative tag */
+    /* Try playing primary tag first, if not go to alternative tags */
     if (!audio_play_sound_tag(tag, FALSE)
-        && !audio_play_sound_tag(alt_tag, FALSE)) {
-      log_verbose( "Neither of tags %s or %s found", tag, pretty_alt_tag);
+        && !audio_play_sound_tag(alt_tag, FALSE)
+        && !audio_play_sound_tag(alt_tag2, FALSE)) {
+      log_verbose( "None of tags %s, %s, or %s found",
+                   tag, pretty_alt_tag, pretty_alt2_tag);
     }
   }
 }
@@ -588,6 +600,22 @@ void audio_play_track(const char *const tag, char *const alt_tag)
   real_audio_play_music(tag, alt_tag, TRUE);
 }
 
+/**********************************************************************//**
+  Pause sound.
+**************************************************************************/
+void audio_pause(void)
+{
+  plugins[selected_plugin].pause();
+}
+
+/**********************************************************************//**
+  Resume sound.
+**************************************************************************/
+void audio_resume(void)
+{
+  plugins[selected_plugin].resume();
+}
+
 /**********************************************************************//**
   Stop sound. Music should die down in a few seconds.
 **************************************************************************/
@@ -632,7 +660,7 @@ void audio_shutdown(bool play_quit_tag)
   audio_stop();
 
   if (play_quit_tag) {
-    audio_play_sound("e_game_quit", NULL);
+    audio_play_sound("e_client_quit", NULL, NULL);
   }
 
   if (plugins[selected_plugin].initialized) {
@@ -645,7 +673,7 @@ void audio_shutdown(bool play_quit_tag)
     ss_tagfile = NULL;
   }
   if (NULL != ms_tagfile) {
-    secfile_destroy(ms_tagfile);
+    musicspec_close(ms_tagfile);
     ms_tagfile = NULL;
   }
 }
