@@ -25,6 +25,7 @@ extern "C" {
 enum cursor_hover_state {
   HOVER_NONE = 0,
   HOVER_GOTO,
+  HOVER_TELEPORT,
   HOVER_PARADROP,
   HOVER_CONNECT,
   HOVER_PATROL,
@@ -140,6 +141,15 @@ void request_unit_wakeup(struct unit *punit);
 #define SPECENUM_COUNT    SELLOC_COUNT
 #include "specenum_gen.h"
 
+struct act_confirmation_data
+{
+  action_id act;
+  int actor;
+  int target;
+  int tgt_sub;
+  char *name;
+};
+
 void request_unit_select(struct unit_list *punits,
                          enum unit_select_type_mode seltype,
                          enum unit_select_location_mode selloc);
@@ -147,6 +157,7 @@ void request_unit_select(struct unit_list *punits,
 void request_do_action(action_id action, int actor_id,
                        int target_id, int sub_tgt, const char *name);
 void request_action_details(action_id action, int actor_id, int target_id);
+void action_confirmation(struct act_confirmation_data *data, bool confirm);
 void request_toggle_city_outlines(void);
 void request_toggle_city_output(void);
 void request_toggle_map_grid(void);
@@ -161,7 +172,7 @@ void request_toggle_city_trade_routes(void);
 void request_toggle_unit_stack_size(void);
 void request_toggle_terrain(void);
 void request_toggle_coastline(void);
-void request_toggle_roads_rails(void);
+void request_toggle_paths(void);
 void request_toggle_irrigation(void);
 void request_toggle_mines(void);
 void request_toggle_bases(void);
@@ -218,7 +229,7 @@ void key_city_trade_routes_toggle(void);
 void key_unit_stack_size_toggle(void);
 void key_terrain_toggle(void);
 void key_coastline_toggle(void);
-void key_roads_rails_toggle(void);
+void key_paths_toggle(void);
 void key_irrigation_toggle(void);
 void key_mines_toggle(void);
 void key_bases_toggle(void);
@@ -251,7 +262,6 @@ void key_unit_action_select_tgt(void);
 void key_unit_clean(void);
 void key_unit_convert(void);
 void key_unit_done(void);
-void key_unit_fallout(void);
 void key_unit_fortify(void);
 void key_unit_fortress(void);
 void key_unit_goto(void);
@@ -263,9 +273,9 @@ void key_unit_plant(void);
 void key_unit_patrol(void);
 void key_unit_paradrop(void);
 void key_unit_pillage(void);
-void key_unit_pollution(void);
 void key_unit_road(void);
 void key_unit_sentry(void);
+void key_unit_teleport(void);
 void key_unit_trade_route(void);
 void key_unit_transform(void);
 void key_unit_unload_all(void);
@@ -290,4 +300,4 @@ extern int num_units_below;
 }
 #endif /* __cplusplus */
 
-#endif  /* FC__CONTROL_H */
+#endif /* FC__CONTROL_H */
