@@ -44,7 +44,7 @@
 #include "packhand.h"
 #include "text.h"
 
-/* client/gui-gtk-3.0 */
+/* client/gui-gtk-3.22 */
 #include "citydlg.h"
 #include "dialogs.h"
 #include "unitselextradlg.h"
@@ -423,7 +423,6 @@ static void found_city_callback(GtkWidget *w, gpointer data)
   struct action_data *args = act_sel_dialog_data;
 
   dsend_packet_city_name_suggestion_req(&client.conn,
-                                        args->actor_unit_id,
                                         args->actor_unit_id);
 
   gtk_widget_destroy(act_sel_dialog);
@@ -583,13 +582,10 @@ static void create_advances_list(struct player *pplayer,
   struct unit *actor_unit = game_unit_by_number(args->actor_unit_id);
 
   spy_tech_shell = gtk_dialog_new_with_buttons(_("Steal Technology"),
-    NULL,
-    0,
-    GTK_STOCK_CANCEL,
-    GTK_RESPONSE_CANCEL,
-    _("_Steal"),
-    GTK_RESPONSE_ACCEPT,
-    NULL);
+                                               NULL, 0,
+                                               _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                               _("_Steal"), GTK_RESPONSE_ACCEPT,
+                                               NULL);
   setup_dialog(spy_tech_shell, toplevel);
   gtk_window_set_position(GTK_WINDOW(spy_tech_shell), GTK_WIN_POS_MOUSE);
 
@@ -774,13 +770,10 @@ static void create_improvements_list(struct player *pplayer,
   struct unit *actor_unit = game_unit_by_number(args->actor_unit_id);
   
   spy_sabotage_shell = gtk_dialog_new_with_buttons(_("Sabotage Improvements"),
-    NULL,
-    0,
-    GTK_STOCK_CANCEL,
-    GTK_RESPONSE_CANCEL,
-    _("_Sabotage"), 
-    GTK_RESPONSE_ACCEPT,
-    NULL);
+                                                   NULL, 0,
+                                                   _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                   _("_Sabotage"), GTK_RESPONSE_ACCEPT,
+                                                   NULL);
   setup_dialog(spy_sabotage_shell, toplevel);
   gtk_window_set_position(GTK_WINDOW(spy_sabotage_shell), GTK_WIN_POS_MOUSE);
 
@@ -1033,18 +1026,17 @@ static void tgt_unit_change_callback(GtkWidget *dlg, gint arg)
       if (tgt_unit == NULL) {
         /* Make the action dialog pop up again. */
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id, actor->id,
+                                      actor->id,
                                       /* Let the server choose the target
                                        * unit. */
                                       IDENTITY_NUMBER_ZERO,
-                                      IDENTITY_NUMBER_ZERO,
                                       tgt_tile->index,
                                       action_selection_target_extra(),
                                       REQEST_PLAYER_INITIATED);
       } else {
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id, actor->id,
-                                      tgt_id, tgt_id,
+                                      actor->id,
+                                      tgt_id,
                                       tgt_tile->index,
                                       action_selection_target_extra(),
                                       REQEST_PLAYER_INITIATED);
@@ -1101,13 +1093,12 @@ static void tgt_extra_change_callback(GtkWidget *dlg, gint arg)
                                                      "target"));
       struct extra_type *tgt_extra = extra_by_number(tgt_id);
       struct tile *tgt_tile = g_object_get_data(G_OBJECT(dlg), "tile");
-      int tgt_unit = action_selection_target_unit();
 
       if (tgt_extra == NULL) {
         /* Make the action dialog pop up again. */
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id, actor->id,
-                                      tgt_unit, tgt_unit,
+                                      actor->id,
+                                      action_selection_target_unit(),
                                       tgt_tile->index,
                                       /* Let the server choose the target
                                        * extra. */
@@ -1115,8 +1106,8 @@ static void tgt_extra_change_callback(GtkWidget *dlg, gint arg)
                                       REQEST_PLAYER_INITIATED);
       } else {
         dsend_packet_unit_get_actions(&client.conn,
-                                      actor->id, actor->id,
-                                      tgt_unit, tgt_unit,
+                                      actor->id,
+                                      action_selection_target_unit(),
                                       tgt_tile->index,
                                       tgt_id,
                                       REQEST_PLAYER_INITIATED);
@@ -1558,7 +1549,7 @@ void popup_action_selection(struct unit *actor_unit,
 
   action_button_map[BUTTON_CANCEL] =
       choice_dialog_get_number_of_buttons(shl);
-  choice_dialog_add(shl, GTK_STOCK_CANCEL,
+  choice_dialog_add(shl, _("_Cancel"),
                     (GCallback)act_sel_cancel_callback,
                     GINT_TO_POINTER(ACTION_NONE),
                     FALSE, NULL);
