@@ -35,7 +35,7 @@
 #include "messagewin_g.h"
 #include "options.h"
 
-/* client/gui-gtk-4.0 */
+/* client/gui-gtk-3.22 */
 #include "cityrep.h"
 #include "dialogs.h"
 #include "gui_main.h"
@@ -63,9 +63,8 @@ static struct cma_dialog *get_cma_dialog(struct city *pcity);
 
 static void update_cma_preset_list(struct cma_dialog *pdialog);
 
-static gboolean cma_preset_key_pressed(GtkEventControllerKey *controller,
-                                       guint keyval, guint keycode,
-                                       GdkModifierType state, gpointer data);
+static gboolean cma_preset_key_pressed_callback(GtkWidget *w, GdkEventKey *ev,
+						gpointer data);
 static void cma_del_preset_callback(GtkWidget *w, gpointer data);
 static void cma_preset_remove(struct cma_dialog *pdialog, int preset_index);
 static void cma_preset_remove_response(GtkWidget *w, gint response,
@@ -100,7 +99,7 @@ void cma_fe_done(void)
 }
 
 /**********************************************************************//**
- only called when the city dialog is closed.
+  Only called when the city dialog is closed.
 **************************************************************************/
 void close_cma_dialog(struct city *pcity)
 {
@@ -110,9 +109,7 @@ void close_cma_dialog(struct city *pcity)
     /* A city which is being investigated doesn't contain cma dialog */
     return;
   }
-
-  gtk_box_remove(GTK_BOX(gtk_widget_get_parent(pdialog->shell)),
-                 pdialog->shell);
+  gtk_widget_destroy(pdialog->shell);
 }
 
 /**********************************************************************//**
@@ -143,21 +140,18 @@ struct cma_dialog *get_cma_dialog(struct city *pcity)
 /**********************************************************************//**
   User has pressed button in cma dialog
 **************************************************************************/
-static gboolean button_press_callback(GtkGestureClick *gesture, int n_press,
-                                      double x, double y)
+static gboolean button_press_callback(GtkTreeView *view, GdkEventButton *ev,
+                                      gpointer data)
 {
-  GtkWidget *widget = gtk_event_controller_get_widget(GTK_EVENT_CONTROLLER(gesture));
-  struct cma_dialog *pdialog
-    = (struct cma_dialog *) g_object_get_data(G_OBJECT(widget), "dialog");
   GtkTreePath *path;
   GtkTreeViewColumn *column;
 
-  if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(pdialog->preset_list),
-                                    x, y, &path, &column, NULL, NULL)) {
-    if (n_press == 1) {
-      cma_activate_preset_callback(GTK_TREE_VIEW(pdialog->preset_list),
-                                   path, column, pdialog);
-    } else if (n_press == 2) {
+  if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(view),
+	ev->x, ev->y, &path, &column, NULL, NULL)) {
+    if (ev->type == GDK_BUTTON_PRESS) {
+      cma_activate_preset_callback(view, path, column, data);
+    } else if (ev->type == GDK_2BUTTON_PRESS) {
+      struct cma_dialog *pdialog = (struct cma_dialog *) data;
       struct cm_parameter param;
 
       cmafec_get_fe_parameter(pdialog->pcity, &param);
@@ -221,16 +215,13 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
 {
   struct cma_dialog *pdialog;
   struct cm_parameter param;
-  GtkWidget *frame, *page, *hbox, *vbox, *label, *table;
-  GtkWidget *sw, *hscale, *button;
+  GtkWidget *frame, *page, *hbox, *label, *table;
+  GtkWidget *vbox, *sw, *hscale, *button;
   GtkListStore *store;
   GtkCellRenderer *rend;
   GtkWidget *view;
   GtkTreeViewColumn *column;
   gint layout_width;
-  GtkEventController *controller;
-  int shell_row = 0;
-  PangoLayout *layout;
 
   cmafec_get_fe_parameter(pcity, &param);
   pdialog = fc_malloc(sizeof(struct cma_dialog));
@@ -239,22 +230,23 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
   gtk_orientable_set_orientation(GTK_ORIENTABLE(pdialog->shell),
                                  GTK_ORIENTATION_VERTICAL);
   gtk_grid_set_row_spacing(GTK_GRID(pdialog->shell), 8);
-  gtk_widget_set_margin_start(pdialog->shell, 8);
-  gtk_widget_set_margin_end(pdialog->shell, 8);
-  gtk_widget_set_margin_top(pdialog->shell, 8);
-  gtk_widget_set_margin_bottom(pdialog->shell, 8);
+  gtk_container_set_border_width(GTK_CONTAINER(pdialog->shell), 8);
   g_signal_connect(pdialog->shell, "destroy",
                    G_CALLBACK(cma_dialog_destroy_callback), pdialog);
 
-  page = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
-  gtk_grid_attach(GTK_GRID(pdialog->shell), page, 0, shell_row++, 1, 1);
+  page = gtk_grid_new();
+  gtk_grid_set_column_spacing(GTK_GRID(page), 12);
+  gtk_container_add(GTK_CONTAINER(pdialog->shell), page);
 
-  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
+  vbox = gtk_grid_new();
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
+                                 GTK_ORIENTATION_VERTICAL);
   gtk_grid_set_row_spacing(GTK_GRID(pdialog->shell), 2);
-  gtk_box_append(GTK_BOX(page), vbox);
+  gtk_container_add(GTK_CONTAINER(page), vbox);
 
-  sw = gtk_scrolled_window_new();
-  gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(sw), TRUE);
+  sw = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
+                                      GTK_SHADOW_ETCHED_IN);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 
@@ -269,11 +261,8 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
   pdialog->preset_list = view;
   pdialog->selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
 
-  g_object_set_data(G_OBJECT(pdialog->preset_list), "dialog", pdialog);
-  controller = GTK_EVENT_CONTROLLER(gtk_gesture_click_new());
-  g_signal_connect(controller, "pressed",
-                   G_CALLBACK(button_press_callback), NULL);
-  gtk_widget_add_controller(pdialog->preset_list, controller);
+  g_signal_connect(pdialog->preset_list, "button_press_event",
+                   G_CALLBACK(button_press_callback), pdialog);
 
   gtk_widget_set_tooltip_text(view,
                               _("For information on\n"
@@ -293,64 +282,61 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
                        "mnemonic-widget", view,
                        "label", _("Prese_ts:"),
                        "xalign", 0.0, "yalign", 0.5, NULL);
-  gtk_box_append(GTK_BOX(vbox), label);
+  gtk_container_add(GTK_CONTAINER(vbox), label);
 
-  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
-  gtk_box_append(GTK_BOX(vbox), sw);
+  gtk_container_add(GTK_CONTAINER(sw), view);
+  gtk_container_add(GTK_CONTAINER(vbox), sw);
 
   g_signal_connect(view, "row_activated",
                    G_CALLBACK(cma_activate_preset_callback), pdialog);
-  controller = gtk_event_controller_key_new();
-  g_signal_connect(controller, "key-pressed",
-                   G_CALLBACK(cma_preset_key_pressed), pdialog);
-  gtk_widget_add_controller(view, controller);
+  g_signal_connect(view, "key-press-event",
+                   G_CALLBACK(cma_preset_key_pressed_callback), pdialog);
 
-  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
-  gtk_box_append(GTK_BOX(vbox), hbox);
+  hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
+  gtk_button_box_set_layout(GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_EDGE);
+  gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
   button = icon_label_button_new("document-new", _("Ne_w"));
-  gtk_box_append(GTK_BOX(hbox), button);
+  gtk_container_add(GTK_CONTAINER(hbox), button);
   g_signal_connect(button, "clicked",
                    G_CALLBACK(cma_add_preset_callback), pdialog);
   pdialog->add_preset_command = button;
 
   pdialog->del_preset_command = icon_label_button_new("edit-delete",
                                                       _("_Delete"));
-  gtk_box_append(GTK_BOX(hbox), pdialog->del_preset_command);
+  gtk_container_add(GTK_CONTAINER(hbox), pdialog->del_preset_command);
   g_signal_connect(pdialog->del_preset_command, "clicked",
                    G_CALLBACK(cma_del_preset_callback), pdialog);
 
-  /* The right-hand side */
-  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
-  gtk_widget_set_margin_bottom(vbox, 2);
-  gtk_widget_set_margin_end(vbox, 2);
-  gtk_widget_set_margin_start(vbox, 2);
-  gtk_widget_set_margin_top(vbox, 2);
-  gtk_box_append(GTK_BOX(page), vbox);
+  /* the right-hand side */
+
+  vbox = gtk_grid_new();
+  g_object_set(vbox, "margin", 2, NULL);
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
+                                 GTK_ORIENTATION_VERTICAL);
+  gtk_container_add(GTK_CONTAINER(page), vbox);
 
   /* Result */
   if (!tiny) {
     frame = gtk_frame_new(_("Results"));
     gtk_widget_set_vexpand(frame, TRUE);
     gtk_widget_set_valign(frame, GTK_ALIGN_CENTER);
-    gtk_box_append(GTK_BOX(vbox), frame);
+    gtk_container_add(GTK_CONTAINER(vbox), frame);
 
     pdialog->result_label =
       gtk_label_new("food\n prod\n trade\n\n people\n grow\n prod\n name");
     gtk_widget_set_name(pdialog->result_label, "city_label");
-    gtk_frame_set_child(GTK_FRAME(frame), pdialog->result_label);
+    gtk_container_add(GTK_CONTAINER(frame), pdialog->result_label);
     gtk_label_set_justify(GTK_LABEL(pdialog->result_label), GTK_JUSTIFY_LEFT);
   } else {
     pdialog->result_label = NULL;
   }
 
   /* Minimal Surplus and Factor */
+
   table = gtk_grid_new();
-  gtk_widget_set_margin_bottom(table, 2);
-  gtk_widget_set_margin_end(table, 2);
-  gtk_widget_set_margin_start(table, 2);
-  gtk_widget_set_margin_top(table, 2);
-  gtk_box_append(GTK_BOX(vbox), table);
+  g_object_set(table, "margin", 2, NULL);
+  gtk_container_add(GTK_CONTAINER(vbox), table);
 
   label = gtk_label_new(_("Minimal Surplus"));
   gtk_widget_set_halign(label, GTK_ALIGN_START);
@@ -373,11 +359,9 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
                         GUI_GTK_OPTION(governor_range_min),
                         GUI_GTK_OPTION(governor_range_max));
     gtk_range_set_increments(GTK_RANGE(hscale), 1, 1);
-    layout = gtk_scale_get_layout(GTK_SCALE(hscale));
-    if (layout != NULL) {
-      pango_layout_get_pixel_size(layout, &layout_width, NULL);
-      gtk_widget_set_size_request(hscale, layout_width + 51 * 2, -1);
-    }
+    pango_layout_get_pixel_size(gtk_scale_get_layout(GTK_SCALE(hscale)),
+                                &layout_width, NULL);
+    gtk_widget_set_size_request(hscale, layout_width + 51 * 2, -1);
 
     gtk_grid_attach(GTK_GRID(table), hscale, 1, i + 1, 1, 1);
     gtk_scale_set_digits(GTK_SCALE(hscale), 0);
@@ -387,16 +371,12 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
                      "value-changed",
                      G_CALLBACK(hscale_changed), pdialog);
 
-    pdialog->factor[i] = hscale
-      = gtk_scale_new(GTK_ORIENTATION_HORIZONTAL, NULL);
+    pdialog->factor[i] = hscale =
+        gtk_scale_new(GTK_ORIENTATION_HORIZONTAL, NULL);
     gtk_range_set_range(GTK_RANGE(hscale), 0, 25);
     gtk_range_set_increments(GTK_RANGE(hscale), 1, 1);
-    layout = gtk_scale_get_layout(GTK_SCALE(hscale));
-    if (layout != NULL) {
-      pango_layout_get_pixel_size(layout, &layout_width, NULL);
-    } else {
-      layout_width = 20;
-    }
+    pango_layout_get_pixel_size(gtk_scale_get_layout(GTK_SCALE(hscale)),
+                                &layout_width, NULL);
     gtk_widget_set_size_request(hscale, layout_width + 26 * 2, -1);
 
     gtk_grid_attach(GTK_GRID(table), hscale, 2, i + 1, 1, 1);
@@ -415,8 +395,8 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
 
   pdialog->happy_button = gtk_check_button_new();
   gtk_widget_set_halign(pdialog->happy_button, GTK_ALIGN_END);
-  gtk_check_button_set_active(GTK_CHECK_BUTTON(pdialog->happy_button),
-                              FALSE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pdialog->happy_button),
+                               FALSE);
   gtk_grid_attach(GTK_GRID(table), pdialog->happy_button, 1, O_LAST + 1, 1, 1);
 
   g_signal_connect(pdialog->happy_button, "toggled",
@@ -426,11 +406,9 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
       gtk_scale_new(GTK_ORIENTATION_HORIZONTAL, NULL);
   gtk_range_set_range(GTK_RANGE(hscale), 0, 50);
   gtk_range_set_increments(GTK_RANGE(hscale), 1, 1);
-  layout = gtk_scale_get_layout(GTK_SCALE(hscale));
-  if (layout != NULL) {
-    pango_layout_get_pixel_size(layout, &layout_width, NULL);
-    gtk_widget_set_size_request(hscale, layout_width + 51 * 2, -1);
-  }
+  pango_layout_get_pixel_size(gtk_scale_get_layout(GTK_SCALE(hscale)),
+                              &layout_width, NULL);
+  gtk_widget_set_size_request(hscale, layout_width + 51 * 2, -1);
 
   gtk_grid_attach(GTK_GRID(table), hscale, 2, O_LAST + 1, 1, 1);
   gtk_scale_set_digits(GTK_SCALE(hscale), 0);
@@ -448,28 +426,33 @@ struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny)
 
   pdialog->growth_button = gtk_check_button_new();
   gtk_widget_set_halign(pdialog->growth_button, GTK_ALIGN_END);
-  gtk_check_button_set_active(GTK_CHECK_BUTTON(pdialog->growth_button),
-                              FALSE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pdialog->growth_button),
+                               FALSE);
   gtk_grid_attach(GTK_GRID(table), pdialog->growth_button, 1, O_LAST + 2, 1, 1);
 
   g_signal_connect(pdialog->growth_button, "toggled",
                    G_CALLBACK(hscale_changed), pdialog);
 
   /* Buttons */
-  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
-  gtk_box_append(GTK_BOX(vbox), hbox);
+  hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
+  gtk_button_box_set_layout(GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_EDGE);
+  gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
   button = icon_label_button_new("help-browser", _("Help"));
   g_signal_connect(button, "clicked",
                    G_CALLBACK(help_callback), NULL);
-  gtk_box_append(GTK_BOX(hbox), button);
+  gtk_container_add(GTK_CONTAINER(hbox), button);
+  gtk_button_box_set_child_non_homogeneous(GTK_BUTTON_BOX(hbox),
+                                           button, TRUE);
 
   pdialog->active_command = gtk_toggle_button_new();
   gtk_button_set_use_underline(GTK_BUTTON(pdialog->active_command), TRUE);
+  gtk_button_set_image_position(GTK_BUTTON(pdialog->active_command),
+                                GTK_POS_TOP);
   gtk_widget_set_name(pdialog->active_command, "comment_label");
-  gtk_box_append(GTK_BOX(hbox), pdialog->active_command);
+  gtk_container_add(GTK_CONTAINER(hbox), pdialog->active_command);
 
-  gtk_widget_show(pdialog->shell);
+  gtk_widget_show_all(pdialog->shell);
 
   dialog_list_prepend(dialog_list, pdialog);
 
@@ -586,7 +569,7 @@ static void cma_add_preset_callback(GtkWidget *w, gpointer data)
 {
   struct cma_dialog *pdialog = (struct cma_dialog *) data;
   const char *default_name;
-  GtkWidget *parent = gtk_widget_get_ancestor(pdialog->shell, GTK_TYPE_WINDOW);
+  GtkWidget *parent = gtk_widget_get_toplevel(pdialog->shell);
   int index;
 
   if ((index = gtk_tree_selection_get_row(pdialog->selection)) != -1) {
@@ -629,9 +612,8 @@ static void cma_preset_add_popup_callback(gpointer data, gint response,
 /**********************************************************************//**
   Key pressed in preset list
 **************************************************************************/
-static gboolean cma_preset_key_pressed(GtkEventControllerKey *controller,
-                                       guint keyval, guint keycode,
-                                       GdkModifierType state, gpointer data)
+static gboolean cma_preset_key_pressed_callback(GtkWidget *w, GdkEventKey *ev,
+                                                gpointer data)
 {
   struct cma_dialog *pdialog = (struct cma_dialog *) data;
   int index;
@@ -640,18 +622,20 @@ static gboolean cma_preset_key_pressed(GtkEventControllerKey *controller,
     return FALSE;
   }
 
-  switch (keyval) {
-  case GDK_KEY_Delete:
-    cma_preset_remove(pdialog, index);
-    break;
-  case GDK_KEY_Insert:
-    cma_add_preset_callback(NULL, pdialog);
-    break;
-  default:
-    return FALSE;
+  if (ev->type == GDK_KEY_PRESS) {
+    switch (ev->keyval) {
+    case GDK_KEY_Delete:
+      cma_preset_remove(pdialog, index);
+      break;
+    case GDK_KEY_Insert:
+      cma_add_preset_callback(NULL, pdialog);
+      break;
+    default:
+      return FALSE;
+    }
+    return TRUE;
   }
-
-  return TRUE;
+  return FALSE;
 }
 
 /**********************************************************************//**
@@ -674,8 +658,7 @@ static void cma_del_preset_callback(GtkWidget *w, gpointer data)
 **************************************************************************/
 static void cma_preset_remove(struct cma_dialog *pdialog, int preset_index)
 {
-  GtkWidget *parent = gtk_widget_get_ancestor(pdialog->shell, GTK_TYPE_WINDOW);
-  GtkWidget *shl;
+  GtkWidget *parent = gtk_widget_get_toplevel(pdialog->shell), *shl;
 
   pdialog->id = preset_index;
   shl = gtk_message_dialog_new(NULL,
@@ -687,6 +670,7 @@ static void cma_preset_remove(struct cma_dialog *pdialog, int preset_index)
   pdialog->preset_remove_shell = shl;
 
   gtk_window_set_title(GTK_WINDOW(shl), cmafec_preset_get_descr(preset_index));
+  gtk_window_set_position(GTK_WINDOW(shl), GTK_WIN_POS_CENTER_ON_PARENT);
 
   g_signal_connect(shl, "response",
                    G_CALLBACK(cma_preset_remove_response), pdialog);
@@ -710,8 +694,8 @@ static void cma_preset_remove_response(GtkWidget *w, gint response,
     /* if this or other cities have this set, reset to "custom" */
     city_report_dialog_update();
   }
-  gtk_window_destroy(GTK_WINDOW(w));
-
+  gtk_widget_destroy(w);
+  
   pdialog->preset_remove_shell = NULL;
 }
 
@@ -746,10 +730,10 @@ static void set_hscales(const struct cm_parameter *const parameter,
                         parameter->minimal_surplus[i]);
     gtk_range_set_value(GTK_RANGE(pdialog->factor[i]), parameter->factor[i]);
   } output_type_iterate_end;
-  gtk_check_button_set_active(GTK_CHECK_BUTTON(pdialog->happy_button),
-                              parameter->require_happy);
-  gtk_check_button_set_active(GTK_CHECK_BUTTON(pdialog->growth_button),
-                              parameter->max_growth);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pdialog->happy_button),
+                               parameter->require_happy);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pdialog->growth_button),
+                               parameter->max_growth);
   gtk_range_set_value(GTK_RANGE(pdialog->factor[O_LAST]),
                       parameter->happy_factor);
   allow_refreshes = 1;
@@ -775,9 +759,11 @@ static void hscale_changed(GtkWidget *get, gpointer data)
         (int) (gtk_range_get_value(GTK_RANGE(pdialog->factor[i])));
   } output_type_iterate_end;
   param.require_happy =
-      (gtk_check_button_get_active(GTK_CHECK_BUTTON(pdialog->happy_button)) ? TRUE : FALSE);
+      (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pdialog->happy_button))
+       ? TRUE : FALSE);
   param.max_growth =
-      (gtk_check_button_get_active(GTK_CHECK_BUTTON(pdialog->growth_button)) ? TRUE : FALSE);
+      (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pdialog->growth_button))
+       ? TRUE : FALSE);
   param.happy_factor =
       (int) (gtk_range_get_value(GTK_RANGE(pdialog->factor[O_LAST])));
 
