@@ -33,6 +33,7 @@
 #include "game.h"
 #include "government.h"
 #include "movement.h"
+#include "nation.h"
 #include "specialist.h"
 #include "tech.h"
 #include "unit.h"
@@ -66,6 +67,7 @@ static GtkWidget *help_view_sw;
 static GtkWidget *help_view;
 
 static GtkWidget *help_frame;
+static int help_frame_width = 520, help_frame_height = 350;
 static GtkTextBuffer *help_text;
 static GtkWidget *help_text_sw;
 static GtkWidget *help_vbox;
@@ -601,7 +603,7 @@ static void create_help_dialog(void)
 
   help_frame = gtk_frame_new("");
   gtk_container_add(GTK_CONTAINER(hbox), help_frame);
-  gtk_widget_set_size_request(help_frame, 520, 350);
+  gtk_widget_set_size_request(help_frame, help_frame_width, help_frame_height);
   gtk_widget_show(help_frame);
 
   help_box = gtk_grid_new();
@@ -781,8 +783,8 @@ static void create_help_dialog(void)
   gtk_widget_show(help_tree);
   gtk_container_add(GTK_CONTAINER(help_box), help_tree_sw);
 
-  help_tree_expand =
-	gtk_button_new_with_label(_("Expand All"));
+  help_tree_expand
+    = gtk_button_new_with_label(_("Expand All"));
   help_tree_collapse = gtk_button_new_with_label(_("Collapse All"));
 
   g_signal_connect(help_tree_expand, "clicked",
@@ -1009,12 +1011,8 @@ static void help_update_unit_type(const struct help_item *pitem,
 		       helptext_unit_upkeep_str(utype));
     sprintf(buf, "%d", (int)sqrt((double)utype->vision_radius_sq));
     gtk_label_set_text(GTK_LABEL(help_ulabel[3][4]), buf);
-    if (A_NEVER == utype->require_advance) {
-      gtk_label_set_text(GTK_LABEL(help_ulabel[4][1]), REQ_LABEL_NEVER);
-    } else {
-      gtk_label_set_text(GTK_LABEL(help_ulabel[4][1]),
-                         advance_name_translation(utype->require_advance));
-    }
+    gtk_label_set_text(GTK_LABEL(help_ulabel[4][1]),
+                       advance_name_translation(utype_primary_tech_req(utype)));
 /*    create_tech_tree(help_improvement_tree, 0, advance_number(utype->require_advance), 3);*/
     if (U_NOT_OBSOLETED == utype->obsoleted_by) {
       gtk_label_set_text(GTK_LABEL(help_ulabel[4][4]), skip_intl_qualifier_prefix(REQ_LABEL_NONE));
@@ -1023,12 +1021,14 @@ static void help_update_unit_type(const struct help_item *pitem,
 			 utype_name_translation(utype->obsoleted_by));
     }
 
-    helptext_unit(buf, sizeof(buf), client.conn.playing, pitem->text, utype);
+    helptext_unit(buf, sizeof(buf), client.conn.playing, pitem->text, utype,
+                  TRUE);
 
     gtk_text_buffer_set_text(help_text, buf, -1);
     gtk_widget_show(help_text_sw);
 
     set_help_tile_from_sprite(get_unittype_sprite(tileset, utype,
+                                                  ACTIVITY_LAST,
                                                   direction8_invalid()));
   } else {
     gtk_label_set_text(GTK_LABEL(help_ulabel[0][1]), "0");
@@ -1178,9 +1178,11 @@ static void help_update_tech(const struct help_item *pitem, char *title)
     } improvement_iterate_end;
 
     unit_type_iterate(punittype) {
-      if (padvance != punittype->require_advance) {
+
+      if (!is_tech_req_for_utype(punittype, padvance)) {
 	continue;
       }
+
       hbox = gtk_grid_new();
       gtk_container_add(GTK_CONTAINER(help_vbox), hbox);
       w = gtk_label_new(_("Allows"));
@@ -1190,7 +1192,7 @@ static void help_update_tech(const struct help_item *pitem, char *title)
       gtk_widget_show_all(hbox);
     } unit_type_iterate_end;
 
-    advance_iterate(A_NONE, ptest) {
+    advance_iterate_all(ptest) {
       if (padvance == advance_requires(ptest, AR_ONE)) {
 	if (advance_by_number(A_NONE) == advance_requires(ptest, AR_TWO)) {
           hbox = gtk_grid_new();
@@ -1234,7 +1236,7 @@ static void help_update_tech(const struct help_item *pitem, char *title)
         gtk_container_add(GTK_CONTAINER(hbox), w);
         gtk_widget_show_all(hbox);
       }
-    } advance_iterate_end;
+    } advance_iterate_all_end;
     gtk_widget_show(help_vbox);
   }
 }
@@ -1319,6 +1321,7 @@ static void help_update_terrain(const struct help_item *pitem,
     if (*(pterrain->resources)) {
       struct extra_type **r;
 
+      /* TODO: include resource frequency information */
       for (r = pterrain->resources; *r; r++) {
         /* TRANS: " Whales (2/1/2)," */
         sprintf (buf + strlen (buf), " %s (%d/%d/%d),",
@@ -1369,19 +1372,22 @@ static void help_update_terrain(const struct help_item *pitem,
     }
 
     if (action_id_univs_not_blocking(ACTION_IRRIGATE, NULL, &for_terr)) {
-      help_extras_of_act_for_terrain(pterrain, ACTIVITY_IRRIGATE, _("Build as irrigation"));
+      help_extras_of_act_for_terrain(pterrain, ACTIVITY_IRRIGATE,
+                                     _("Build as irrigation"));
     }
     if (action_id_univs_not_blocking(ACTION_MINE, NULL, &for_terr)) {
-      help_extras_of_act_for_terrain(pterrain, ACTIVITY_MINE, _("Build as mine"));
+      help_extras_of_act_for_terrain(pterrain, ACTIVITY_MINE,
+                                     _("Build as mine"));
     }
-    if (pterrain->road_time != 0
-        && action_id_univs_not_blocking(ACTION_ROAD, NULL, &for_terr)) {
-      help_extras_of_act_for_terrain(pterrain, ACTIVITY_GEN_ROAD, _("Build as road"));
+    if (action_id_univs_not_blocking(ACTION_ROAD, NULL, &for_terr)) {
+      help_extras_of_act_for_terrain(pterrain, ACTIVITY_GEN_ROAD,
+                                     _("Build as road"));
     }
-    if (pterrain->base_time != 0
-        && action_id_univs_not_blocking(ACTION_BASE, NULL, &for_terr)) {
-      help_extras_of_act_for_terrain(pterrain, ACTIVITY_BASE, _("Build as base"));
+    if (action_id_univs_not_blocking(ACTION_BASE, NULL, &for_terr)) {
+      help_extras_of_act_for_terrain(pterrain, ACTIVITY_BASE,
+                                     _("Build as base"));
     }
+
     gtk_widget_show(help_vbox);
   }
 
@@ -1622,7 +1628,7 @@ static void help_item_zoom(GtkTreePath *path)
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(help_view));
   gtk_tree_model_get_iter(model, &item, path);
 
-  for (child=item; gtk_tree_model_iter_parent(model, &it, &child); child=it) {
+  for (child = item; gtk_tree_model_iter_parent(model, &it, &child); child=it) {
     GtkTreePath *it_path;
 
     it_path = gtk_tree_model_get_path(model, &it);
@@ -1752,6 +1758,9 @@ static void help_command_callback(GtkWidget *w, gint response_id)
       help_command_update();
     }
   } else {
+	  /* Save size of the dialog. */
+    help_frame_width = gtk_widget_get_allocated_width(help_frame);
+    help_frame_height = gtk_widget_get_allocated_height(help_frame);
     gtk_widget_destroy(help_dialog_shell);
   }
 }
