@@ -389,6 +389,7 @@ static void science_report_update(struct science_report *preport)
   const char *text;
   double pct;
   Tech_type_id tech;
+  Tech_type_id ac = advance_count();
 
   fc_assert_ret(NULL != preport);
   fc_assert_ret(NULL != presearch);
@@ -413,11 +414,11 @@ static void science_report_update(struct science_report *preport)
   sorting_list = NULL;
 
   /* Collect all techs which are reachable in the next step. */
-  advance_index_iterate(A_FIRST, i) {
+  advance_index_iterate_max(A_FIRST, i, ac) {
     if (TECH_PREREQS_KNOWN == presearch->inventions[i].state) {
       sorting_list = g_list_prepend(sorting_list, GINT_TO_POINTER(i));
     }
-  } advance_index_iterate_end;
+  } advance_index_iterate_max_end;
 
   if (sorting_list != NULL) {
     if (A_UNSET == presearch->researching
@@ -464,14 +465,14 @@ static void science_report_update(struct science_report *preport)
                      get_science_goal_text(presearch->tech_goal));
 
   /* Collect all techs which are reachable in next 10 steps. */
-  advance_index_iterate(A_FIRST, i) {
+  advance_index_iterate_max(A_FIRST, i, ac) {
     if (research_invention_reachable(presearch, i)
         && TECH_KNOWN != presearch->inventions[i].state
         && (i == presearch->tech_goal
             || 10 >= presearch->inventions[i].num_required_techs)) {
       sorting_list = g_list_prepend(sorting_list, GINT_TO_POINTER(i));
     }
-  } advance_index_iterate_end;
+  } advance_index_iterate_max_end;
 
   if (sorting_list != NULL) {
     if (A_UNSET == presearch->tech_goal) {
@@ -916,6 +917,7 @@ static void economy_report_update(struct economy_report *preport)
     struct unit_entry *pentry = unit_entries + i;
     struct unit_type *putype = pentry->type;
     struct sprite *sprite = get_unittype_sprite(tileset, putype,
+                                                ACTIVITY_LAST,
                                                 direction8_invalid());
     cid id = cid_encode_unit(putype);
 
@@ -1347,9 +1349,10 @@ static GtkListStore *units_report_store_new(void)
 {
   int i;
   GType cols[URD_COL_NUM];
+
   fc_assert(ARRAY_SIZE(unit_report_columns) == URD_COL_NUM);
 
-  for (i=0; i<URD_COL_NUM; i++) {
+  for (i = 0; i < URD_COL_NUM; i++) {
     cols[i] = unit_report_columns[i].type;
   }
   
