@@ -43,7 +43,7 @@
 #include "options.h"
 #include "text.h"
 
-/* clien/gui-gtk-3.0 */
+/* clien/gui-gtk-4.0 */
 #include "plrdlg.h"
 #include "dialogs.h"
 #include "gui_main.h"
@@ -113,7 +113,7 @@ static void goto_cmd_callback(GtkWidget *dlg, gint arg)
       struct city *pdestcity = get_selected_city();
 
       if (pdestcity) {
-	unit_list_iterate(get_units_in_focus(), punit) {
+        unit_list_iterate(get_units_in_focus(), punit) {
           send_goto_tile(punit, pdestcity->tile);
         } unit_list_iterate_end;
       }
@@ -124,7 +124,7 @@ static void goto_cmd_callback(GtkWidget *dlg, gint arg)
     break;
   }
 
-  gtk_widget_destroy(dlg);
+  gtk_window_destroy(GTK_WINDOW(dlg));
   dshell = NULL;
 }
 
@@ -138,28 +138,27 @@ static void create_goto_dialog(void)
   GtkTreeViewColumn *col;
 
   dshell = gtk_dialog_new_with_buttons(_("Goto/Airlift Unit"),
-    NULL,
-    0,
-    GTK_STOCK_CANCEL,
-    GTK_RESPONSE_CANCEL,
-    _("Air_lift"),
-    CMD_AIRLIFT,
-    _("_Goto"),
-    CMD_GOTO,
-    NULL);
+                                       NULL,
+                                       0,
+                                       _("_Cancel"),
+                                       GTK_RESPONSE_CANCEL,
+                                       _("Air_lift"),
+                                       CMD_AIRLIFT,
+                                       _("_Goto"),
+                                       CMD_GOTO,
+                                       NULL);
   setup_dialog(dshell, toplevel);
-  gtk_window_set_position(GTK_WINDOW(dshell), GTK_WIN_POS_MOUSE);
   gtk_dialog_set_default_response(GTK_DIALOG(dshell), CMD_GOTO);
   g_signal_connect(dshell, "destroy",
-		   G_CALLBACK(gtk_widget_destroyed), &dshell);
+                   G_CALLBACK(widget_destroyed), &dshell);
   g_signal_connect(dshell, "response",
                    G_CALLBACK(goto_cmd_callback), NULL);
 
-  source = gtk_label_new("" /* filled in later */);
-  gtk_label_set_line_wrap(GTK_LABEL(source), TRUE);
+  source = gtk_label_new("" /* Filled in later */);
+  gtk_label_set_wrap(GTK_LABEL(source), TRUE);
   gtk_label_set_justify(GTK_LABEL(source), GTK_JUSTIFY_CENTER);
-  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
-        source, FALSE, FALSE, 0);
+  gtk_box_insert_child_after(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
+                             source, NULL);
 
   label = g_object_new(GTK_TYPE_LABEL,
     "use-underline", TRUE,
@@ -169,17 +168,15 @@ static void create_goto_dialog(void)
     NULL);
   frame = gtk_frame_new("");
   gtk_frame_set_label_widget(GTK_FRAME(frame), label);
-  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
-        frame, TRUE, TRUE, 0);
+  gtk_box_insert_child_after(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
+                             frame, NULL);
 
-  vbox = gtk_grid_new();
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
-                                 GTK_ORIENTATION_VERTICAL);
-  gtk_grid_set_row_spacing(GTK_GRID(vbox), 6);
-  gtk_container_add(GTK_CONTAINER(frame), vbox);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+  gtk_frame_set_child(GTK_FRAME(frame), vbox);
 
   goto_list_store = gtk_list_store_new(GD_COL_NUM, G_TYPE_INT, G_TYPE_STRING,
-                                       GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING);
+                                       GDK_TYPE_PIXBUF, G_TYPE_STRING,
+                                       G_TYPE_STRING);
   gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(goto_list_store),
                                        GD_COL_CITY_NAME, GTK_SORT_ASCENDING);
 
@@ -216,33 +213,36 @@ static void create_goto_dialog(void)
 
   rend = gtk_cell_renderer_text_new();
   col = gtk_tree_view_column_new_with_attributes(_("Nation"), rend,
-    "text", GD_COL_NATION, NULL);
+                                                 "text", GD_COL_NATION,
+                                                 NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
   gtk_tree_view_column_set_sort_column_id(col, GD_COL_NATION);
 
   rend = gtk_cell_renderer_text_new();
   col = gtk_tree_view_column_new_with_attributes(_("Airlift"), rend,
-    "text", GD_COL_AIRLIFT, NULL);
+                                                 "text", GD_COL_AIRLIFT,
+                                                 NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
   gtk_tree_view_column_set_sort_column_id(col, GD_COL_AIRLIFT);
 
-  sw = gtk_scrolled_window_new(NULL, NULL);
-  gtk_container_add(GTK_CONTAINER(sw), view);
+  sw = gtk_scrolled_window_new();
+  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
-    GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+                                 GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
   gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(sw), 200);
 
-  gtk_container_add(GTK_CONTAINER(vbox), sw);
+  gtk_box_append(GTK_BOX(vbox), sw);
 
   all_toggle = gtk_check_button_new_with_mnemonic(_("Show _All Cities"));
-  gtk_container_add(GTK_CONTAINER(vbox), all_toggle);
+  gtk_box_append(GTK_BOX(vbox), all_toggle);
 
-  g_signal_connect(all_toggle, "toggled", G_CALLBACK(update_goto_dialog), NULL);
+  g_signal_connect(all_toggle, "toggled",
+                   G_CALLBACK(update_goto_dialog), NULL);
 
   g_signal_connect(goto_list_selection, "changed",
-    G_CALLBACK(goto_selection_callback), NULL);
+                   G_CALLBACK(goto_selection_callback), NULL);
 
-  gtk_widget_show_all(dshell);
+  gtk_widget_set_visible(dshell, TRUE);
 
   original_tile = get_center_tile_mapcanvas();
 
@@ -379,7 +379,7 @@ static void update_source_label(void)
 
     astr_init(&strs[i]);
     if (air_text != NULL) {
-      astr_add(&strs[i], 
+      astr_add(&strs[i],
                /* TRANS: goto/airlift dialog. "Paris (airlift: 2/4)".
                 * A set of these appear in an "and"-separated list. */
                _("%s (airlift: %s)"),
@@ -408,7 +408,7 @@ static void update_source_label(void)
   /* Finally, update the label. */
   {
     struct astring label = ASTRING_INIT, list = ASTRING_INIT;
-    astr_set(&label, 
+    astr_set(&label,
              /* TRANS: goto/airlift dialog. Current location of units; %s is an
               * "and"-separated list of cities and associated info */
              _("Currently in: %s"),
@@ -431,7 +431,7 @@ static void update_source_label(void)
 static void update_goto_dialog(GtkToggleButton *button)
 {
   bool nonempty = FALSE;
-  
+
   if (!client_has_player()) {
     /* Case global observer. */
     return;
