@@ -33,8 +33,9 @@
 
 /* common */
 #include "game.h"
-#include "government.h"		/* government_graphic() */
+#include "government.h"	        /* government_graphic() */
 #include "map.h"
+#include "nation.h"
 #include "player.h"
 
 /* client */
@@ -50,7 +51,7 @@
 #include "text.h"
 #include "zoom.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-4.0 */
 #include "citydlg.h" /* For reset_city_dialogs() */
 #include "editgui.h"
 #include "graphics.h"
@@ -66,6 +67,9 @@ static GtkAdjustment *map_hadj, *map_vadj;
 static int cursor_timer_id = 0, cursor_type = -1, cursor_frame = 0;
 static int mapview_frozen_level = 0;
 
+static int mc_actual_width = -1;
+static int mc_actual_height = -1;
+
 /**********************************************************************//**
   If do_restore is FALSE it will invert the turn done button style. If
   called regularly from a timer this will give a blinking turn done
@@ -82,29 +86,29 @@ void update_turn_done_button(bool do_restore)
 
   if ((do_restore && flip) || !do_restore) {
     static GtkCssProvider *tdb_provider = NULL;
-    GtkStyleContext *scontext = gtk_widget_get_style_context(turn_done_button);
 
     if (tdb_provider == NULL) {
       tdb_provider = gtk_css_provider_new();
 
       gtk_css_provider_load_from_data(tdb_provider,
-                                      ".lighted {\n"
+                                      ".td_lighted {\n"
                                       "color: rgba(235, 127, 235, 255);\n"
                                       "background-color: rgba(127, 127, 127, 255);\n"
                                       "}\n",
-                                      -1, NULL);
+                                      -1);
 
       /* Turn Done button is persistent, so we only need to do this
        * once too. */
-      gtk_style_context_add_provider(scontext,
+      gtk_style_context_add_provider_for_display(
+                                     gtk_widget_get_display(toplevel),
                                      GTK_STYLE_PROVIDER(tdb_provider),
                                      GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
     }
 
     if (flip) {
-      gtk_style_context_add_class(scontext, "lighted");
+      gtk_widget_add_css_class(turn_done_button, "td_lighted");
     } else {
-      gtk_style_context_remove_class(scontext, "lighted");
+      gtk_widget_remove_css_class(turn_done_button, "td_lighted");
     }
 
     flip = !flip;
@@ -194,34 +198,34 @@ void update_info_label(void)
     for (; d < pplayer->economic.luxury / 10; d++) {
       struct sprite *spr = get_tax_sprite(tileset, O_LUXURY);
 
-      gtk_image_set_from_surface(GTK_IMAGE(econ_label[d]), spr->surface);
+      picture_set_from_surface(GTK_PICTURE(econ_label[d]), spr->surface);
     }
 
     for (; d < (pplayer->economic.science
                 + pplayer->economic.luxury) / 10; d++) {
       struct sprite *spr = get_tax_sprite(tileset, O_SCIENCE);
 
-      gtk_image_set_from_surface(GTK_IMAGE(econ_label[d]), spr->surface);
+      picture_set_from_surface(GTK_PICTURE(econ_label[d]), spr->surface);
     }
 
     for (; d < 10; d++) {
       struct sprite *spr = get_tax_sprite(tileset, O_GOLD);
 
-      gtk_image_set_from_surface(GTK_IMAGE(econ_label[d]), spr->surface);
+      picture_set_from_surface(GTK_PICTURE(econ_label[d]), spr->surface);
     }
   }
 
   update_timeout_label();
 
   /* Update tooltips. */
-  gtk_widget_set_tooltip_text(econ_ebox,
+  gtk_widget_set_tooltip_text(econ_widget,
                               _("Shows your current luxury/science/tax rates; "
                                 "click to toggle them."));
 
-  gtk_widget_set_tooltip_text(bulb_ebox, get_bulb_tooltip());
-  gtk_widget_set_tooltip_text(sun_ebox, get_global_warming_tooltip());
-  gtk_widget_set_tooltip_text(flake_ebox, get_nuclear_winter_tooltip());
-  gtk_widget_set_tooltip_text(government_ebox, get_government_tooltip());
+  gtk_widget_set_tooltip_text(bulb_label, get_bulb_tooltip());
+  gtk_widget_set_tooltip_text(sun_label, get_global_warming_tooltip());
+  gtk_widget_set_tooltip_text(flake_label, get_nuclear_winter_tooltip());
+  gtk_widget_set_tooltip_text(government_label, get_government_tooltip());
 }
 
 /**********************************************************************//**
@@ -239,13 +243,13 @@ static gboolean anim_cursor_cb(gpointer data)
   }
 
   if (cursor_type == CURSOR_DEFAULT) {
-    gdk_window_set_cursor(root_window, NULL);
+    gtk_widget_set_cursor(toplevel, NULL);
     cursor_timer_id = 0;
-    return FALSE; 
+    return FALSE;
   }
 
-  gdk_window_set_cursor(root_window,
-                fc_cursors[cursor_type][cursor_frame]);
+  gtk_widget_set_cursor(toplevel,
+                        fc_cursors[cursor_type][cursor_frame]);
   control_mouse_cursor(NULL);
   return TRUE;
 }
@@ -301,10 +305,10 @@ GdkPixbuf *get_thumb_pixbuf(int onoff)
 void set_indicator_icons(struct sprite *bulb, struct sprite *sol,
                          struct sprite *flake, struct sprite *gov)
 {
-  gtk_image_set_from_surface(GTK_IMAGE(bulb_label), bulb->surface);
-  gtk_image_set_from_surface(GTK_IMAGE(sun_label), sol->surface);
-  gtk_image_set_from_surface(GTK_IMAGE(flake_label), flake->surface);
-  gtk_image_set_from_surface(GTK_IMAGE(government_label), gov->surface);
+  picture_set_from_surface(GTK_PICTURE(bulb_label), bulb->surface);
+  picture_set_from_surface(GTK_PICTURE(sun_label), sol->surface);
+  picture_set_from_surface(GTK_PICTURE(flake_label), flake->surface);
+  picture_set_from_surface(GTK_PICTURE(government_label), gov->surface);
 }
 
 /**********************************************************************//**
@@ -337,9 +341,10 @@ struct canvas *get_overview_window(void)
 {
 #if 0
   static struct canvas store;
+  GtkNative *nat = gtk_widget_get_native(overview_canvas);
 
   store.surface = NULL;
-  store.drawable = gdk_cairo_create(gtk_widget_get_window(overview_canvas));
+  store.drawable = gdk_cairo_create(gtk_native_get_surface(nat));
 
   return &store;
 #endif /* 0 */
@@ -352,7 +357,8 @@ struct canvas *get_overview_window(void)
 /**********************************************************************//**
   Redraw overview canvas
 **************************************************************************/
-gboolean overview_canvas_draw(GtkWidget *w, cairo_t *cr, gpointer data)
+void overview_canvas_draw(GtkDrawingArea *w, cairo_t *cr,
+                          int width, int height, gpointer data)
 {
   gpointer source = (can_client_change_view()) ?
                      (gpointer)gui_options.overview.window : NULL;
@@ -363,7 +369,6 @@ gboolean overview_canvas_draw(GtkWidget *w, cairo_t *cr, gpointer data)
     cairo_set_source_surface(cr, surface, 0, 0);
     cairo_paint(cr);
   }
-  return TRUE;
 }
 
 /**********************************************************************//**
@@ -399,12 +404,13 @@ bool mapview_is_frozen(void)
 /**********************************************************************//**
   Update on canvas widget size change
 **************************************************************************/
-gboolean map_canvas_configure(GtkWidget *w, GdkEventConfigure *ev,
-                              gpointer data)
+void map_canvas_resize(GtkWidget *w, int width, int height,
+                       gpointer data)
 {
-  map_canvas_resized(ev->width, ev->height);
+  mc_actual_width = width;
+  mc_actual_height = height;
 
-  return TRUE;
+  map_canvas_size_refresh();
 }
 
 /**********************************************************************//**
@@ -412,27 +418,26 @@ gboolean map_canvas_configure(GtkWidget *w, GdkEventConfigure *ev,
 **************************************************************************/
 void map_canvas_size_refresh(void)
 {
-  /* Needed only with full screen zoom mode.
-   * Not needed, nor implemented, in this client. */
-  fc_assert(FALSE);
+  map_canvas_resized(mc_actual_width / mouse_zoom,
+                     mc_actual_height / mouse_zoom);
 }
 
 /**********************************************************************//**
   Redraw map canvas.
 **************************************************************************/
-gboolean map_canvas_draw(GtkWidget *w, cairo_t *cr, gpointer data)
+void map_canvas_draw(GtkDrawingArea *w, cairo_t *cr,
+                     int width, int height, gpointer data)
 {
   if (can_client_change_view() && !map_is_empty() && !mapview_is_frozen()) {
-    /* First we mark the area to be updated as dirty.  Then we unqueue
+    /* First we mark the area to be updated as dirty. Then we unqueue
      * any pending updates, to make sure only the most up-to-date data
      * is written (otherwise drawing bugs happen when old data is copied
-     * to screen).  Then we draw all changed areas to the screen. */
-    update_animation();
+     * to screen). Then we draw all changed areas to the screen. */
     unqueue_mapview_updates(FALSE);
+    cairo_scale(cr, mouse_zoom, mouse_zoom);
     cairo_set_source_surface(cr, mapview.store->surface, 0, 0);
     cairo_paint(cr);
   }
-  return TRUE;
 }
 
 /**********************************************************************//**
@@ -442,11 +447,7 @@ gboolean map_canvas_draw(GtkWidget *w, cairo_t *cr, gpointer data)
 void dirty_rect(int canvas_x, int canvas_y,
                 int pixel_width, int pixel_height)
 {
-  GdkRectangle rectangle = {canvas_x, canvas_y, pixel_width, pixel_height};
-
-  if (gtk_widget_get_realized(map_canvas)) {
-    gdk_window_invalidate_rect(gtk_widget_get_window(map_canvas), &rectangle, FALSE);
-  }
+  dirty_all();
 }
 
 /**********************************************************************//**
@@ -455,7 +456,7 @@ void dirty_rect(int canvas_x, int canvas_y,
 void dirty_all(void)
 {
   if (gtk_widget_get_realized(map_canvas)) {
-    gdk_window_invalidate_rect(gtk_widget_get_window(map_canvas), NULL, FALSE);
+    gtk_widget_queue_draw(map_canvas);
   }
 }
 
@@ -466,9 +467,6 @@ void dirty_all(void)
 **************************************************************************/
 void flush_dirty(void)
 {
-  if (map_canvas != NULL && gtk_widget_get_realized(map_canvas)) {
-    gdk_window_process_updates(gtk_widget_get_window(map_canvas), FALSE);
-  }
 }
 
 /**********************************************************************//**
@@ -482,7 +480,7 @@ void gui_flush(void)
 }
 
 /**********************************************************************//**
-  Update display of descriptions associated with cities on the main map.
+ Update display of descriptions associated with cities on the main map.
 **************************************************************************/
 void update_city_descriptions(void)
 {
@@ -490,9 +488,9 @@ void update_city_descriptions(void)
 }
 
 /**********************************************************************//**
-  Fill image with unit gfx
+  Fill picture with unit gfx
 **************************************************************************/
-void put_unit_image(struct unit *punit, GtkImage *p, int height)
+void put_unit_picture(struct unit *punit, GtkPicture *p, int height)
 {
   struct canvas store = FC_STATIC_CANVAS_INIT;
   int width;
@@ -507,7 +505,7 @@ void put_unit_image(struct unit *punit, GtkImage *p, int height)
 
   put_unit(punit, &store, 1.0, 0, 0);
 
-  gtk_image_set_from_surface(p, store.surface);
+  picture_set_from_surface(p, store.surface);
   cairo_surface_destroy(store.surface);
 }
 
@@ -515,11 +513,11 @@ void put_unit_image(struct unit *punit, GtkImage *p, int height)
   FIXME:
   For now only two food, two gold one shield and two masks can be drawn per
   unit, the proper way to do this is probably something like what Civ II does.
-  (One food/shield/mask drawn N times, possibly one top of itself. -- SKi 
+  (One food/shield/mask drawn N times, possibly one top of itself. -- SKi
 **************************************************************************/
-void put_unit_image_city_overlays(struct unit *punit, GtkImage *p,
-                                  int height,
-                                  int *upkeep_cost, int happy_cost)
+void put_unit_picture_city_overlays(struct unit *punit, GtkPicture *p,
+                                    int height,
+                                    int *upkeep_cost, int happy_cost)
 {
   struct canvas store = FC_STATIC_CANVAS_INIT;
   int width = tileset_full_tile_width(tileset);
@@ -532,17 +530,18 @@ void put_unit_image_city_overlays(struct unit *punit, GtkImage *p,
   put_unit_city_overlays(punit, &store, 0, tileset_unit_layout_offset_y(tileset),
                          upkeep_cost, happy_cost);
 
-  gtk_image_set_from_surface(p, store.surface);
+  picture_set_from_surface(p, store.surface);
   cairo_surface_destroy(store.surface);
 }
 
 /**********************************************************************//**
   Put overlay tile to pixmap
 **************************************************************************/
-void pixmap_put_overlay_tile(GdkWindow *pixmap, float zoom,
+void pixmap_put_overlay_tile(GdkSurface *pixmap, float zoom,
                              int canvas_x, int canvas_y,
                              struct sprite *ssprite)
 {
+#if 0
   cairo_t *cr;
   GdkDrawingContext *ctx;
 
@@ -550,13 +549,14 @@ void pixmap_put_overlay_tile(GdkWindow *pixmap, float zoom,
     return;
   }
 
-  ctx = gdk_window_begin_draw_frame(pixmap,
+  ctx = gdk_window_begin_draw_frame(pixmap, NULL,
                                     gdk_window_get_clip_region(pixmap));
   cr = gdk_drawing_context_get_cairo_context(ctx);
   cairo_scale(cr, zoom, zoom);
   cairo_set_source_surface(cr, ssprite->surface, canvas_x, canvas_y);
   cairo_paint(cr);
   gdk_window_end_draw_frame(pixmap, ctx);
+#endif
 }
 
 /**********************************************************************//**
@@ -637,14 +637,16 @@ void pixmap_put_overlay_tile_draw(struct canvas *pcanvas,
 }
 
 /**********************************************************************//**
-  Draws a cross-hair overlay on a tile
+ Draws a cross-hair overlay on a tile
 **************************************************************************/
 void put_cross_overlay_tile(struct tile *ptile)
 {
   float canvas_x, canvas_y;
 
   if (tile_to_canvas_pos(&canvas_x, &canvas_y, map_zoom, ptile)) {
-    pixmap_put_overlay_tile(gtk_widget_get_window(map_canvas), map_zoom,
+    GtkNative *nat = gtk_widget_get_native(map_canvas);
+
+    pixmap_put_overlay_tile(gtk_native_get_surface(nat), map_zoom,
 			    canvas_x / map_zoom, canvas_y / map_zoom,
 			    get_attention_crosshair_sprite(tileset));
   }
@@ -703,8 +705,10 @@ void update_map_canvas_scrollbars_size(void)
   map_hadj = gtk_adjustment_new(-1, xmin, xmax, xstep, xsize, xsize);
   map_vadj = gtk_adjustment_new(-1, ymin, ymax, ystep, ysize, ysize);
 
-  gtk_range_set_adjustment(GTK_RANGE(map_horizontal_scrollbar), map_hadj);
-  gtk_range_set_adjustment(GTK_RANGE(map_vertical_scrollbar), map_vadj);
+  gtk_scrollbar_set_adjustment(GTK_SCROLLBAR(map_horizontal_scrollbar),
+                               map_hadj);
+  gtk_scrollbar_set_adjustment(GTK_SCROLLBAR(map_vertical_scrollbar),
+                               map_vadj);
 
   g_signal_connect(map_hadj, "value_changed",
 	G_CALLBACK(scrollbar_jump_callback),
@@ -747,11 +751,7 @@ void scrollbar_jump_callback(GtkAdjustment *adj, gpointer hscrollbar)
 **************************************************************************/
 void draw_selection_rectangle(int canvas_x, int canvas_y, int w, int h)
 {
-  double dashes[2] = {4.0, 4.0};
   struct color *pcolor;
-  cairo_t *cr;
-  GdkDrawingContext *ctx;
-  GdkWindow *wndw;
 
   if (w == 0 || h == 0) {
     return;
@@ -762,17 +762,14 @@ void draw_selection_rectangle(int canvas_x, int canvas_y, int w, int h)
     return;
   }
 
-  wndw = gtk_widget_get_window(map_canvas);
-  ctx = gdk_window_begin_draw_frame(wndw,
-                                    gdk_window_get_clip_region(wndw));
-  cr = gdk_drawing_context_get_cairo_context(ctx);
-  gdk_cairo_set_source_rgba(cr, &pcolor->color);
-  cairo_set_line_width(cr, 2.0);
-  cairo_set_dash(cr, dashes, 2, 0);
-  cairo_set_operator(cr, CAIRO_OPERATOR_DIFFERENCE);
-  cairo_rectangle(cr, canvas_x, canvas_y, w, h);
-  cairo_stroke(cr);
-  gdk_window_end_draw_frame(wndw, ctx);
+  canvas_put_line(mapview.store, pcolor, LINE_SELECT_RECT,
+                  canvas_x, canvas_y, w, 0);
+  canvas_put_line(mapview.store, pcolor, LINE_SELECT_RECT,
+                  canvas_x, canvas_y, 0, h);
+  canvas_put_line(mapview.store, pcolor, LINE_SELECT_RECT,
+                  canvas_x, canvas_y + h, w, 0);
+  canvas_put_line(mapview.store, pcolor, LINE_SELECT_RECT,
+                  canvas_x + w, canvas_y, 0, h);
 }
 
 /**********************************************************************//**
@@ -789,11 +786,8 @@ void tileset_changed(void)
   /* keep the icon of the executable on Windows (see PR#36491) */
 #ifndef FREECIV_MSWINDOWS
   {
-    GdkPixbuf *pixbuf = sprite_get_pixbuf(get_icon_sprite(tileset, ICON_FREECIV));
-
     /* Only call this after tileset_load_tiles is called. */
-    gtk_window_set_icon(GTK_WINDOW(toplevel), pixbuf);
-    g_object_unref(pixbuf);
+    gtk_window_set_icon_name(GTK_WINDOW(toplevel), "freeciv");
   }
 #endif /* FREECIV_MSWINDOWS */
 }
