@@ -36,6 +36,7 @@
 
 #include "optiondlg.h"
 
+static int opt_dlog_width = -1, opt_dlog_height = 480;
 
 /* The option dialog data. */
 struct option_dialog {
@@ -132,6 +133,11 @@ static void option_dialog_destroy_callback(GtkWidget *object, gpointer data)
 {
   struct option_dialog *pdialog = (struct option_dialog *) data;
 
+  /* Save size of the dialog. */
+  gtk_window_get_default_size(GTK_WINDOW(object),
+                              &opt_dlog_width,
+                              &opt_dlog_height);
+
   if (NULL != pdialog->shell) {
     /* Mark as destroyed, see also option_dialog_destroy(). */
     pdialog->shell = NULL;
@@ -307,15 +313,17 @@ static void option_color_set_button_color(GtkButton *button,
       cairo_surface_t *surface = cairo_image_surface_create(
           CAIRO_FORMAT_RGB24, 16, 16);
       cairo_t *cr = cairo_create(surface);
+
       gdk_cairo_set_source_rgba(cr, current_color);
       cairo_paint(cr);
       cairo_destroy(cr);
       pixbuf = gdk_pixbuf_get_from_surface(surface, 0, 0, 16, 16);
       cairo_surface_destroy(surface);
     }
+
     child = gtk_image_new_from_pixbuf(pixbuf);
     gtk_button_set_child(GTK_BUTTON(button), child);
-    gtk_widget_show(child);
+    gtk_widget_set_visible(child, TRUE);
     g_object_unref(G_OBJECT(pixbuf));
   }
 }
@@ -363,11 +371,11 @@ static void option_color_select_callback(GtkButton *button, gpointer data)
   g_object_set_data(G_OBJECT(dialog), "chooser", chooser);
   gtk_box_insert_child_after(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
                              chooser, NULL);
-  if (current_color) {
+  if (current_color != NULL) {
     gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(chooser), current_color);
   }
 
-  gtk_widget_show(dialog);
+  gtk_widget_set_visible(dialog, TRUE);
 }
 
 /************************************************************************//**
@@ -402,7 +410,9 @@ option_dialog_new(const char *name, const struct option_set *poptset)
 
   /* Shell */
   setup_dialog(pdialog->shell, toplevel);
-  gtk_window_set_default_size(GTK_WINDOW(pdialog->shell), -1, 480);
+  gtk_window_set_default_size(GTK_WINDOW(pdialog->shell),
+                              opt_dlog_width,
+                              opt_dlog_height);
   g_signal_connect(pdialog->shell, "response",
                    G_CALLBACK(option_dialog_reponse_callback), pdialog);
   g_signal_connect(pdialog->shell, "destroy",
@@ -419,7 +429,7 @@ option_dialog_new(const char *name, const struct option_set *poptset)
   option_dialog_reorder_notebook(pdialog);
 
   /* Show the widgets. */
-  gtk_widget_show(pdialog->shell);
+  gtk_widget_set_visible(pdialog->shell, TRUE);
 
   return pdialog;
 }
@@ -537,9 +547,10 @@ static void option_dialog_option_add(struct option_dialog *pdialog,
     gtk_widget_set_margin_start(pdialog->vboxes[category], 8);
     gtk_widget_set_margin_top(pdialog->vboxes[category], 8);
     gtk_widget_set_hexpand(pdialog->vboxes[category], TRUE);
-    gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), pdialog->vboxes[category]);
+    gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw),
+                                  pdialog->vboxes[category]);
 
-    gtk_widget_show(sw);
+    gtk_widget_set_visible(sw, TRUE);
   }
   pdialog->box_children[category]++;
 
@@ -688,7 +699,7 @@ static void option_dialog_option_add(struct option_dialog *pdialog,
     gtk_grid_attach(GTK_GRID(main_hbox), w, main_col++, 0, 1, 1);
   }
 
-  gtk_widget_show(main_hbox);
+  gtk_widget_set_visible(main_hbox, TRUE);
 
   /* Set as current value. */
   option_dialog_option_refresh(poption);
