@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,8 +33,12 @@ GtkWidget *create_worklist(void);
 void reset_city_worklist(GtkWidget *editor, struct city *pcity);
 void refresh_worklist(GtkWidget *editor);
 
-void add_worklist_dnd_target(GtkWidget *w);
+void add_worklist_dnd_target(GtkWidget *w,
+                             gboolean (drag_drop_cb)
+                               (GtkDropTarget *target, const GValue *value,
+                                double x, double y, gpointer data),
+                             gpointer data);
 
 void blank_max_unit_size(void);
 
-#endif				/* FC__WLDLG_H */
+#endif /* FC__WLDLG_H */
