@@ -795,7 +795,6 @@ void city_widget::invert_selection()
   struct city *pcity;
   QVariant qvar;
 
-
   for (int j = 0; j < filter_model->rowCount(); j++) {
     i = filter_model->index(j, 0);
     qvar = i.data(Qt::UserRole);
@@ -923,8 +922,7 @@ void city_widget::select_building_something()
     if (NULL != pcity) {
       if (str == "impr" && VUT_IMPROVEMENT == pcity->production.kind
           && !is_wonder(pcity->production.value.building)
-          && !improvement_has_flag(pcity->production.value.building,
-                                  IF_GOLD)) {
+          && !is_convert_improvement(pcity->production.value.building)) {
         selection.append(QItemSelectionRange(i));
       } else if (str == "unit" && VUT_UTYPE == pcity->production.kind) {
         selection.append(QItemSelectionRange(i));
@@ -1359,7 +1357,7 @@ void popdown_city_report()
 ***************************************************************************/
 void hilite_cities_from_canvas(void)
 {
-  /* PORTME */
+  // PORTME
 }
 
 /***********************************************************************//**
@@ -1367,5 +1365,5 @@ void hilite_cities_from_canvas(void)
 ***************************************************************************/
 void toggle_city_hilite(struct city *pcity, bool on_off)
 {
-  /* PORTME */
+  // PORTME
 }
