@@ -33,11 +33,13 @@
 
 // common
 #include "game.h"
+#include "rgbcolor.h"
 #include "version.h"
 
 // client
 #include "client_main.h"
 #include "connectdlg_common.h"
+#include "svgflag.h"
 
 // gui-qt
 #include "colors.h"
@@ -136,7 +138,7 @@ void update_start_page(void)
 void fc_client::create_main_page(void)
 {
   QPixmap main_graphics(tileset_main_intro_filename(tileset));
-  QLabel* free_main_pic = new QLabel;
+  QLabel *free_main_pic = new QLabel;
   QPainter painter(&main_graphics);
   QStringList buttons_names;
   int buttons_nr;
@@ -157,7 +159,7 @@ void fc_client::create_main_page(void)
   rev_ver = fc_git_revision();
 
   if (rev_ver == NULL) {
-    /* TRANS: "version 3.1.0, Qt5 client" */
+    // TRANS: "version 3.1.0, Qt5 client"
 #ifdef FC_QT5_MODE
     fc_snprintf(msgbuf, sizeof(msgbuf), _("%s%s, Qt5 client"),
                 word_version(), VERSION_STRING);
@@ -172,7 +174,7 @@ void fc_client::create_main_page(void)
                      main_graphics.height() - fm.descent() - fm.height() * 2,
                      msgbuf);
 
-    /* TRANS: "commit: [modified] <git commit id>" */
+    // TRANS: "commit: [modified] <git commit id>"
     fc_snprintf(msgbuf, sizeof(msgbuf), _("commit: %s"), rev_ver);
     painter.drawText(10,
                      main_graphics.height() - fm.descent() - fm.height(),
@@ -967,7 +969,7 @@ void fc_client::update_server_list(enum server_scan_type sstype,
     row++;
   } server_list_iterate_end;
 
-  /* Remove unneeded rows, if there are any */
+  // Remove unneeded rows, if there are any
   while (old_row_count - row > 0) {
     sel->removeRow(old_row_count - 1);
     old_row_count--;
@@ -1057,11 +1059,11 @@ bool fc_client::check_server_scan(server_scan *scan_data)
 
     type = server_scan_get_type(scan);
     srvrs = server_scan_get_list(scan);
-    fc_allocate_mutex(&srvrs->mutex);
+    fc_mutex_allocate(&srvrs->mutex);
     holding_srv_list_mutex = true;
     update_server_list(type, srvrs->servers);
     holding_srv_list_mutex = false;
-    fc_release_mutex(&srvrs->mutex);
+    fc_mutex_release(&srvrs->mutex);
   }
 
   if (stat == SCAN_STATUS_ERROR || stat == SCAN_STATUS_DONE) {
@@ -1094,15 +1096,15 @@ void fc_client::slot_meta_scan()
 }
 
 /**********************************************************************//**
-  Spawn a server, if there isn't one, using the default settings.
+  spawn a server, if there isn't one, using the default settings.
 **************************************************************************/
 void fc_client::start_new_game()
 {
   if (!is_server_running()) {
     client_start_server();
 
-    /* Saved settings are sent in client/options.c
-     * resend_desired_settable_options() */
+    // Saved settings are sent in client/options.c
+    // resend_desired_settable_options()
   }
 }
 
@@ -1186,13 +1188,13 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
 
     srvrs = server_scan_get_list(meta_scan);
     if (!holding_srv_list_mutex) {
-      fc_allocate_mutex(&srvrs->mutex);
+      fc_mutex_allocate(&srvrs->mutex);
     }
     if (srvrs->servers) {
       pserver = server_list_get(srvrs->servers, index.row());
     }
     if (!holding_srv_list_mutex) {
-      fc_release_mutex(&srvrs->mutex);
+      fc_mutex_release(&srvrs->mutex);
     }
     if (!pserver || !pserver->players) {
       return;
@@ -1281,13 +1283,13 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
           }
         }
       }
-      /* Break case (and return) if no human player found */
+      // Break case (and return) if no human player found
       if (pl_str == nullptr) {
         load_save_text->setText(final_str);
         break;
       }
 
-      /* Information about human player */
+      // Information about human player
       pl_bytes = pl_str.toUtf8();
       if ((sf = secfile_load_section(fn_bytes.data(),
                                      pl_bytes.data(), true))) {
@@ -1328,17 +1330,18 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
           str_pixmap = str_pixmap + line;
         }
 
-        /* Reset terrain information */
+        // Reset terrain information
         terrain_type_iterate(pterr) {
           pterr->identifier_load = '\0';
         } terrain_type_iterate_end;
 
-        /* Load possible terrains and their identifiers (chars) */
+        // Load possible terrains and their identifiers (chars)
         if ((sf = secfile_load_section(fn_bytes.data(),
-                                       "savefile", true)))
+                                       "savefile", true))) {
           while ((terr_name = secfile_lookup_str_default(sf, NULL,
                                  "savefile.terrident%d.name", ii)) != NULL) {
             struct terrain *pterr = terrain_by_rule_name(terr_name);
+
             if (pterr != NULL) {
               const char *iptr = secfile_lookup_str_default(sf, NULL,
                                       "savefile.terrident%d.identifier", ii);
@@ -1346,8 +1349,9 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
             }
             ii++;
           }
+        }
 
-        /* Create image */
+        // Create image
         QImage img(nat_x, nat_y, QImage::Format_ARGB32_Premultiplied);
 
         img.fill(Qt::black);
@@ -1379,10 +1383,10 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
 
         load_pix->setFixedSize(pm.width(),
                                pm.height());
-#else  /* FC_QT5_MODE */
+#else  // FC_QT5_MODE
         load_pix->setFixedSize(load_pix->pixmap()->width(),
                                load_pix->pixmap()->height());
-#endif /* FC_QT5_MODE */
+#endif // FC_QT5_MODE
 
         if ((sf = secfile_load_section(fn_bytes.data(),
                                        "research", TRUE))) {
@@ -1511,7 +1515,7 @@ void fc_client::update_scenarios_page(void)
             version = QString("%1.%2").arg(maj).arg(min);
           }
         } else {
-          /* TRANS: Unknown scenario format */
+          // TRANS: Unknown scenario format
           version = QString(_("pre-2.6"));
         }
 
@@ -1571,7 +1575,6 @@ void fc_client::update_scenarios_page(void)
   scenarios_load->update();
 }
 
-
 /**********************************************************************//**
   Configure the dialog depending on what type of authentication request the
   server is making.
@@ -1643,7 +1646,7 @@ void fc_client::slot_connect()
     sz_strlcpy(reply.password,
                ba_bytes.data());
 
-    if (strncmp(reply.password, fc_password, MAX_LEN_NAME) == 0) {
+    if (!fc_strncmp(reply.password, fc_password, MAX_LEN_NAME)) {
       fc_password[0] = '\0';
       send_packet_authentication_reply(&client.conn, &reply);
       set_connection_state(WAITING_TYPE);
@@ -1688,6 +1691,8 @@ void fc_client::update_start_page()
   QTreeWidgetItem *global_item;
   QTreeWidgetItem *detach_item;
   int conn_id;
+  bool svg = is_svg_flag_enabled();
+
   conn_num = conn_list_size(game.est_connections);
 
   if (conn_num == 0) {
@@ -1706,9 +1711,7 @@ void fc_client::update_start_page()
     i++;
   } players_iterate_end;
   gui()->pr_options->set_aifill(i);
-  /**
-   * Inserts playing players, observing custom players, and AI)
-   */
+  // Inserts playing players, observing custom players, and AI)
 
   players_iterate(pplayer) {
     host = "";
@@ -1785,7 +1788,11 @@ void fc_client::update_start_page()
           }
           psprite = get_nation_flag_sprite(tileset, pplayer->nation);
           pixmap = psprite->pm;
-          item->setData(col, Qt::DecorationRole, *pixmap);
+          if (svg) {
+            item->setData(col, Qt::DecorationRole, (*pixmap).scaledToHeight(50));
+          } else {
+            item->setData(col, Qt::DecorationRole, *pixmap);
+          }
           break;
         case 4:
           if (!player_has_color(pplayer)) {
@@ -1816,9 +1823,7 @@ void fc_client::update_start_page()
         }
       }
 
-      /**
-       * find any custom observers
-       */
+      // Find any custom observers
       recursed_items.clear();
       conn_list_iterate(pplayer->connections, pconn) {
         if (pconn->id == conn_id) {
@@ -1838,9 +1843,7 @@ void fc_client::update_start_page()
   player_item->addChildren(items);
   start_players_tree->insertTopLevelItem(0, player_item);
 
-  /**
-   * Insert global observers
-   */
+  // Insert global observers
   items.clear();
   global_item = new QTreeWidgetItem();
   global_item->setText(0, _("Global observers"));
@@ -1874,9 +1877,7 @@ void fc_client::update_start_page()
   start_players_tree->insertTopLevelItem(1, global_item);
   items.clear();
 
-  /**
-  * Insert detached
-  */
+  // Insert detached
   detach_item = new QTreeWidgetItem();
   detach_item->setText(0, _("Detached"));
   qvar2 = 0;
@@ -1907,14 +1908,14 @@ void fc_client::update_buttons()
   bool sensitive;
   QString text;
 
-  /* Observe button */
+  // Observe button
   if (client_is_observer() || client_is_global_observer()) {
     obs_button->setText(_("Don't Observe"));
   } else {
     obs_button->setText(_("Observe"));
   }
 
-  /* Ready button */
+  // Ready button
   if (can_client_control()) {
     sensitive = client_player()->is_alive;
     if (client_player()->is_ready) {
@@ -1955,7 +1956,7 @@ void fc_client::update_buttons()
   start_button->setEnabled(sensitive);
   start_button->setText(text);
 
-  /* Nation button */
+  // Nation button
   sensitive = game.info.is_new_game && can_client_control();
   nation_button->setEnabled(sensitive);
 
@@ -2035,7 +2036,7 @@ void fc_client::start_page_menu(QPoint pos)
       if (can_conn_edit_players_nation(&client.conn, pplayer)) {
         str = QString(_("Pick nation"));
         action = new QAction(str, start_players_tree);
-        str = "PICK:" + QString(player_name(pplayer));  /* PICK is a key */
+        str = "PICK:" + QString(player_name(pplayer));  // PICK is a key
         QObject::connect(action, &QAction::triggered, [this,str]() {
           send_fake_chat_message(str);
         });
@@ -2043,9 +2044,7 @@ void fc_client::start_page_menu(QPoint pos)
       }
 
       if (is_ai(pplayer)) {
-        /**
-         * Set AI difficulty submenu
-         */
+        // Set AI difficulty submenu
         if (ALLOW_CTRL <= client.conn.access_level) {
           page_submenu_AI->setTitle(_("Set difficulty"));
           page_menu->addMenu(page_submenu_AI);
@@ -2065,9 +2064,7 @@ void fc_client::start_page_menu(QPoint pos)
         }
       }
 
-      /**
-       * Put to Team X submenu
-       */
+      // Put to Team X submenu
       if (game.info.is_new_game) {
         page_menu->addMenu(page_submenu_team);
         page_submenu_team->setTitle(_("Put on team"));
