@@ -60,11 +60,11 @@ const char **gfx_fileextensions(void)
 }
 
 /************************************************************************//**
-  Load the given graphics file into a sprite.  This function loads an
+  Load the given graphics file into a sprite. This function loads an
   entire image file, which may later be broken up into individual sprites
-  with crop_sprite.
+  with crop_sprite().
 ****************************************************************************/
-struct sprite *qtg_load_gfxfile(const char *filename)
+struct sprite *qtg_load_gfxfile(const char *filename, bool svgflag)
 {
   sprite *entire = new sprite;
   QPixmap *pm = new QPixmap;
@@ -198,7 +198,7 @@ struct sprite *qtg_load_gfxnumber(int num)
   QString ns;
   int w, h;
   QPixmap *pm;
-  /* FIXME: This should not depend on city_productions font setting */
+  // FIXME: This should not depend on city_productions font setting
   QFont *qf = fc_font::instance()->get_font(fonts::city_productions);
 
   if (gui()->map_scale != 1.0f && gui()->map_font_scale) {
