@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,4 +25,4 @@ struct sprite
   QPixmap *pm;
 };
 
-#endif /* FC__SPRITE_H */
+#endif // FC__SPRITE_H
