@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,4 +18,4 @@ extern "C" {
 #include "wldlg_g.h"
 }
 
-#endif /* FC__WLDLG_H */
+#endif // FC__WLDLG_H
