@@ -273,13 +273,13 @@ void popup_connection_dialog(bool lan_scan)
 
   /* Copy list */
   server_list = server_list_new();
-  fc_allocate_mutex(&srvrs->mutex);
+  fc_mutex_allocate(&srvrs->mutex);
   server_list_iterate(srvrs->servers, pserver) {
     server_list_append(server_list, pserver);
   } server_list_iterate_end;
-  fc_release_mutex(&srvrs->mutex);
+  fc_mutex_release(&srvrs->mutex);
 
-  /* clear label */
+  /* Clear label */
   popdown_window_group_dialog(new_widget, label_window);
 
   meswin_dialog_popup(TRUE);
@@ -771,7 +771,7 @@ static int cancel_passwd_callback(struct widget *pwidget)
 {
   memset(fc_password, 0, MAX_LEN_NAME);
   fc_password[0] = '\0';
-  disconnect_from_server();
+  disconnect_from_server(TRUE);
 
   return cancel_connect_dlg_callback(pwidget);
 }
@@ -927,16 +927,17 @@ static int convert_second_passwd_callback(struct widget *pwidget)
 {
   if (PRESSED_EVENT(main_data.event)) {
     if (pwidget->string_utf8->text != NULL
-        && !strncmp(fc_password, pwidget->string_utf8->text, MAX_LEN_NAME)) {
-      set_wstate(pwidget->prev, FC_WS_NORMAL); /* next button */
+        && !fc_strncmp(fc_password, pwidget->string_utf8->text,
+                       MAX_LEN_NAME)) {
+      set_wstate(pwidget->prev, FC_WS_NORMAL); /* Next button */
       widget_redraw(pwidget->prev);
       widget_flush(pwidget->prev);
     } else {
       memset(fc_password, 0, MAX_LEN_NAME);
       fc_password[0] = '\0';
 
-      FC_FREE(pwidget->next->string_utf8->text);/* first edit */
-      FC_FREE(pwidget->string_utf8->text); /* second edit */
+      FC_FREE(pwidget->next->string_utf8->text);/* First edit */
+      FC_FREE(pwidget->string_utf8->text); /* Second edit */
 
       popup_new_user_passwd_dialog(_("Passwords don't match, enter password."));
     }
