@@ -51,7 +51,7 @@
 #include "diplodlg.h"
 
 struct diplomacy_dialog {
-  struct Treaty treaty;
+  struct Treaty *treaty;
   struct advanced_dialog *pdialog;
   struct advanced_dialog *pwants;
   struct advanced_dialog *poffers;
@@ -70,7 +70,8 @@ static struct dialog_list *dialog_list;
 static void update_diplomacy_dialog(struct diplomacy_dialog *pdialog);
 static void update_acceptance_icons(struct diplomacy_dialog *pdialog);
 static void update_clauses_list(struct diplomacy_dialog *pdialog);
-static void remove_clause_widget_from_list(int counterpart, int giver,
+static void remove_clause_widget_from_list(struct player *they,
+                                           struct player *giver,
                                            enum clause_type type, int value);
 static void popdown_diplomacy_dialog(struct diplomacy_dialog *pdialog);
 static void popdown_diplomacy_dialogs(void);
@@ -95,14 +96,13 @@ void diplomacy_dialog_done(void)
 /**********************************************************************//**
   Get diplomacy dialog between client user and other player.
 **************************************************************************/
-static struct diplomacy_dialog *get_diplomacy_dialog(int other_player_id)
+static struct diplomacy_dialog *get_diplomacy_dialog(struct player *they)
 {
-  struct player *plr0 = client.conn.playing;
-  struct player *plr1 = player_by_number(other_player_id);
+  struct player *we = client_player();
 
   dialog_list_iterate(dialog_list, pdialog) {
-    if ((pdialog->treaty.plr0 == plr0 && pdialog->treaty.plr1 == plr1)
-        || (pdialog->treaty.plr0 == plr1 && pdialog->treaty.plr1 == plr0)) {
+    if ((pdialog->treaty->plr0 == we && pdialog->treaty->plr1 == they)
+        || (pdialog->treaty->plr0 == they && pdialog->treaty->plr1 == we)) {
       return pdialog;
     }
   } dialog_list_iterate_end;
@@ -114,17 +114,15 @@ static struct diplomacy_dialog *get_diplomacy_dialog(int other_player_id)
   Update a player's acceptance status of a treaty (traditionally shown
   with the thumbs-up/thumbs-down sprite).
 **************************************************************************/
-void handle_diplomacy_accept_treaty(int counterpart, bool I_accepted,
-                                    bool other_accepted)
+void gui_recv_accept_treaty(struct Treaty *ptreaty, struct player *they)
 {
-  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(counterpart);
+  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(they);
 
   if (!pdialog) {
     return;
   }
 
-  pdialog->treaty.accept0 = I_accepted;
-  pdialog->treaty.accept1 = other_accepted;
+  fc_assert(pdialog->treaty == ptreaty);
 
   update_acceptance_icons(pdialog);
 }
@@ -133,9 +131,10 @@ void handle_diplomacy_accept_treaty(int counterpart, bool I_accepted,
   Update the diplomacy dialog when the meeting is canceled (the dialog
   should be closed).
 **************************************************************************/
-void handle_diplomacy_cancel_meeting(int counterpart, int initiated_from)
+void gui_recv_cancel_meeting(struct Treaty *ptreaty, struct player *they,
+                             struct player *initiator)
 {
-  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(counterpart);
+  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(they);
 
   if (pdialog != NULL) {
     dialog_list_remove(dialog_list, pdialog);
@@ -154,12 +153,12 @@ static int remove_clause_callback(struct widget *pwidget)
   if (PRESSED_EVENT(main_data.event)) {
     struct diplomacy_dialog *pdialog;
 
-    if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-      pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
     }
 
     dsend_packet_diplomacy_remove_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              (enum clause_type) ((pwidget->data.
                                              cont->value >> 16) & 0xFFFF),
@@ -170,26 +169,38 @@ static int remove_clause_callback(struct widget *pwidget)
 }
 
 /**********************************************************************//**
-  Update the diplomacy dialog by adding a clause.
+  Prepare to clause creation or removal.
 **************************************************************************/
-void handle_diplomacy_create_clause(int counterpart, int giver,
-                                    enum clause_type type, int value)
+void gui_prepare_clause_updt(struct Treaty *ptreaty, struct player *they)
 {
-  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(counterpart);
+  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(they);
 
   if (!pdialog) {
     return;
   }
 
-  clause_list_iterate(pdialog->treaty.clauses, pclause) {
-    remove_clause_widget_from_list(player_number(pdialog->treaty.plr1),
-                                   player_number(pclause->from),
+  fc_assert(pdialog->treaty == ptreaty);
+
+  clause_list_iterate(pdialog->treaty->clauses, pclause) {
+    remove_clause_widget_from_list(pdialog->treaty->plr1,
+                                   pclause->from,
                                    pclause->type,
                                    pclause->value);
   } clause_list_iterate_end;
+}
 
-  add_clause(&pdialog->treaty, player_by_number(giver), type, value,
-             client_player());
+/**********************************************************************//**
+  Update the diplomacy dialog by adding a clause.
+**************************************************************************/
+void gui_recv_create_clause(struct Treaty *ptreaty, struct player *they)
+{
+  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(they);
+
+  if (!pdialog) {
+    return;
+  }
+
+  fc_assert(pdialog->treaty == ptreaty);
 
   update_clauses_list(pdialog);
   update_acceptance_icons(pdialog);
@@ -198,24 +209,14 @@ void handle_diplomacy_create_clause(int counterpart, int giver,
 /**********************************************************************//**
   Update the diplomacy dialog by removing a clause.
 **************************************************************************/
-void handle_diplomacy_remove_clause(int counterpart, int giver,
-                                    enum clause_type type, int value)
+void gui_recv_remove_clause(struct Treaty *ptreaty, struct player *they)
 {
-  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(counterpart);
+  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(they);
 
   if (!pdialog) {
     return;
   }
 
-  clause_list_iterate(pdialog->treaty.clauses, pclause) {
-    remove_clause_widget_from_list(player_number(pdialog->treaty.plr1),
-                                   player_number(pclause->from),
-                                   pclause->type,
-                                   pclause->value);
-  } clause_list_iterate_end;
-
-  remove_clause(&pdialog->treaty, player_by_number(giver), type, value);
-
   update_clauses_list(pdialog);
   update_acceptance_icons(pdialog);
 }
@@ -259,8 +260,8 @@ static int pact_callback(struct widget *pwidget)
     int clause_type;
     struct diplomacy_dialog *pdialog;
 
-    if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-      pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
     }
 
     switch (MAX_ID - pwidget->id) {
@@ -276,7 +277,7 @@ static int pact_callback(struct widget *pwidget)
     }
 
     dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              clause_type, 0);
   }
@@ -292,12 +293,12 @@ static int vision_callback(struct widget *pwidget)
   if (PRESSED_EVENT(main_data.event)) {
     struct diplomacy_dialog *pdialog;
 
-    if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-      pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
     }
   
     dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              CLAUSE_VISION, 0);
   }
@@ -306,19 +307,19 @@ static int vision_callback(struct widget *pwidget)
 }
 
 /**********************************************************************//**
-  User interacted with embassy -widget.
+  User interacted with Embassy -widget.
 **************************************************************************/
 static int embassy_callback(struct widget *pwidget)
 {
   if (PRESSED_EVENT(main_data.event)) {
     struct diplomacy_dialog *pdialog;
 
-    if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-      pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
     }
 
     dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              CLAUSE_EMBASSY, 0);
   }
@@ -326,6 +327,27 @@ static int embassy_callback(struct widget *pwidget)
   return -1;
 }
 
+/**********************************************************************//**
+  User interacted with Shared Tiles -widget.
+**************************************************************************/
+static int shared_tiles_callback(struct widget *pwidget)
+{
+  if (PRESSED_EVENT(main_data.event)) {
+    struct diplomacy_dialog *pdialog;
+
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
+    }
+
+    dsend_packet_diplomacy_create_clause_req(&client.conn,
+                                             player_number(pdialog->treaty->plr1),
+                                             pwidget->data.cont->id0,
+                                             CLAUSE_SHARED_TILES, 0);
+  }
+
+  return -1;
+}
+
 /**********************************************************************//**
   User interacted with map -widget.
 **************************************************************************/
@@ -335,8 +357,8 @@ static int maps_callback(struct widget *pwidget)
     int clause_type;
     struct diplomacy_dialog *pdialog;
 
-    if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-      pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
     }
 
     switch (MAX_ID - pwidget->id) {
@@ -349,7 +371,7 @@ static int maps_callback(struct widget *pwidget)
     }
 
     dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              clause_type, 0);
   }
@@ -365,12 +387,12 @@ static int techs_callback(struct widget *pwidget)
   if (PRESSED_EVENT(main_data.event)) {
     struct diplomacy_dialog *pdialog;
 
-    if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-      pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
     }
 
     dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              CLAUSE_ADVANCE,
                                              (MAX_ID - pwidget->id));
@@ -387,15 +409,15 @@ static int gold_callback(struct widget *pwidget)
   int amount;
   struct diplomacy_dialog *pdialog;
 
-  if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-    pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+  if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+    pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
   }
 
   if (pwidget->string_utf8->text != NULL) {
     sscanf(pwidget->string_utf8->text, "%d", &amount);
 
     if (amount > pwidget->data.cont->value) {
-      /* max player gold */
+      /* Max player gold */
       amount = pwidget->data.cont->value;
     }
 
@@ -405,10 +427,9 @@ static int gold_callback(struct widget *pwidget)
 
   if (amount > 0) {
     dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              CLAUSE_GOLD, amount);
-      
   } else {
     output_window_append(ftc_client,
                          _("Invalid amount of gold specified."));
@@ -431,12 +452,12 @@ static int cities_callback(struct widget *pwidget)
   if (PRESSED_EVENT(main_data.event)) {
     struct diplomacy_dialog *pdialog;
 
-    if (!(pdialog = get_diplomacy_dialog(pwidget->data.cont->id1))) {
-      pdialog = get_diplomacy_dialog(pwidget->data.cont->id0);
+    if (!(pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id1)))) {
+      pdialog = get_diplomacy_dialog(player_by_number(pwidget->data.cont->id0));
     }
 
     dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                             player_number(pdialog->treaty.plr1),
+                                             player_number(pdialog->treaty->plr1),
                                              pwidget->data.cont->id0,
                                              CLAUSE_CITY,
                                              (MAX_ID - pwidget->id));
@@ -652,7 +673,23 @@ static struct advanced_dialog *popup_diplomatic_objects(struct player *pplayer0,
     count++;
   }
 
+  if (clause_enabled(CLAUSE_SHARED_TILES)) {
+    buf = create_iconlabel_from_chars_fonto(NULL, pwindow->dst,
+                                            _("Share tiles"), FONTO_ATTENTION,
+                                            (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
+    buf->string_utf8->fgcol
+      = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+    width = MAX(width, buf->size.w);
+    height = MAX(height, buf->size.h);
+    buf->action = shared_tiles_callback;
+    buf->data.cont = cont;
+    set_wstate(buf, FC_WS_NORMAL);
+    add_to_gui_list(ID_LABEL, buf);
+    count++;
+  }
+
   /* ---------------------------- */
+
   if (clause_enabled(CLAUSE_GOLD) && pplayer0->economic.gold > 0) {
     cont->value = pplayer0->economic.gold;
 
@@ -678,6 +715,7 @@ static struct advanced_dialog *popup_diplomatic_objects(struct player *pplayer0,
     add_to_gui_list(ID_LABEL, buf);
     count++;
   }
+
   /* ---------------------------- */
 
   /* Trading: advances */
@@ -685,8 +723,9 @@ static struct advanced_dialog *popup_diplomatic_objects(struct player *pplayer0,
     const struct research *presearch0 = research_get(pplayer0);
     const struct research *presearch1 = research_get(pplayer1);
     int flag = A_NONE;
+    Tech_type_id ac = advance_count();
 
-    advance_index_iterate(A_FIRST, i) {
+    advance_index_iterate_max(A_FIRST, i, ac) {
       if (research_invention_state(presearch0, i) == TECH_KNOWN
           && research_invention_gettable(presearch1, i,
                                          game.info.tech_trade_allow_holes)
@@ -722,10 +761,10 @@ static struct advanced_dialog *popup_diplomatic_objects(struct player *pplayer0,
         flag = ++i;
         break;
       }
-    } advance_index_iterate_end;
+    } advance_index_iterate_max_end;
 
     if (flag > A_NONE) {
-      advance_index_iterate(flag, i) {
+      advance_index_iterate_max(flag, i, ac) {
         if (research_invention_state(presearch0, i) == TECH_KNOWN
             && research_invention_gettable(presearch1, i,
                                            game.info.tech_trade_allow_holes)
@@ -750,7 +789,7 @@ static struct advanced_dialog *popup_diplomatic_objects(struct player *pplayer0,
           count++;
         }
       }
-    } advance_index_iterate_end;
+    } advance_index_iterate_max_end;
   }  /* Advances */
 
   /* Trading: cities */
@@ -871,12 +910,13 @@ static struct advanced_dialog *popup_diplomatic_objects(struct player *pplayer0,
 /**********************************************************************//**
   Open new diplomacy dialog between players.
 **************************************************************************/
-static struct diplomacy_dialog *create_diplomacy_dialog(struct player *plr0, 
+static struct diplomacy_dialog *create_diplomacy_dialog(struct Treaty *ptreaty,
+                                                        struct player *plr0,
                                                         struct player *plr1)
 {
   struct diplomacy_dialog *pdialog = fc_calloc(1, sizeof(struct diplomacy_dialog));
 
-  init_treaty(&pdialog->treaty, plr0, plr1);
+  pdialog->treaty = ptreaty;
 
   pdialog->pdialog = fc_calloc(1, sizeof(struct advanced_dialog));
 
@@ -916,8 +956,8 @@ static void update_diplomacy_dialog(struct diplomacy_dialog *pdialog)
                                   pdialog->pdialog->end_widget_list);
     }
 
-    pplayer0 = pdialog->treaty.plr0;
-    pplayer1 = pdialog->treaty.plr1;
+    pplayer0 = pdialog->treaty->plr0;
+    pplayer1 = pdialog->treaty->plr1;
 
     cont->id0 = player_number(pplayer0);
     cont->id1 = player_number(pplayer1);
@@ -1075,7 +1115,7 @@ static void update_acceptance_icons(struct diplomacy_dialog *pdialog)
   /* updates your own acceptance status */
   label = pdialog->pdialog->end_widget_list->prev;
 
-  label->private_data.cbox->state = pdialog->treaty.accept0;
+  label->private_data.cbox->state = pdialog->treaty->accept0;
   if (label->private_data.cbox->state) {
     thm = label->private_data.cbox->true_theme;
   } else {
@@ -1094,7 +1134,7 @@ static void update_acceptance_icons(struct diplomacy_dialog *pdialog)
   /* updates other player's acceptance status */
   label = pdialog->pdialog->end_widget_list->prev->prev;
 
-  label->private_data.cbox->state = pdialog->treaty.accept1;
+  label->private_data.cbox->state = pdialog->treaty->accept1;
   if (label->private_data.cbox->state) {
     thm = label->private_data.cbox->true_theme;
   } else {
@@ -1121,20 +1161,20 @@ static void update_clauses_list(struct diplomacy_dialog *pdialog)
   bool redraw_all, scroll = (pdialog->pdialog->active_widget_list != NULL);
   int len = pdialog->pdialog->scroll->up_left_button->size.w;
 
-  clause_list_iterate(pdialog->treaty.clauses, pclause) {
+  clause_list_iterate(pdialog->treaty->clauses, pclause) {
     client_diplomacy_clause_string(cbuf, sizeof(cbuf), pclause);
 
     pstr = create_utf8_from_char_fonto(cbuf, FONTO_ATTENTION);
     pbuf = create_iconlabel(NULL, pwindow->dst, pstr,
      (WF_FREE_DATA|WF_DRAW_TEXT_LABEL_WITH_SPACE|WF_RESTORE_BACKGROUND));
 
-    if (pclause->from != client.conn.playing) {
+    if (pclause->from != client_player()) {
        pbuf->string_utf8->style |= SF_CENTER_RIGHT;
     }
 
     pbuf->data.cont = fc_calloc(1, sizeof(struct container));
     pbuf->data.cont->id0 = player_number(pclause->from);
-    pbuf->data.cont->id1 = player_number(pdialog->treaty.plr1);
+    pbuf->data.cont->id1 = player_number(pdialog->treaty->plr1);
     pbuf->data.cont->value = ((int)pclause->type << 16) + pclause->value;
 
     pbuf->action = remove_clause_callback;
@@ -1176,25 +1216,26 @@ static void update_clauses_list(struct diplomacy_dialog *pdialog)
 /**********************************************************************//**
   Remove widget related to clause from list of widgets.
 **************************************************************************/
-static void remove_clause_widget_from_list(int counterpart, int giver,
+static void remove_clause_widget_from_list(struct player *they,
+                                           struct player *giver,
                                            enum clause_type type, int value)
 {
   struct widget *buf;
   SDL_Rect src = {0, 0, 0, 0};
   bool scroll;
-  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(counterpart);
+  struct diplomacy_dialog *pdialog = get_diplomacy_dialog(they);
 
   /* Find widget with clause */
   buf = pdialog->pdialog->end_active_widget_list->next;
 
   do {
     buf = buf->prev;
-  } while (!((buf->data.cont->id0 == giver)
+  } while (!((buf->data.cont->id0 == player_number(giver))
              && (((buf->data.cont->value >> 16) & 0xFFFF) == (int)type)
              && ((buf->data.cont->value & 0xFFFF) == value))
            && (buf != pdialog->pdialog->begin_active_widget_list));
 
-  if (!(buf->data.cont->id0 == giver
+  if (!(buf->data.cont->id0 == player_number(giver)
         && ((buf->data.cont->value >> 16) & 0xFFFF) == (int)type
         && (buf->data.cont->value & 0xFFFF) == value)) {
      return;
@@ -1233,7 +1274,8 @@ static void remove_clause_widget_from_list(int counterpart, int giver,
   Handle the start of a diplomacy meeting - usually by popping up a
   diplomacy dialog.
 **************************************************************************/
-void handle_diplomacy_init_meeting(int counterpart, int initiated_from)
+void gui_init_meeting(struct Treaty *ptreaty, struct player *they,
+                      struct player *initiator)
 {
   struct diplomacy_dialog *pdialog;
 
@@ -1241,13 +1283,12 @@ void handle_diplomacy_init_meeting(int counterpart, int initiated_from)
     return;
   }
 
-  if (!is_human(client.conn.playing)) {
+  if (!is_human(client_player())) {
     return; /* Don't show if we are not under human control. */
   }
 
-  if (!(pdialog = get_diplomacy_dialog(counterpart))) {
-    pdialog = create_diplomacy_dialog(client.conn.playing,
-                                      player_by_number(counterpart));
+  if (!(pdialog = get_diplomacy_dialog(they))) {
+    pdialog = create_diplomacy_dialog(ptreaty, client_player(), they);
   } else {
     /* bring existing dialog to front */
     select_window_group_dialog(pdialog->pdialog->begin_widget_list,
