@@ -95,9 +95,8 @@ enum GUI_ID {
   ID_UNIT_ORDER_FORTRESS,
   ID_UNIT_ORDER_FORTIFY,
   ID_UNIT_ORDER_AIRBASE,
-  ID_UNIT_ORDER_POLLUTION,
   ID_UNIT_ORDER_PARADROP,
-  ID_UNIT_ORDER_FALLOUT,
+  ID_UNIT_ORDER_CLEAN,
   ID_UNIT_ORDER_SENTRY,
   ID_UNIT_ORDER_PILLAGE,
   ID_UNIT_ORDER_HOMECITY,
