@@ -35,6 +35,10 @@
 #include <unistd.h>
 #endif
 
+#ifdef __EMSCRIPTEN__
+#include <emscripten.h>
+#endif
+
 /* SDL2 */
 #ifdef SDL2_PLAIN_INCLUDE
 #include <SDL.h>
@@ -139,7 +143,7 @@ static SDL_Event *map_scroll_user_event = NULL;
 
 static void print_usage(void);
 static bool parse_options(int argc, char **argv);
-static int check_scroll_area(int x, int y);
+static bool check_scroll_area(int x, int y);
 
 int user_event_type;
 
@@ -199,7 +203,7 @@ static bool parse_options(int argc, char **argv)
 
       return FALSE;
     } else if (is_option("--fullscreen", argv[i])) {
-      gui_options.gui_sdl2_fullscreen = TRUE;
+      GUI_SDL_OPTION(fullscreen) = TRUE;
     } else if (is_option("--swrenderer", argv[i])) {
       sdl2_client_flags |= CF_SWRENDERER;
     } else if ((option = get_option_malloc("--Font", argv, &i, argc, FALSE))) {
@@ -209,10 +213,11 @@ static bool parse_options(int argc, char **argv)
       }
       free(option);
     } else if ((option = get_option_malloc("--theme", argv, &i, argc, FALSE))) {
-      sz_strlcpy(gui_options.gui_sdl2_default_theme_name, option);
+      sz_strlcpy(GUI_SDL_OPTION(default_theme_name), option);
       free(option);
     } else {
       fc_fprintf(stderr, _("Unrecognized option: \"%s\"\n"), argv[i]);
+
       exit(EXIT_FAILURE);
     }
 
@@ -269,7 +274,7 @@ static Uint16 main_key_down_handler(SDL_Keysym key, void *data)
           return ID_ERROR;
 
         case SDLK_F8:
-          send_report_request(REPORT_TOP_5_CITIES);
+          send_report_request(REPORT_TOP_CITIES);
           return ID_ERROR;
 
         case SDLK_F9:
@@ -425,7 +430,7 @@ static Uint16 main_mouse_button_up_handler(SDL_MouseButtonEvent *button_event,
 #ifdef UNDER_CE
   #define SCROLL_MAP_AREA       8
 #else
-  #define SCROLL_MAP_AREA       1 
+  #define SCROLL_MAP_AREA       1
 #endif
 
 /**********************************************************************//**
@@ -452,7 +457,7 @@ static Uint16 main_mouse_motion_handler(SDL_MouseMotionEvent *motion_event,
   }
 
 #ifndef UNDER_CE
-  if (gui_options.gui_sdl2_fullscreen) {
+  if (GUI_SDL_OPTION(fullscreen)) {
     check_scroll_area(motion_event->x, motion_event->y);
   }
 #endif /* UNDER_CE */
@@ -510,35 +515,39 @@ static void update_button_hold_state(void)
 /**********************************************************************//**
   Check if coordinate is in scroll area.
 **************************************************************************/
-static int check_scroll_area(int x, int y)
+static bool check_scroll_area(int x, int y)
 {
-  SDL_Rect rect_north = {0, 0, main_data.map->w, SCROLL_MAP_AREA};
-  SDL_Rect rect_east = {main_data.map->w - SCROLL_MAP_AREA, 0, SCROLL_MAP_AREA, main_data.map->h};
-  SDL_Rect rect_south = {0, main_data.map->h - SCROLL_MAP_AREA, main_data.map->w, SCROLL_MAP_AREA};
-  SDL_Rect rect_west = {0, 0, SCROLL_MAP_AREA, main_data.map->h};
+  SDL_Rect rect_north = {.x = 0, .y = 0,
+    .w = main_data.map->w, .h = SCROLL_MAP_AREA};
+  SDL_Rect rect_east = {.x = main_data.map->w - SCROLL_MAP_AREA, .y = 0,
+    .w = SCROLL_MAP_AREA, .h = main_data.map->h};
+  SDL_Rect rect_south = {.x = 0, .y = main_data.map->h - SCROLL_MAP_AREA,
+    .w = main_data.map->w, .h = SCROLL_MAP_AREA};
+  SDL_Rect rect_west = {.x = 0, .y = 0,
+    .w = SCROLL_MAP_AREA, .h = main_data.map->h};
 
-  if (is_in_rect_area(x, y, rect_north)) {
+  if (is_in_rect_area(x, y, &rect_north)) {
     is_map_scrolling = TRUE;
-    if (is_in_rect_area(x, y, rect_west)) {
+    if (is_in_rect_area(x, y, &rect_west)) {
       scroll_dir = DIR8_NORTHWEST;
-    } else if (is_in_rect_area(x, y, rect_east)) {
+    } else if (is_in_rect_area(x, y, &rect_east)) {
       scroll_dir = DIR8_NORTHEAST;
     } else {
       scroll_dir = DIR8_NORTH;
     }
-  } else if (is_in_rect_area(x, y, rect_south)) {
+  } else if (is_in_rect_area(x, y, &rect_south)) {
     is_map_scrolling = TRUE;
-    if (is_in_rect_area(x, y, rect_west)) {
+    if (is_in_rect_area(x, y, &rect_west)) {
       scroll_dir = DIR8_SOUTHWEST;
-    } else if (is_in_rect_area(x, y, rect_east)) {
+    } else if (is_in_rect_area(x, y, &rect_east)) {
       scroll_dir = DIR8_SOUTHEAST;
     } else {
       scroll_dir = DIR8_SOUTH;
     }
-  } else if (is_in_rect_area(x, y, rect_east)) {
+  } else if (is_in_rect_area(x, y, &rect_east)) {
     is_map_scrolling = TRUE;
     scroll_dir = DIR8_EAST;
-  } else if (is_in_rect_area(x, y, rect_west)) {
+  } else if (is_in_rect_area(x, y, &rect_west)) {
     is_map_scrolling = TRUE;
     scroll_dir = DIR8_WEST;
   } else {
@@ -594,7 +603,7 @@ Uint16 gui_event_loop(void *data,
                       void (*loop_action)(void *data),
                       Uint16 (*key_down_handler)(SDL_Keysym key, void *data),
                       Uint16 (*key_up_handler)(SDL_Keysym key, void *data),
-                      Uint16 (*textinput_handler)(char *text, void *data),
+                      Uint16 (*textinput_handler)(const char *text, void *data),
                       Uint16 (*finger_down_handler)(SDL_TouchFingerEvent *touch_event, void *data),
                       Uint16 (*finger_up_handler)(SDL_TouchFingerEvent *touch_event, void *data),
                       Uint16 (*finger_motion_handler)(SDL_TouchFingerEvent *touch_event,
@@ -853,6 +862,10 @@ Uint16 gui_event_loop(void *data,
     }
 
     update_main_screen();
+
+#ifdef __EMSCRIPTEN__
+    emscripten_sleep(100);
+#endif
   }
 
   return ID;
@@ -928,7 +941,7 @@ static void fullscreen_callback(struct option *poption)
 {
   SDL_DisplayMode mode;
 
-  if (gui_options.gui_sdl2_fullscreen) {
+  if (GUI_SDL_OPTION(fullscreen)) {
     SDL_SetWindowFullscreen(main_data.screen, SDL_WINDOW_FULLSCREEN_DESKTOP);
   } else {
     SDL_SetWindowFullscreen(main_data.screen, 0);
@@ -938,7 +951,7 @@ static void fullscreen_callback(struct option *poption)
 
   if (!create_surfaces(mode.w, mode.h)) {
     /* Try to revert */
-    if (!gui_options.gui_sdl2_fullscreen) {
+    if (!GUI_SDL_OPTION(fullscreen)) {
       SDL_SetWindowFullscreen(main_data.screen, SDL_WINDOW_FULLSCREEN_DESKTOP);
     } else {
       SDL_SetWindowFullscreen(main_data.screen, 0);
@@ -957,14 +970,15 @@ void options_extra_init(void)
   struct option *poption;
 
 #define option_var_set_callback(var, callback)                              \
-  if ((poption = optset_option_by_name(client_optset, #var))) {             \
+  if ((poption = optset_option_by_name(client_optset,                       \
+                                       GUI_SDL_OPTION_STR(var)))) {         \
     option_set_changed_callback(poption, callback);                         \
   } else {                                                                  \
-    log_error("Didn't find option %s!", #var);                              \
+    log_error("Didn't find option %s!", GUI_SDL_OPTION_STR(var));           \
   }
 
-  option_var_set_callback(gui_sdl2_fullscreen, fullscreen_callback);
-  option_var_set_callback(gui_sdl2_screen, resize_window_callback);
+  option_var_set_callback(fullscreen, fullscreen_callback);
+  option_var_set_callback(screen, resize_window_callback);
 #undef option_var_set_callback
 }
 
@@ -976,7 +990,7 @@ static void clear_double_messages_call(void)
 {
   int i;
 
-  /* clear double call */
+  /* Clear double call */
   for (i = 0; i <= event_type_max(); i++) {
     if (messages_where[i] & MW_MESSAGES) {
       messages_where[i] &= ~MW_OUTPUT;
@@ -1026,15 +1040,24 @@ int ui_main(int argc, char *argv[])
     if (!gui_options.gui_sdl2_migrated_from_sdl) {
       migrate_options_from_sdl();
     }
+    if (!GUI_SDL_OPTION(default_screen_size_set)) {
+      if (font_size_parameter > 10) {
+        GUI_SDL_OPTION(screen) = VIDEO_MODE(640 * font_size_parameter / 10,
+                                            480 * font_size_parameter / 10);
+      }
 
-    if (gui_options.gui_sdl2_fullscreen) {
+      GUI_SDL_OPTION(default_screen_size_set) = TRUE;
+    }
+
+    if (GUI_SDL_OPTION(fullscreen)) {
       flags |= SDL_WINDOW_FULLSCREEN;
     } else {
       flags &= ~SDL_WINDOW_FULLSCREEN;
     }
+
     log_normal(_("Using Video Output: %s"), SDL_GetCurrentVideoDriver());
-    if (!set_video_mode(gui_options.gui_sdl2_screen.width,
-                        gui_options.gui_sdl2_screen.height,
+    if (!set_video_mode(GUI_SDL_OPTION(screen.width),
+                        GUI_SDL_OPTION(screen.height),
                         flags)) {
       return EXIT_FAILURE;
     }
@@ -1099,7 +1122,7 @@ int ui_main(int argc, char *argv[])
 
     setup_auxiliary_tech_icons();
 
-    /* This need correct main_data.screen size */
+    /* This needs correct main_data.screen size */
     init_mapcanvas_and_overview();
 
     set_client_state(C_S_DISCONNECTED);
@@ -1111,11 +1134,6 @@ int ui_main(int argc, char *argv[])
                    main_mouse_motion_handler);
     start_quitting();
 
-#if defined UNDER_CE && defined SMALL_SCREEN
-    /* Change back to window mode to restore the title bar */
-    set_video_mode(320, 240, SDL_SWSURFACE | SDL_ANYFORMAT);
-#endif
-
     city_map_canvas_free();
 
     free_mapcanvas_and_overview();
@@ -1127,7 +1145,7 @@ int ui_main(int argc, char *argv[])
 
     callback_list_destroy(callbacks);
     callbacks = NULL;
-
+  
     unload_cursors();
 
     free(button_behavior.event);
@@ -1295,7 +1313,8 @@ void gui_update_font(const char *font_name, const char *font_value)
 unsigned default_font_size(struct theme *act_theme)
 {
   return font_size_parameter > 0 ? font_size_parameter :
-    theme_default_font_size(act_theme);
+    (GUI_SDL_OPTION(use_theme_font_size) ? theme_default_font_size(act_theme) :
+     GUI_SDL_OPTION(font_size));
 }
 
 /**********************************************************************//**
