@@ -47,11 +47,11 @@
 
 #include "themespec.h"
 
-#define THEMESPEC_SDL2_CAPSTR "+Freeciv-2.6-sdl2-themespec duplicates_ok"
+#define THEMESPEC_SDL2_CAPSTR "+Freeciv-3.2-sdl2-themespec duplicates_ok"
 /*
  * Themespec capabilities acceptable to this program:
  *
- * +Freeciv-2.6-sdl2-themespec  -  basic format for Freeciv versions 2.6.x;
+ * +Freeciv-3.2-sdl2-themespec  -  basic format for Freeciv versions 3.2.x;
  *                                 required
  *
  * duplicates_ok  -  we can handle existence of duplicate tags
@@ -59,11 +59,11 @@
  *                   have duplicates should specify "+duplicates_ok")
  */
 
-#define SPEC_SDL2_CAPSTR "+Freeciv-3.1-sdl2-spec"
+#define SPEC_SDL2_CAPSTR "+Freeciv-3.2-sdl2-spec"
 /*
  * Individual spec file capabilities acceptable to this program:
  *
- * +Freeciv-3.1-sdl2-spec  -  basic format for Freeciv versions 3.1.x; required
+ * +Freeciv-3.2-sdl2-spec  -  basic format for Freeciv versions 3.2.x; required
  */
 
 #define THEMESPEC_SUFFIX ".themespec"
@@ -294,7 +294,8 @@ static bool check_themespec_capabilities(struct section_file *file,
 static void theme_free_toplevel(struct theme *t)
 {
   if (t->font_filename) {
-    FC_FREE(t->font_filename);
+    free(t->font_filename);
+    t->font_filename = NULL;
   }
 
   t->default_font_size = 0;
@@ -350,21 +351,24 @@ void themespec_try_read(const char *theme_name)
 
     if (active_theme == NULL) {
       log_fatal(_("No usable default theme found, aborting!"));
+
       exit(EXIT_FAILURE);
     }
 
     log_verbose("Trying theme \"%s\".", active_theme->name);
   }
-/*  sz_strlcpy(gui_sdl2_default_theme_name, theme_get_name(theme));*/
+
+  /*  sz_strlcpy(GUI_SDL_OPTION(default_theme_name),
+                 theme_get_name(theme)); */
 }
 
 /************************************************************************//**
   Read a new themespec in from scratch.
 
   Unlike the initial reading code, which reads pieces one at a time,
-  this gets rid of the old data and reads in the new all at once.  If the
-  new theme fails to load the old theme may be reloaded; otherwise the
-  client will exit.  If a NULL name is given the current theme will be
+  this gets rid of the old data and reads in the new all at once.
+  If the new theme fails to load the old theme may be reloaded; otherwise
+  the client will exit. If a NULL name is given the current theme will be
   reread.
 
   It will also call the necessary functions to redraw the graphics.
@@ -397,7 +401,7 @@ void themespec_reread(const char *new_theme_name)
 
   /* Step 2:  Read.
    *
-   * We read in the new theme.  This should be pretty straightforward.
+   * We read in the new theme. This should be pretty straightforward.
    */
   if (!(active_theme = theme_read_toplevel(theme_name))) {
     if (!(active_theme = theme_read_toplevel(old_name))) {
@@ -406,21 +410,22 @@ void themespec_reread(const char *new_theme_name)
                          "Failed to re-read the currently loaded theme.");
     }
   }
-/*  sz_strlcpy(gui_sdl2_default_theme_name, theme->name);*/
+  /* sz_strlcpy(GUI_SDL_OPTION(default_theme_name), theme->name); */
+
   theme_load_sprites(active_theme);
 
   /* Step 3: Setup
    *
-   * This is a seriously sticky problem.  On startup, we build a hash
+   * This is a seriously sticky problem. On startup, we build a hash
    * from all the sprite data. Then, when we connect to a server, the
    * server sends us ruleset data a piece at a time and we use this data
-   * to assemble the sprite structures.  But if we change while connected
-   *  we have to reassemble all of these.  This should just involve
-   * calling themespec_setup_*** on everything.  But how do we tell what
+   * to assemble the sprite structures. But if we change while connected
+   *  we have to reassemble all of these. This should just involve
+   * calling themespec_setup_*** on everything. But how do we tell what
    * "everything" is?
    *
    * The below code just does things straightforwardly, by setting up
-   * each possible sprite again.  Hopefully it catches everything, and
+   * each possible sprite again. Hopefully it catches everything, and
    * doesn't mess up too badly if we change themes while not connected
    * to a server.
    */
@@ -438,8 +443,8 @@ void themespec_reread(const char *new_theme_name)
 /*  theme_changed();*/
   can_slide = FALSE;
   center_tile_mapcanvas(center_tile);
-  /* update_map_canvas_visible forces a full redraw.  Otherwise with fast
-   * drawing we might not get one.  Of course this is slower. */
+  /* update_map_canvas_visible() forces a full redraw. Otherwise with fast
+   * drawing we might not get one. Of course this is slower. */
   update_map_canvas_visible();
   can_slide = TRUE;
 }
@@ -448,7 +453,7 @@ void themespec_reread(const char *new_theme_name)
   Loads the given graphics file (found in the data path) into a newly
   allocated sprite.
 ****************************************************************************/
-static struct sprite *load_gfx_file(const char *gfx_filename)
+static struct sprite *load_sdl2_gfx_file(const char *gfx_filename)
 {
   const char **gfx_fileexts = gfx_fileextensions(), *gfx_fileext;
   struct sprite *s;
@@ -462,7 +467,7 @@ static struct sprite *load_gfx_file(const char *gfx_filename)
     sprintf(full_name, "%s.%s", gfx_filename, gfx_fileext);
     if ((real_full_name = fileinfoname(get_data_dirs(), full_name))) {
       log_debug("trying to load gfx file \"%s\".", real_full_name);
-      s = load_gfxfile(real_full_name);
+      s = load_gfxfile(real_full_name, FALSE);
       if (s) {
         return s;
       }
@@ -502,7 +507,7 @@ static void theme_ensure_big_sprite(struct specfile *sf)
 
   gfx_filename = secfile_lookup_str(file, "file.gfx");
 
-  sf->big_sprite = load_gfx_file(gfx_filename);
+  sf->big_sprite = load_sdl2_gfx_file(gfx_filename);
 
   if (!sf->big_sprite) {
     log_fatal("Could not load gfx file for the spec file \"%s\".",
@@ -724,7 +729,8 @@ struct theme *theme_read_toplevel(const char *theme_name)
   bool duplicates_ok;
   struct theme *t = theme_new();
   const char *langname;
-  const char *filename, *c;
+  const char *filename, *t_fontname;
+  const char *lang;
 
   fname = themespec_fullname(theme_name);
   if (!fname) {
@@ -754,43 +760,35 @@ struct theme *theme_read_toplevel(const char *theme_name)
   file_capstr = secfile_lookup_str(file, "themespec.options");
   duplicates_ok = has_capabilities("+duplicates_ok", file_capstr);
 
-  (void) secfile_entry_by_path(file, "themespec.name"); /* currently unused */
+  (void) secfile_entry_by_path(file, "themespec.name"); /* Currently unused */
 
   sz_strlcpy(t->name, theme_name);
   t->priority = secfile_lookup_int_default(file, 0, "themespec.priority");
 
   langname = setup_langname();
 
-  c = NULL;
-
-  if (langname != NULL && strstr(langname, "zh_CN") != NULL) {
-    c = secfile_lookup_str(file, "themespec.font_file_zh_CN");
-  } else {
-    (void) secfile_entry_lookup(file, "themespec.font_file_zh_CN");
+  t_fontname = NULL;
+  for (i = 0;
+       (lang = secfile_lookup_str_default(file, NULL, "themespec.fonts%d.langname", i)) != NULL;
+       i++) {
+    if (langname != NULL && strstr(langname, lang) != NULL) {
+      t_fontname = secfile_lookup_str(file, "themespec.fonts%d.font_file", i);
+      /* Don't break the loop, but read all the entries to avoid "unused entry" warnings */
+    } else {
+      (void) secfile_entry_lookup(file, "themespec.fonts%d.font_file", i);
+    }
   }
 
-  if (c == NULL && langname != NULL && strstr(langname, "ja") != NULL) {
-    c = secfile_lookup_str(file, "themespec.font_file_ja");
+  if (t_fontname == NULL) {
+    t_fontname = secfile_lookup_str(file, "themespec.default_font_file");
   } else {
-    (void) secfile_entry_lookup(file, "themespec.font_file_ja");
+    (void) secfile_entry_lookup(file, "themespec.default_font_file");
   }
 
-  if (c == NULL && langname != NULL && strstr(langname, "ko") != NULL) {
-    c = secfile_lookup_str(file, "themespec.font_file_ko");
-  } else {
-    (void) secfile_entry_lookup(file, "themespec.font_file_ko");
-  }
-
-  if (c == NULL) {
-    c = secfile_lookup_str(file, "themespec.font_file");
-  } else {
-    (void) secfile_entry_lookup(file, "themespec.font_file");
-  }
-
-  if ((filename = fileinfoname(get_data_dirs(), c))) {
+  if ((filename = fileinfoname(get_data_dirs(), t_fontname))) {
     t->font_filename = fc_strdup(filename);
   } else {
-    log_fatal("Could not open font: %s", c);
+    log_fatal("Could not open font: %s", t_fontname);
     secfile_destroy(file);
     FC_FREE(fname);
     theme_free(t);
@@ -870,7 +868,7 @@ static struct sprite *theme_load_sprite(struct theme *t, const char *tag_name)
     /* If the sprite hasn't been loaded already, then load it. */
     fc_assert_ret_val(ss->ref_count == 0, NULL);
     if (ss->file) {
-      ss->sprite = load_gfx_file(ss->file);
+      ss->sprite = load_sdl2_gfx_file(ss->file);
       if (!ss->sprite) {
         log_fatal("Couldn't load gfx file \"%s\" for sprite '%s'.",
                   ss->file, tag_name);
