@@ -222,17 +222,18 @@ SDL_Surface *create_bcgnd_surf(SDL_Surface *ptheme, enum widget_state state,
 struct widget *find_next_widget_at_pos(struct widget *start_widget,
                                        int x, int y)
 {
-  SDL_Rect area = {0, 0, 0, 0};
   struct widget *pwidget;
 
   pwidget = start_widget ? start_widget : begin_main_widget_list;
 
   while (pwidget) {
-    area.x = pwidget->dst->dest_rect.x + pwidget->size.x;
-    area.y = pwidget->dst->dest_rect.y + pwidget->size.y;
-    area.w = pwidget->size.w;
-    area.h = pwidget->size.h;
-    if (is_in_rect_area(x, y, area)
+    SDL_Rect area = {
+      .x = pwidget->dst->dest_rect.x + pwidget->size.x,
+      .y = pwidget->dst->dest_rect.y + pwidget->size.y,
+      .w = pwidget->size.w,
+      .h = pwidget->size.h};
+
+    if (is_in_rect_area(x, y, &area)
         && !((get_wflags(pwidget) & WF_HIDDEN) == WF_HIDDEN)) {
       return (struct widget *) pwidget;
     }
@@ -615,8 +616,8 @@ void widget_add_as_prev(struct widget *new_widget, struct widget *add_dock)
   Delete Widget from Main widgets list ( begin_widget_list )
 
   NOTE: This function does not destroy Widget, only remove its pointer from
-  list. To destroy this Widget totaly ( free mem... ) call macro:
-  del_widget_from_gui_list( pwidget ).  This macro call this function.
+  list. To destroy this Widget totally ( free mem... ) call macro:
+  del_widget_from_gui_list( pwidget ). This macro call this function.
 **************************************************************************/
 void del_widget_pointer_from_gui_list(struct widget *gui)
 {
