@@ -36,6 +36,7 @@
 #include "game.h"
 #include "government.h"
 #include "map.h"
+#include "nation.h"
 #include "research.h"
 #include "traderoutes.h"
 #include "unitlist.h"
@@ -171,6 +172,8 @@ const char *popup_info_text(struct tile *ptile)
   index_to_native_pos(&nat_x, &nat_y, tile_index(ptile));
   astr_add_line(&str, _("Native coordinates: (%d, %d)"),
                 nat_x, nat_y);
+  astr_add_line(&str, _("Latitude: %d"),
+                map_signed_latitude(ptile));
 
   if (client_tile_get_known(ptile) == TILE_UNKNOWN) {
     astr_add(&str, _("Unknown"));
@@ -405,43 +408,7 @@ const char *popup_info_text(struct tile *ptile)
       }
     }
 
-    unit_list_iterate(get_units_in_focus(), pfocus_unit) {
-      int att_chance = FC_INFINITY, def_chance = FC_INFINITY;
-      bool found = FALSE;
-      struct civ_map *nmap = &(wld.map);
-
-      unit_list_iterate(ptile->units, tile_unit) {
-	if (unit_owner(tile_unit) != unit_owner(pfocus_unit)) {
-	  int att = unit_win_chance(nmap, pfocus_unit, tile_unit) * 100;
-	  int def = (1.0 - unit_win_chance(nmap, tile_unit, pfocus_unit)) * 100;
-
-	  found = TRUE;
-
-	  /* Presumably the best attacker and defender will be used. */
-	  att_chance = MIN(att, att_chance);
-	  def_chance = MIN(def, def_chance);
-	}
-      } unit_list_iterate_end;
-
-      if (found) {
-	/* TRANS: "Chance to win: A:95% D:46%" */
-	astr_add_line(&str, _("Chance to win: A:%d%% D:%d%%"),
-		      att_chance, def_chance);	
-      }
-    } unit_list_iterate_end;
-
-    /* TRANS: A is attack power, D is defense power, FP is firepower,
-     * HP is hitpoints (current and max). */
-    astr_add_line(&str, _("A:%d D:%d FP:%d HP:%d/%d"),
-                  ptype->attack_strength, ptype->defense_strength,
-                  ptype->firepower, punit->hp, ptype->hp);
-    {
-      const char *veteran_name =
-        utype_veteran_name_translation(ptype, punit->veteran);
-      if (veteran_name) {
-        astr_add(&str, " (%s)", veteran_name);
-      }
-    }
+    combat_odds_to_astr(&str, get_units_in_focus(), ptile, punit, "%%");
 
     if (unit_owner(punit) == client_player()
         || client_is_global_observer()) {
@@ -1761,6 +1728,7 @@ const char *get_act_sel_action_custom_text(struct action *paction,
   if (action_has_result(paction, ACTRES_TRADE_ROUTE)) {
     int revenue = get_caravan_enter_city_trade_bonus(actor_homecity,
                                                      target_city,
+                                                     unit_type_get(actor_unit),
                                                      actor_unit->carrying,
                                                      TRUE);
 
@@ -1781,6 +1749,7 @@ const char *get_act_sel_action_custom_text(struct action *paction,
   } else if (action_has_result(paction, ACTRES_MARKETPLACE)) {
     int revenue = get_caravan_enter_city_trade_bonus(actor_homecity,
                                                      target_city,
+                                                     unit_type_get(actor_unit),
                                                      actor_unit->carrying,
                                                      FALSE);
 
