@@ -15,54 +15,35 @@
 #define FC_ACTIONS_H
 
 /* common */
+#include "actres.h"
 #include "fc_types.h"
 #include "map_types.h"
-#include "metaknowledge.h"
 #include "requirements.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
+/* If 'enum gen_action' has currently unused values that should
+ * not be used in 'switch - cases', put those cases here. E.g.:
+ *
+ *#define ASSERT_UNUSED_ACTION_CASES              \
+ *   case ACTION_UNUSED_1:                        \
+ *     fc_assert_msg(FALSE, "ACTION_UNUSED_1");   \
+ *     break;                                     \
+  *   case ACTION_UNUSED_2:                       \
+ *     fc_assert_msg(FALSE, "ACTION_UNUSED_2");   \
+ *     break;
+ */
+#define ASSERT_UNUSED_ACTION_CASES            \
+
+
 #define SPECENUM_NAME action_actor_kind
 #define SPECENUM_VALUE0 AAK_UNIT
 #define SPECENUM_VALUE0NAME N_("a unit")
 #define SPECENUM_COUNT AAK_COUNT
 #include "specenum_gen.h"
 
-/* When making changes to this, update also atk_helpnames at actions.c */
-#define SPECENUM_NAME action_target_kind
-#define SPECENUM_VALUE0 ATK_CITY
-#define SPECENUM_VALUE0NAME "City"
-#define SPECENUM_VALUE1 ATK_UNIT
-#define SPECENUM_VALUE1NAME "Unit"
-#define SPECENUM_VALUE2 ATK_UNITS
-#define SPECENUM_VALUE2NAME "Stack"
-#define SPECENUM_VALUE3 ATK_TILE
-#define SPECENUM_VALUE3NAME "Tile"
-#define SPECENUM_VALUE4 ATK_EXTRAS
-#define SPECENUM_VALUE4NAME "Extras"
-/* No target except the actor itself. */
-#define SPECENUM_VALUE5 ATK_SELF
-#define SPECENUM_VALUE5NAME "Self"
-#define SPECENUM_COUNT ATK_COUNT
-#include "specenum_gen.h"
-
-/* Values used in the network protocol. */
-#define SPECENUM_NAME action_sub_target_kind
-#define SPECENUM_VALUE0 ASTK_NONE
-#define SPECENUM_VALUE0NAME N_("nothing")
-#define SPECENUM_VALUE1 ASTK_BUILDING
-#define SPECENUM_VALUE1NAME N_("buildings in")
-#define SPECENUM_VALUE2 ASTK_TECH
-#define SPECENUM_VALUE2NAME N_("techs from")
-#define SPECENUM_VALUE3 ASTK_EXTRA
-#define SPECENUM_VALUE3NAME N_("extras on")
-#define SPECENUM_VALUE4 ASTK_EXTRA_NOT_THERE
-#define SPECENUM_VALUE4NAME N_("create extras on")
-#define SPECENUM_COUNT ASTK_COUNT
-#include "specenum_gen.h"
-
 const char *gen_action_name_update_cb(const char *old_name);
 
 /* Values used in the network protocol. */
@@ -160,127 +141,164 @@ const char *gen_action_name_update_cb(const char *old_name);
 #define SPECENUM_VALUE44NAME "Airlift Unit"
 #define SPECENUM_VALUE45 ACTION_ATTACK
 #define SPECENUM_VALUE45NAME "Attack"
-#define SPECENUM_VALUE46 ACTION_SUICIDE_ATTACK
-#define SPECENUM_VALUE46NAME "Suicide Attack"
-#define SPECENUM_VALUE47 ACTION_STRIKE_BUILDING
-#define SPECENUM_VALUE47NAME "Surgical Strike Building"
-#define SPECENUM_VALUE48 ACTION_STRIKE_PRODUCTION
-#define SPECENUM_VALUE48NAME "Surgical Strike Production"
-#define SPECENUM_VALUE49 ACTION_CONQUER_CITY
-#define SPECENUM_VALUE49NAME "Conquer City"
-#define SPECENUM_VALUE50 ACTION_CONQUER_CITY2
-#define SPECENUM_VALUE50NAME "Conquer City 2"
-#define SPECENUM_VALUE51 ACTION_CONQUER_CITY3
-#define SPECENUM_VALUE51NAME "Conquer City 3"
-#define SPECENUM_VALUE52 ACTION_CONQUER_CITY4
-#define SPECENUM_VALUE52NAME "Conquer City 4"
-#define SPECENUM_VALUE53 ACTION_BOMBARD
-#define SPECENUM_VALUE53NAME "Bombard"
-#define SPECENUM_VALUE54 ACTION_BOMBARD2
-#define SPECENUM_VALUE54NAME "Bombard 2"
-#define SPECENUM_VALUE55 ACTION_BOMBARD3
-#define SPECENUM_VALUE55NAME "Bombard 3"
-#define SPECENUM_VALUE56 ACTION_FORTIFY
-#define SPECENUM_VALUE56NAME "Fortify"
-#define SPECENUM_VALUE57 ACTION_CULTIVATE
-#define SPECENUM_VALUE57NAME "Cultivate"
-#define SPECENUM_VALUE58 ACTION_PLANT
-#define SPECENUM_VALUE58NAME "Plant"
-#define SPECENUM_VALUE59 ACTION_TRANSFORM_TERRAIN
-#define SPECENUM_VALUE59NAME "Transform Terrain"
-#define SPECENUM_VALUE60 ACTION_ROAD
-#define SPECENUM_VALUE60NAME "Build Road"
-#define SPECENUM_VALUE61 ACTION_IRRIGATE
-#define SPECENUM_VALUE61NAME "Build Irrigation"
-#define SPECENUM_VALUE62 ACTION_MINE
-#define SPECENUM_VALUE62NAME "Build Mine"
-#define SPECENUM_VALUE63 ACTION_BASE
-#define SPECENUM_VALUE63NAME "Build Base"
-#define SPECENUM_VALUE64 ACTION_PILLAGE
-#define SPECENUM_VALUE64NAME "Pillage"
-#define SPECENUM_VALUE65 ACTION_CLEAN_POLLUTION
-#define SPECENUM_VALUE65NAME "Clean Pollution"
-#define SPECENUM_VALUE66 ACTION_CLEAN_FALLOUT
-#define SPECENUM_VALUE66NAME "Clean Fallout"
-#define SPECENUM_VALUE67 ACTION_TRANSPORT_BOARD
-#define SPECENUM_VALUE67NAME "Transport Board"
-/* Deboard */
-#define SPECENUM_VALUE68 ACTION_TRANSPORT_ALIGHT
-#define SPECENUM_VALUE68NAME "Transport Alight"
-#define SPECENUM_VALUE69 ACTION_TRANSPORT_EMBARK
-#define SPECENUM_VALUE69NAME "Transport Embark"
-#define SPECENUM_VALUE70 ACTION_TRANSPORT_EMBARK2
-#define SPECENUM_VALUE70NAME "Transport Embark 2"
-#define SPECENUM_VALUE71 ACTION_TRANSPORT_EMBARK3
-#define SPECENUM_VALUE71NAME "Transport Embark 3"
-#define SPECENUM_VALUE72 ACTION_TRANSPORT_DISEMBARK1
-#define SPECENUM_VALUE72NAME "Transport Disembark"
-#define SPECENUM_VALUE73 ACTION_TRANSPORT_DISEMBARK2
-#define SPECENUM_VALUE73NAME "Transport Disembark 2"
-#define SPECENUM_VALUE74 ACTION_TRANSPORT_DISEMBARK3
-#define SPECENUM_VALUE74NAME "Transport Disembark 3"
-#define SPECENUM_VALUE75 ACTION_TRANSPORT_DISEMBARK4
-#define SPECENUM_VALUE75NAME "Transport Disembark 4"
-#define SPECENUM_VALUE76 ACTION_TRANSPORT_UNLOAD
-#define SPECENUM_VALUE76NAME "Transport Unload"
-#define SPECENUM_VALUE77 ACTION_SPY_SPREAD_PLAGUE
-#define SPECENUM_VALUE77NAME "Spread Plague"
-#define SPECENUM_VALUE78 ACTION_SPY_ATTACK
-#define SPECENUM_VALUE78NAME "Spy Attack"
-#define SPECENUM_VALUE79 ACTION_CONQUER_EXTRAS
-#define SPECENUM_VALUE79NAME "Conquer Extras"
-#define SPECENUM_VALUE80 ACTION_CONQUER_EXTRAS2
-#define SPECENUM_VALUE80NAME "Conquer Extras 2"
-#define SPECENUM_VALUE81 ACTION_CONQUER_EXTRAS3
-#define SPECENUM_VALUE81NAME "Conquer Extras 3"
-#define SPECENUM_VALUE82 ACTION_CONQUER_EXTRAS4
-#define SPECENUM_VALUE82NAME "Conquer Extras 4"
-#define SPECENUM_VALUE83 ACTION_HUT_ENTER
-#define SPECENUM_VALUE83NAME "Enter Hut"
-#define SPECENUM_VALUE84 ACTION_HUT_ENTER2
-#define SPECENUM_VALUE84NAME "Enter Hut 2"
-#define SPECENUM_VALUE85 ACTION_HUT_ENTER3
-#define SPECENUM_VALUE85NAME "Enter Hut 3"
-#define SPECENUM_VALUE86 ACTION_HUT_ENTER4
-#define SPECENUM_VALUE86NAME "Enter Hut 4"
-#define SPECENUM_VALUE87 ACTION_HUT_FRIGHTEN
-#define SPECENUM_VALUE87NAME "Frighten Hut"
-#define SPECENUM_VALUE88 ACTION_HUT_FRIGHTEN2
-#define SPECENUM_VALUE88NAME "Frighten Hut 2"
-#define SPECENUM_VALUE89 ACTION_HUT_FRIGHTEN3
-#define SPECENUM_VALUE89NAME "Frighten Hut 3"
-#define SPECENUM_VALUE90 ACTION_HUT_FRIGHTEN4
-#define SPECENUM_VALUE90NAME "Frighten Hut 4"
-#define SPECENUM_VALUE91 ACTION_HEAL_UNIT
-#define SPECENUM_VALUE91NAME "Heal Unit"
-#define SPECENUM_VALUE92 ACTION_HEAL_UNIT2
-#define SPECENUM_VALUE92NAME "Heal Unit 2"
-#define SPECENUM_VALUE93 ACTION_PARADROP
-#define SPECENUM_VALUE93NAME "Paradrop Unit"
-#define SPECENUM_VALUE94 ACTION_PARADROP_CONQUER
-#define SPECENUM_VALUE94NAME "Paradrop Unit Conquer"
-#define SPECENUM_VALUE95 ACTION_PARADROP_FRIGHTEN
-#define SPECENUM_VALUE95NAME "Paradrop Unit Frighten"
-#define SPECENUM_VALUE96 ACTION_PARADROP_FRIGHTEN_CONQUER
-#define SPECENUM_VALUE96NAME "Paradrop Unit Frighten Conquer"
-#define SPECENUM_VALUE97 ACTION_PARADROP_ENTER
-#define SPECENUM_VALUE97NAME "Paradrop Unit Enter"
-#define SPECENUM_VALUE98 ACTION_PARADROP_ENTER_CONQUER
-#define SPECENUM_VALUE98NAME "Paradrop Unit Enter Conquer"
-#define SPECENUM_VALUE99 ACTION_UNIT_MOVE
-#define SPECENUM_VALUE99NAME "Unit Move"
-#define SPECENUM_VALUE100 ACTION_UNIT_MOVE2
-#define SPECENUM_VALUE100NAME "Unit Move 2"
-#define SPECENUM_VALUE101 ACTION_UNIT_MOVE3
-#define SPECENUM_VALUE101NAME "Unit Move 3"
-#define SPECENUM_VALUE102 ACTION_USER_ACTION1
-#define SPECENUM_VALUE102NAME "User Action 1"
-#define SPECENUM_VALUE103 ACTION_USER_ACTION2
-#define SPECENUM_VALUE103NAME "User Action 2"
-#define SPECENUM_VALUE104 ACTION_USER_ACTION3
-#define SPECENUM_VALUE104NAME "User Action 3"
-#define SPECENUM_VALUE105 ACTION_USER_ACTION4
-#define SPECENUM_VALUE105NAME "User Action 4"
+#define SPECENUM_VALUE46 ACTION_ATTACK2
+#define SPECENUM_VALUE46NAME "Attack 2"
+#define SPECENUM_VALUE47 ACTION_SUICIDE_ATTACK
+#define SPECENUM_VALUE47NAME "Suicide Attack"
+#define SPECENUM_VALUE48 ACTION_SUICIDE_ATTACK2
+#define SPECENUM_VALUE48NAME "Suicide Attack 2"
+#define SPECENUM_VALUE49 ACTION_STRIKE_BUILDING
+#define SPECENUM_VALUE49NAME "Surgical Strike Building"
+#define SPECENUM_VALUE50 ACTION_STRIKE_PRODUCTION
+#define SPECENUM_VALUE50NAME "Surgical Strike Production"
+#define SPECENUM_VALUE51 ACTION_CONQUER_CITY
+#define SPECENUM_VALUE51NAME "Conquer City"
+#define SPECENUM_VALUE52 ACTION_CONQUER_CITY2
+#define SPECENUM_VALUE52NAME "Conquer City 2"
+#define SPECENUM_VALUE53 ACTION_CONQUER_CITY3
+#define SPECENUM_VALUE53NAME "Conquer City 3"
+#define SPECENUM_VALUE54 ACTION_CONQUER_CITY4
+#define SPECENUM_VALUE54NAME "Conquer City 4"
+#define SPECENUM_VALUE55 ACTION_BOMBARD
+#define SPECENUM_VALUE55NAME "Bombard"
+#define SPECENUM_VALUE56 ACTION_BOMBARD2
+#define SPECENUM_VALUE56NAME "Bombard 2"
+#define SPECENUM_VALUE57 ACTION_BOMBARD3
+#define SPECENUM_VALUE57NAME "Bombard 3"
+#define SPECENUM_VALUE58 ACTION_BOMBARD4
+#define SPECENUM_VALUE58NAME "Bombard 4"
+#define SPECENUM_VALUE59 ACTION_BOMBARD_LETHAL
+#define SPECENUM_VALUE59NAME "Bombard Lethal"
+#define SPECENUM_VALUE60 ACTION_BOMBARD_LETHAL2
+#define SPECENUM_VALUE60NAME "Bombard Lethal 2"
+#define SPECENUM_VALUE61 ACTION_FORTIFY
+#define SPECENUM_VALUE61NAME "Fortify"
+#define SPECENUM_VALUE62 ACTION_CULTIVATE
+#define SPECENUM_VALUE62NAME "Cultivate"
+#define SPECENUM_VALUE63 ACTION_PLANT
+#define SPECENUM_VALUE63NAME "Plant"
+#define SPECENUM_VALUE64 ACTION_TRANSFORM_TERRAIN
+#define SPECENUM_VALUE64NAME "Transform Terrain"
+#define SPECENUM_VALUE65 ACTION_ROAD
+#define SPECENUM_VALUE65NAME "Build Road"
+#define SPECENUM_VALUE66 ACTION_IRRIGATE
+#define SPECENUM_VALUE66NAME "Build Irrigation"
+#define SPECENUM_VALUE67 ACTION_MINE
+#define SPECENUM_VALUE67NAME "Build Mine"
+#define SPECENUM_VALUE68 ACTION_BASE
+#define SPECENUM_VALUE68NAME "Build Base"
+#define SPECENUM_VALUE69 ACTION_PILLAGE
+#define SPECENUM_VALUE69NAME "Pillage"
+#define SPECENUM_VALUE70 ACTION_TRANSPORT_BOARD
+#define SPECENUM_VALUE70NAME "Transport Board"
+#define SPECENUM_VALUE71 ACTION_TRANSPORT_BOARD2
+#define SPECENUM_VALUE71NAME "Transport Board 2"
+#define SPECENUM_VALUE72 ACTION_TRANSPORT_BOARD3
+#define SPECENUM_VALUE72NAME "Transport Board_3"
+#define SPECENUM_VALUE73 ACTION_TRANSPORT_DEBOARD
+#define SPECENUM_VALUE73NAME "Transport Deboard"
+#define SPECENUM_VALUE74 ACTION_TRANSPORT_EMBARK
+#define SPECENUM_VALUE74NAME "Transport Embark"
+#define SPECENUM_VALUE75 ACTION_TRANSPORT_EMBARK2
+#define SPECENUM_VALUE75NAME "Transport Embark 2"
+#define SPECENUM_VALUE76 ACTION_TRANSPORT_EMBARK3
+#define SPECENUM_VALUE76NAME "Transport Embark 3"
+#define SPECENUM_VALUE77 ACTION_TRANSPORT_EMBARK4
+#define SPECENUM_VALUE77NAME "Transport Embark 4"
+#define SPECENUM_VALUE78 ACTION_TRANSPORT_DISEMBARK1
+#define SPECENUM_VALUE78NAME "Transport Disembark"
+#define SPECENUM_VALUE79 ACTION_TRANSPORT_DISEMBARK2
+#define SPECENUM_VALUE79NAME "Transport Disembark 2"
+#define SPECENUM_VALUE80 ACTION_TRANSPORT_DISEMBARK3
+#define SPECENUM_VALUE80NAME "Transport Disembark 3"
+#define SPECENUM_VALUE81 ACTION_TRANSPORT_DISEMBARK4
+#define SPECENUM_VALUE81NAME "Transport Disembark 4"
+#define SPECENUM_VALUE82 ACTION_TRANSPORT_LOAD
+#define SPECENUM_VALUE82NAME "Transport Load"
+#define SPECENUM_VALUE83 ACTION_TRANSPORT_LOAD2
+#define SPECENUM_VALUE83NAME "Transport Load 2"
+#define SPECENUM_VALUE84 ACTION_TRANSPORT_LOAD3
+#define SPECENUM_VALUE84NAME "Transport Load 3"
+#define SPECENUM_VALUE85 ACTION_TRANSPORT_UNLOAD
+#define SPECENUM_VALUE85NAME "Transport Unload"
+#define SPECENUM_VALUE86 ACTION_SPY_SPREAD_PLAGUE
+#define SPECENUM_VALUE86NAME "Spread Plague"
+#define SPECENUM_VALUE87 ACTION_SPY_ATTACK
+#define SPECENUM_VALUE87NAME "Spy Attack"
+#define SPECENUM_VALUE88 ACTION_CONQUER_EXTRAS
+#define SPECENUM_VALUE88NAME "Conquer Extras"
+#define SPECENUM_VALUE89 ACTION_CONQUER_EXTRAS2
+#define SPECENUM_VALUE89NAME "Conquer Extras 2"
+#define SPECENUM_VALUE90 ACTION_CONQUER_EXTRAS3
+#define SPECENUM_VALUE90NAME "Conquer Extras 3"
+#define SPECENUM_VALUE91 ACTION_CONQUER_EXTRAS4
+#define SPECENUM_VALUE91NAME "Conquer Extras 4"
+#define SPECENUM_VALUE92 ACTION_HUT_ENTER
+#define SPECENUM_VALUE92NAME "Enter Hut"
+#define SPECENUM_VALUE93 ACTION_HUT_ENTER2
+#define SPECENUM_VALUE93NAME "Enter Hut 2"
+#define SPECENUM_VALUE94 ACTION_HUT_ENTER3
+#define SPECENUM_VALUE94NAME "Enter Hut 3"
+#define SPECENUM_VALUE95 ACTION_HUT_ENTER4
+#define SPECENUM_VALUE95NAME "Enter Hut 4"
+#define SPECENUM_VALUE96 ACTION_HUT_FRIGHTEN
+#define SPECENUM_VALUE96NAME "Frighten Hut"
+#define SPECENUM_VALUE97 ACTION_HUT_FRIGHTEN2
+#define SPECENUM_VALUE97NAME "Frighten Hut 2"
+#define SPECENUM_VALUE98 ACTION_HUT_FRIGHTEN3
+#define SPECENUM_VALUE98NAME "Frighten Hut 3"
+#define SPECENUM_VALUE99 ACTION_HUT_FRIGHTEN4
+#define SPECENUM_VALUE99NAME "Frighten Hut 4"
+#define SPECENUM_VALUE100 ACTION_HEAL_UNIT
+#define SPECENUM_VALUE100NAME "Heal Unit"
+#define SPECENUM_VALUE101 ACTION_HEAL_UNIT2
+#define SPECENUM_VALUE101NAME "Heal Unit 2"
+#define SPECENUM_VALUE102 ACTION_PARADROP
+#define SPECENUM_VALUE102NAME "Paradrop Unit"
+#define SPECENUM_VALUE103 ACTION_PARADROP_CONQUER
+#define SPECENUM_VALUE103NAME "Paradrop Unit Conquer"
+#define SPECENUM_VALUE104 ACTION_PARADROP_FRIGHTEN
+#define SPECENUM_VALUE104NAME "Paradrop Unit Frighten"
+#define SPECENUM_VALUE105 ACTION_PARADROP_FRIGHTEN_CONQUER
+#define SPECENUM_VALUE105NAME "Paradrop Unit Frighten Conquer"
+#define SPECENUM_VALUE106 ACTION_PARADROP_ENTER
+#define SPECENUM_VALUE106NAME "Paradrop Unit Enter"
+#define SPECENUM_VALUE107 ACTION_PARADROP_ENTER_CONQUER
+#define SPECENUM_VALUE107NAME "Paradrop Unit Enter Conquer"
+#define SPECENUM_VALUE108 ACTION_WIPE_UNITS
+#define SPECENUM_VALUE108NAME "Wipe Units"
+#define SPECENUM_VALUE109 ACTION_SPY_ESCAPE
+#define SPECENUM_VALUE109NAME "Spy Escape"
+#define SPECENUM_VALUE110 ACTION_UNIT_MOVE
+#define SPECENUM_VALUE110NAME "Unit Move"
+#define SPECENUM_VALUE111 ACTION_UNIT_MOVE2
+#define SPECENUM_VALUE111NAME "Unit Move 2"
+#define SPECENUM_VALUE112 ACTION_UNIT_MOVE3
+#define SPECENUM_VALUE112NAME "Unit Move 3"
+#define SPECENUM_VALUE113 ACTION_TELEPORT
+#define SPECENUM_VALUE113NAME "Teleport"
+#define SPECENUM_VALUE114 ACTION_TELEPORT_CONQUER
+#define SPECENUM_VALUE114NAME "Teleport Conquer"
+#define SPECENUM_VALUE115 ACTION_TELEPORT_FRIGHTEN
+#define SPECENUM_VALUE115NAME "Teleport Frighten"
+#define SPECENUM_VALUE116 ACTION_TELEPORT_FRIGHTEN_CONQUER
+#define SPECENUM_VALUE116NAME "Teleport Frighten Conquer"
+#define SPECENUM_VALUE117 ACTION_TELEPORT_ENTER
+#define SPECENUM_VALUE117NAME "Teleport Enter"
+#define SPECENUM_VALUE118 ACTION_TELEPORT_ENTER_CONQUER
+#define SPECENUM_VALUE118NAME "Teleport Enter Conquer"
+#define SPECENUM_VALUE119 ACTION_CLEAN
+#define SPECENUM_VALUE119NAME "Clean"
+#define SPECENUM_VALUE120 ACTION_COLLECT_RANSOM
+#define SPECENUM_VALUE120NAME "Collect Ransom"
+#define SPECENUM_VALUE121 ACTION_USER_ACTION1
+#define SPECENUM_VALUE121NAME "User Action 1"
+#define SPECENUM_VALUE122 ACTION_USER_ACTION2
+#define SPECENUM_VALUE122NAME "User Action 2"
+#define SPECENUM_VALUE123 ACTION_USER_ACTION3
+#define SPECENUM_VALUE123NAME "User Action 3"
+#define SPECENUM_VALUE124 ACTION_USER_ACTION4
+#define SPECENUM_VALUE124NAME "User Action 4"
 #define SPECENUM_BITVECTOR bv_actions
 #define SPECENUM_COUNT ACTION_COUNT
 #define SPECENUM_NAME_UPDATER
@@ -296,19 +314,6 @@ const char *gen_action_name_update_cb(const char *old_name);
 #define MAX_NUM_ACTIONS ACTION_COUNT
 #define NUM_ACTIONS MAX_NUM_ACTIONS
 
-/* A battle is against a defender that tries to stop the action where the
- * defender is in danger. A dice roll without a defender risking anything,
- * like the roll controlled by EFT_ACTION_ODDS_PCT, isn't a battle. */
-#define SPECENUM_NAME action_battle_kind
-#define SPECENUM_VALUE0 ABK_NONE
-#define SPECENUM_VALUE0NAME N_("no battle")
-#define SPECENUM_VALUE1 ABK_STANDARD
-#define SPECENUM_VALUE1NAME N_("battle")
-#define SPECENUM_VALUE2 ABK_DIPLOMATIC
-#define SPECENUM_VALUE2NAME N_("diplomatic battle")
-#define SPECENUM_COUNT ABK_COUNT
-#include "specenum_gen.h"
-
 /* Describes how a unit successfully performing an action will move it. */
 #define SPECENUM_NAME moves_actor_kind
 #define SPECENUM_VALUE0 MAK_STAYS
@@ -353,28 +358,6 @@ const char *gen_action_name_update_cb(const char *old_name);
 /* No action max distance can be bigger than this. */
 #define ACTION_DISTANCE_MAX ACTION_DISTANCE_UNLIMITED
 
-/* Action target complexity */
-#define SPECENUM_NAME act_tgt_compl
-/* The action's target is just the primary target. (Just the tile, unit,
- * city, etc). */
-#define SPECENUM_VALUE0 ACT_TGT_COMPL_SIMPLE
-#define SPECENUM_VALUE0NAME N_("simple")
-/* The action's target is complex because its target is the primary target
- * and a sub target. (Examples: Tile + Extra and City + Building.) The
- * player is able to specify details about this action but the server will
- * fill in missing details so a client can choose to not specify the sub
- * target. */
-#define SPECENUM_VALUE1 ACT_TGT_COMPL_FLEXIBLE
-#define SPECENUM_VALUE1NAME N_("flexible")
-/* The action's target is complex because its target is the primary target
- * and a sub target. (Examples: Tile + Extra and City + Building.) The
- * player is required to specify details about this action because the
- * server won't fill inn the missing details when unspecified. A client must
- * therefore specify the sub target of this action. */
-#define SPECENUM_VALUE2 ACT_TGT_COMPL_MANDATORY
-#define SPECENUM_VALUE2NAME N_("mandatory")
-#include "specenum_gen.h"
-
 struct action
 {
   action_id id;
@@ -448,6 +431,7 @@ struct action_enabler
 #define action_has_result(_act_, _res_) ((_act_)->result == (_res_))
 
 #define enabler_get_action(_enabler_) action_by_number(_enabler_->action)
+#define enabler_get_action_id(_enabler_) (_enabler_->action)
 
 #define SPECLIST_TAG action_enabler
 #define SPECLIST_TYPE struct action_enabler
@@ -464,13 +448,22 @@ struct action_enabler
     }                                                                 \
   } action_enabler_list_iterate_end
 
-#define action_iterate(_act_)                                             \
+#define action_iterate_all(_act_)                                         \
 {                                                                         \
   action_id _act_;                                                        \
   for (_act_ = 0; _act_ < NUM_ACTIONS; _act_++) {
 
-#define action_iterate_end                             \
-  }                                                    \
+#define action_iterate_all_end                                            \
+  }                                                                       \
+}
+
+/* Filter out unused action slots, in versions where those exist */
+#define action_iterate(_act_)                                             \
+{                                                                         \
+  action_iterate_all(_act_) {
+
+#define action_iterate_end                                                \
+  } action_iterate_all_end;                                               \
 }
 
 /* Get 'struct action_id_list' and related functions: */
@@ -501,19 +494,19 @@ struct action_list *action_list_by_activity(enum unit_activity activity);
   } action_list_iterate_end;                                              \
 }
 
-#define action_array_iterate(_act_list_, _act_id_)                        \
+#define action_array_iterate(_act_array_, _act_id_)                         \
 {                                                                         \
   int _pos_;                                                              \
                                                                           \
   for (_pos_ = 0; _pos_ < NUM_ACTIONS; _pos_++) {                         \
-    const action_id _act_id_ = _act_list_[_pos_];                         \
+    const action_id _act_id_ = _act_array_[_pos_];                         \
                                                                           \
     if (_act_id_ == ACTION_NONE) {                                        \
       /* No more actions in this list. */                                 \
       break;                                                              \
     }
 
-#define action_array_iterate_end                                          \
+#define action_array_iterate_end                              \
   }                                                                       \
 }
 
@@ -610,15 +603,19 @@ action_auto_perf_iterate(_act_perf_) {                                    \
   action_array_iterate_end
 
 /* Hard coded location of action auto performers. Used for conversion while
- * action auto performers aren't directly exposed to the ruleset. */
-#define ACTION_AUTO_UPKEEP_FOOD   0
-#define ACTION_AUTO_UPKEEP_GOLD   1
-#define ACTION_AUTO_UPKEEP_SHIELD 2
-#define ACTION_AUTO_MOVED_ADJ     3
-#define ACTION_AUTO_POST_BRIBE    4
-#define ACTION_AUTO_POST_ATTACK   5
-#define ACTION_AUTO_ESCAPE_CITY   6
-#define ACTION_AUTO_ESCAPE_STACK  7
+ * action auto performers aren't directly exposed to the ruleset.
+ * Remember to update also MAX_NUM_ACTION_AUTO_PERFORMERS when changing these. */
+#define ACTION_AUTO_UPKEEP_FOOD          0
+#define ACTION_AUTO_UPKEEP_GOLD          1
+#define ACTION_AUTO_UPKEEP_SHIELD        2
+#define ACTION_AUTO_MOVED_ADJ            3
+#define ACTION_AUTO_POST_BRIBE           4
+#define ACTION_AUTO_POST_ATTACK          5
+#define ACTION_AUTO_POST_ATTACK2         6
+#define ACTION_AUTO_POST_COLLECT_RANSOM  7
+#define ACTION_AUTO_ESCAPE_CITY          8
+#define ACTION_AUTO_ESCAPE_STACK         9
+#define ACTION_AUTO_POST_WIPE_UNITS     10
 
 /* Initialization */
 void actions_init(void);
@@ -659,10 +656,10 @@ enum action_sub_target_kind action_get_sub_target_kind(
 #define action_id_get_sub_target_kind(act_id)                             \
   action_get_sub_target_kind(action_by_number(act_id))
 
-enum action_battle_kind action_get_battle_kind(const struct action *pact);
-
 int action_number(const struct action *action);
 
+#define action_id(_act_) (_act_->id)
+
 #define action_has_result_safe(paction, result)                           \
   (paction && action_has_result(paction, result))
 #define action_id_has_result_safe(act_id, result)                         \
@@ -676,19 +673,10 @@ bool action_requires_details(const struct action *paction);
 #define action_id_requires_details(act_id)                                \
   action_requires_details(action_by_number(act_id))
 
-int action_get_act_time(const struct action *paction,
-                        const struct unit *actor_unit,
-                        const struct tile *tgt_tile,
-                        const struct extra_type *tgt_extra);
-#define action_id_get_act_time(act_id, actor_unit, tgt_tile, tgt_extra)    \
-  action_get_act_time(action_by_number(act_id),                            \
+#define action_id_get_act_time(act_id, actor_unit, tgt_tile, tgt_extra)   \
+  actres_get_act_time(action_by_number(act_id)->result,                   \
                       actor_unit, tgt_tile, tgt_extra)
 
-bool action_creates_extra(const struct action *paction,
-                          const struct extra_type *pextra);
-bool action_removes_extra(const struct action *paction,
-                          const struct extra_type *pextra);
-
 bool action_id_is_rare_pop_up(action_id act_id);
 
 bool action_distance_accepted(const struct action *action,
@@ -708,9 +696,10 @@ int action_get_role(const struct action *paction);
 #define action_id_get_role(act_id)                                        \
   action_get_role(action_by_number(act_id))
 
-enum unit_activity actres_get_activity(enum action_result result);
+#define action_get_activity(_pact_)                                       \
+  actres_activity_result(_pact_->result)
 #define action_id_get_activity(act_id)                                    \
-  actres_get_activity(action_by_number(act_id)->result)
+  action_get_activity(action_by_number(act_id))
 
 const char *action_rule_name(const struct action *action);
 const char *action_id_rule_name(action_id act_id);
@@ -727,15 +716,9 @@ const char *action_ui_name_ruleset_var_name(int act);
 const char *action_ui_name_default(int act);
 
 const char *action_min_range_ruleset_var_name(int act);
-int action_min_range_default(enum action_result result);
 const char *action_max_range_ruleset_var_name(int act);
-int action_max_range_default(enum action_result result);
 
 const char *action_target_kind_ruleset_var_name(int act);
-enum action_target_kind
-action_target_kind_default(enum action_result result);
-bool action_result_legal_target_kind(enum action_result result,
-                                     enum action_target_kind tgt_kind);
 const char *action_target_kind_help(enum action_target_kind kind);
 
 const char *action_actor_consuming_always_ruleset_var_name(action_id act);
@@ -793,7 +776,7 @@ bool is_action_enabled_unit_on_unit(const struct civ_map *nmap,
                                     const struct unit *actor_unit,
                                     const struct unit *target_unit);
 
-bool is_action_enabled_unit_on_units(const struct civ_map *nmap,
+bool is_action_enabled_unit_on_stack(const struct civ_map *nmap,
                                      const action_id wanted_action,
                                      const struct unit *actor_unit,
                                      const struct tile *target_tile);
@@ -824,7 +807,7 @@ struct act_prob action_prob_vs_unit(const struct civ_map *nmap,
                                     const action_id act_id,
                                     const struct unit *victim);
 
-struct act_prob action_prob_vs_units(const struct civ_map *nmap,
+struct act_prob action_prob_vs_stack(const struct civ_map *nmap,
                                      const struct unit* actor,
                                      const action_id act_id,
                                      const struct tile* victims);
@@ -872,7 +855,7 @@ action_speculate_unit_on_unit(const struct civ_map *nmap,
                               const struct unit *target);
 
 struct act_prob
-action_speculate_unit_on_units(const struct civ_map *nmap,
+action_speculate_unit_on_stack(const struct civ_map *nmap,
                                action_id act_id,
                                const struct unit *actor,
                                const struct city *actor_home,
@@ -966,11 +949,11 @@ bool action_immune_government(struct government *gov, action_id act);
 
 bool is_action_possible_on_city(action_id act_id,
                                 const struct player *actor_player,
-                                const struct city* target_city);
+                                const struct city *target_city);
 
 bool action_maybe_possible_actor_unit(const struct civ_map *nmap,
                                       const action_id wanted_action,
-                                      const struct unit* actor_unit);
+                                      const struct unit *actor_unit);
 
 bool action_mp_full_makes_legal(const struct unit *actor,
                                 const action_id act_id);
@@ -978,8 +961,8 @@ bool action_mp_full_makes_legal(const struct unit *actor,
 bool action_is_in_use(struct action *paction);
 
 /* Action lists */
-void action_list_end(action_id *act_list, int size);
-void action_list_add_all_by_result(action_id *act_list,
+void action_array_end(action_id *act_array, int size);
+void action_array_add_all_by_result(action_id *act_array,
                                    int *position,
                                    enum action_result result);
 
