@@ -38,8 +38,8 @@ extern "C" {
 #define MAX_NUM_CONNECTIONS (2 * (MAX_NUM_PLAYER_SLOTS))
 /* e.g. unit_types. Used in the network protocol. */
 #define MAX_NUM_ITEMS   200
-#define MAX_NUM_ADVANCES  250 /* Used in the network protocol. */
-#define MAX_NUM_UNITS     250 /* Used in the network protocol. */
+#define MAX_NUM_ADVANCES  400 /* Used in the network protocol. */
+#define MAX_NUM_UNITS     300 /* Used in the network protocol. */
 #define MAX_NUM_BUILDINGS 200 /* Used in the network protocol. */
 #define MAX_NUM_TECH_LIST 10 /* Used in the network protocol. */
 #define MAX_NUM_UNIT_LIST 10 /* Used in the network protocol. */
@@ -47,12 +47,12 @@ extern "C" {
 #define MAX_LEN_VET_SHORT_NAME 8
 /* Used in the network protocol. See diplomat_success_vs_defender() */
 #define MAX_VET_LEVELS 20
-#define MAX_EXTRA_TYPES 128 /* Used in the network protocol. */
+#define MAX_EXTRA_TYPES 250 /* Used in the network protocol. */
 #define MAX_GOODS_TYPES 25
 #define MAX_DISASTER_TYPES 10
 #define MAX_ACHIEVEMENT_TYPES 40
-#define MAX_NUM_ACTION_AUTO_PERFORMERS 8
-#define MAX_NUM_MULTIPLIERS 15
+#define MAX_NUM_ACTION_AUTO_PERFORMERS 11
+#define MAX_NUM_MULTIPLIERS 50
 #define MAX_NUM_LEADERS MAX_NUM_ITEMS /* Used in the network protocol. */
 #define MAX_NUM_NATION_SETS 32 /* Used in the network protocol.
                                 * RULESET_NATION_SETS packet may become too big
@@ -65,19 +65,29 @@ extern "C" {
 #define MAX_NUM_TECH_CLASSES   16     /* Used in the network protocol. */
 
 /* Changing these will probably break network compatibility. */
-#define MAX_LEN_NAME       48
-#define MAX_LEN_CITYNAME   80
-#define MAX_LEN_MAP_LABEL  64
-#define MAX_LEN_DEMOGRAPHY 16
-#define MAX_LEN_ALLOW_TAKE 16
+#define MAX_LEN_NAME        48
+#define MAX_LEN_CITYNAME   120
+#define MAX_LEN_MAP_LABEL   64
+#define MAX_LEN_DEMOGRAPHY  16
+#define MAX_LEN_ALLOW_TAKE  16
 #define MAX_LEN_GAME_IDENTIFIER 33
-#define MAX_GRANARY_INIS 24
+#define MAX_GRANARY_INIS    24
 #define MAX_LEN_STARTUNIT (20+1)
-#define MAX_LEN_ENUM     64
+#define MAX_LEN_ENUM        64
 
 /* Line breaks after this number of characters; be careful and use only 70 */
 #define LINE_BREAK 70
 
+/* Changing the max radius requires updating network capabilities and results
+ * in incompatible savefiles. */
+#define CITY_MAP_MIN_RADIUS       0
+#define CITY_MAP_DEFAULT_RADIUS   2
+#define CITY_MAP_MAX_RADIUS       5
+
+/* Below size of city tiles array is big enough for radius 5 city */
+FC_STATIC_ASSERT(CITY_MAP_MAX_RADIUS <= 5, too_many_city_tiles);
+#define MAX_CITY_TILES (91)
+
 #define MAX_CITY_NATIONALITIES (MIN(MAX_NUM_PLAYER_SLOTS, MAX_CITY_SIZE))
 
 /* symbol to flag missing numbers for better debugging */
@@ -93,6 +103,30 @@ enum output_type_id {
   O_FOOD, O_SHIELD, O_TRADE, O_GOLD, O_LUXURY, O_SCIENCE, O_LAST
 };
 
+/* Counters related definitions. See common/counters.h */
+/* Used in the network protocol. */
+#define MAX_COUNTERS 20
+
+/* Counters related types. See common/counters.h */
+/* Used in the network protocol. */
+#define SPECENUM_NAME counter_behavior
+#define SPECENUM_VALUE1 CB_CITY_OWNED_TURNS
+#define SPECENUM_VALUE1NAME "Owned"
+#define SPECENUM_VALUE2 CB_CITY_CELEBRATION_TURNS
+#define SPECENUM_VALUE2NAME "Celebration"
+#define SPECENUM_VALUE3 CB_CITY_DISORDER_TURNS
+#define SPECENUM_VALUE3NAME "Disorder"
+#define SPECENUM_VALUE4 CB_USER
+#define SPECENUM_VALUE4NAME "User"
+
+
+
+#define SPECENUM_COUNT COUNTER_BEHAVIOR_LAST
+#include "specenum_gen.h"
+
+/* Used in the network protocol. */
+enum counter_target { CTGT_CITY };
+
 /* Changing this enum will break savegame and network compatibility. */
 /* When changing this, also update the list of valid requirement "Activity"
  * values in doc/README.effects and the list of invalid requirement
@@ -101,77 +135,57 @@ enum output_type_id {
 /* Not performing any activity right now */
 #define SPECENUM_VALUE0 ACTIVITY_IDLE
 #define SPECENUM_VALUE0NAME N_("Idle")
-/* Action with the result ACTRES_CLEAN_POLLUTION */
-#define SPECENUM_VALUE1 ACTIVITY_POLLUTION
-#define SPECENUM_VALUE1NAME N_("Pollution")
-/* Savegame compatibility */
-#define SPECENUM_VALUE2 ACTIVITY_OLD_ROAD
-#define SPECENUM_VALUE2NAME "Unused Road"
 /* Action with the result ACTRES_CULTIVATE */
-#define SPECENUM_VALUE3 ACTIVITY_MINE
-#define SPECENUM_VALUE3NAME N_("?act:Mine")
+#define SPECENUM_VALUE1 ACTIVITY_CULTIVATE
+#define SPECENUM_VALUE1NAME N_("Cultivate")
+/* Action with the result ACTRES_MINE */
+#define SPECENUM_VALUE2 ACTIVITY_MINE
+#define SPECENUM_VALUE2NAME N_("?act:Mine")
 /* Action with the result ACTRES_IRRIGATE */
-#define SPECENUM_VALUE4 ACTIVITY_IRRIGATE
-#define SPECENUM_VALUE4NAME N_("Irrigate")
+#define SPECENUM_VALUE3 ACTIVITY_IRRIGATE
+#define SPECENUM_VALUE3NAME N_("Irrigate")
 /* Has completed ACTIVITY_FORTIFYING */
-#define SPECENUM_VALUE5 ACTIVITY_FORTIFIED
-#define SPECENUM_VALUE5NAME N_("Fortified")
-/* Savegame compatibility */
-#define SPECENUM_VALUE6 ACTIVITY_FORTRESS
-#define SPECENUM_VALUE6NAME "Fortress"
+#define SPECENUM_VALUE4 ACTIVITY_FORTIFIED
+#define SPECENUM_VALUE4NAME N_("Fortified")
 /* Server side client state (UI) */
-#define SPECENUM_VALUE7 ACTIVITY_SENTRY
-#define SPECENUM_VALUE7NAME "Sentry"
-/* Savegame compatibility */
-#define SPECENUM_VALUE8 ACTIVITY_OLD_RAILROAD
-#define SPECENUM_VALUE8NAME "Unused Railroad"
+#define SPECENUM_VALUE5 ACTIVITY_SENTRY
+#define SPECENUM_VALUE5NAME "Sentry"
 /* Action with the result ACTRES_PILLAGE */
-#define SPECENUM_VALUE9 ACTIVITY_PILLAGE
-#define SPECENUM_VALUE9NAME N_("Pillage")
+#define SPECENUM_VALUE6 ACTIVITY_PILLAGE
+#define SPECENUM_VALUE6NAME N_("Pillage")
 /* AI compatibility. Is not orders' goto. */
-#define SPECENUM_VALUE10 ACTIVITY_GOTO
-#define SPECENUM_VALUE10NAME "Goto"
+#define SPECENUM_VALUE7 ACTIVITY_GOTO
+#define SPECENUM_VALUE7NAME "Goto"
 /* Server side agent */
-#define SPECENUM_VALUE11 ACTIVITY_EXPLORE
-#define SPECENUM_VALUE11NAME "Explore"
+#define SPECENUM_VALUE8 ACTIVITY_EXPLORE
+#define SPECENUM_VALUE8NAME "Explore"
 /* Action with the result ACTRES_TRANSFORM_TERRAIN */
-#define SPECENUM_VALUE12 ACTIVITY_TRANSFORM
-#define SPECENUM_VALUE12NAME N_("Transform")
-/* Unused */
-#define SPECENUM_VALUE13 ACTIVITY_UNKNOWN
-#define SPECENUM_VALUE13NAME "Unused"
-/* Savegame compatibility */
-#define SPECENUM_VALUE14 ACTIVITY_AIRBASE
-#define SPECENUM_VALUE14NAME "Unused Airbase"
+#define SPECENUM_VALUE9 ACTIVITY_TRANSFORM
+#define SPECENUM_VALUE9NAME N_("Transform")
 /* Action with the result ACTRES_FORTIFY */
-#define SPECENUM_VALUE15 ACTIVITY_FORTIFYING
-#define SPECENUM_VALUE15NAME N_("Fortifying")
-/* Action with the result ACTRES_CLEAN_FALLOUT */
-#define SPECENUM_VALUE16 ACTIVITY_FALLOUT
-#define SPECENUM_VALUE16NAME N_("Fallout")
-/* Unused */
-#define SPECENUM_VALUE17 ACTIVITY_PATROL_UNUSED
-#define SPECENUM_VALUE17NAME "Unused Patrol"
+#define SPECENUM_VALUE10 ACTIVITY_FORTIFYING
+#define SPECENUM_VALUE10NAME N_("Fortifying")
+/* Action with the result ACTRES_CLEAN */
+#define SPECENUM_VALUE11 ACTIVITY_CLEAN
+#define SPECENUM_VALUE11NAME N_("Clean")
 /* Action with the result ACTRES_BASE */
-#define SPECENUM_VALUE18 ACTIVITY_BASE
-#define SPECENUM_VALUE18NAME N_("Base")
+#define SPECENUM_VALUE12 ACTIVITY_BASE
+#define SPECENUM_VALUE12NAME N_("Base")
 /* Action with the result ACTRES_ROAD */
-#define SPECENUM_VALUE19 ACTIVITY_GEN_ROAD
-#define SPECENUM_VALUE19NAME N_("Road")
+#define SPECENUM_VALUE13 ACTIVITY_GEN_ROAD
+#define SPECENUM_VALUE13NAME N_("Road")
 /* Action with the result ACTRES_CONVERT */
-#define SPECENUM_VALUE20 ACTIVITY_CONVERT
-#define SPECENUM_VALUE20NAME N_("Convert")
-/* Action with the result ACTRES_CULTIVATE */
-#define SPECENUM_VALUE21 ACTIVITY_CULTIVATE
-#define SPECENUM_VALUE21NAME N_("Cultivate")
+#define SPECENUM_VALUE14 ACTIVITY_CONVERT
+#define SPECENUM_VALUE14NAME N_("Convert")
 /* Action with the result ACTRES_PLANT */
-#define SPECENUM_VALUE22 ACTIVITY_PLANT
-#define SPECENUM_VALUE22NAME N_("Plant")
+#define SPECENUM_VALUE15 ACTIVITY_PLANT
+#define SPECENUM_VALUE15NAME N_("Plant")
 /* Number of activities */
 #define SPECENUM_COUNT ACTIVITY_LAST
 #include "specenum_gen.h"
 
 /* Values used in the network protocol. */
+/* Update also properties table on actres.c when touching this. */
 #define SPECENUM_NAME action_result
 #define SPECENUM_VALUE0 ACTRES_ESTABLISH_EMBASSY
 #define SPECENUM_VALUE0NAME "Unit Establish Embassy"
@@ -265,12 +279,12 @@ enum output_type_id {
 #define SPECENUM_VALUE44NAME "Unit Build Mine"
 #define SPECENUM_VALUE45 ACTRES_IRRIGATE
 #define SPECENUM_VALUE45NAME "Unit Build Irrigation"
-#define SPECENUM_VALUE46 ACTRES_CLEAN_POLLUTION
-#define SPECENUM_VALUE46NAME "Unit Clean Pollution"
-#define SPECENUM_VALUE47 ACTRES_CLEAN_FALLOUT
-#define SPECENUM_VALUE47NAME "Unit Clean Fallout"
-#define SPECENUM_VALUE48 ACTRES_TRANSPORT_ALIGHT
-#define SPECENUM_VALUE48NAME "Unit Transport Alight"
+#define SPECENUM_VALUE46 ACTRES_COLLECT_RANSOM
+#define SPECENUM_VALUE46NAME "Collect Ransom"
+#define SPECENUM_VALUE47 ACTRES_TRANSPORT_LOAD
+#define SPECENUM_VALUE47NAME "Unit Transport Load"
+#define SPECENUM_VALUE48 ACTRES_TRANSPORT_DEBOARD
+#define SPECENUM_VALUE48NAME "Unit Transport Deboard"
 #define SPECENUM_VALUE49 ACTRES_TRANSPORT_UNLOAD
 #define SPECENUM_VALUE49NAME "Unit Transport Unload"
 #define SPECENUM_VALUE50 ACTRES_TRANSPORT_DISEMBARK
@@ -295,11 +309,24 @@ enum output_type_id {
 #define SPECENUM_VALUE59NAME "Unit Paradrop Conquer"
 #define SPECENUM_VALUE60 ACTRES_HOMELESS
 #define SPECENUM_VALUE60NAME "Unit Make Homeless"
+#define SPECENUM_VALUE61 ACTRES_WIPE_UNITS
+#define SPECENUM_VALUE61NAME "Wipe Units"
+#define SPECENUM_VALUE62 ACTRES_SPY_ESCAPE
+#define SPECENUM_VALUE62NAME "Unit Spy Escape"
+#define SPECENUM_VALUE63 ACTRES_CLEAN
+#define SPECENUM_VALUE63NAME "Clean"
+/* TODO: Move close to "Move" */
+#define SPECENUM_VALUE64 ACTRES_TELEPORT
+#define SPECENUM_VALUE64NAME "Teleport"
+#define SPECENUM_VALUE65 ACTRES_TELEPORT_CONQUER
+#define SPECENUM_VALUE65NAME "Teleport Conquer"
+/* Hardcoded action that's just controlled by enablers */
+#define SPECENUM_VALUE66 ACTRES_ENABLER_CHECK
 /* All consequences are handled as (ruleset) action data. */
-#define SPECENUM_COUNT ACTRES_NONE
+#define SPECENUM_COUNT ACTRES_LAST
 #include "specenum_gen.h"
 
-#define ACTRES_LAST ACTRES_NONE
+#define ACTRES_NONE ACTRES_LAST
 
 /* Used in the network protocol. */
 #define SPECENUM_NAME action_sub_result
@@ -313,6 +340,9 @@ enum output_type_id {
  * target tile. */
 #define SPECENUM_VALUE2 ACT_SUB_RES_MAY_EMBARK
 #define SPECENUM_VALUE2NAME "Unit May Embark"
+/* Target units won't be killed by this action. */
+#define SPECENUM_VALUE3 ACT_SUB_RES_NON_LETHAL
+#define SPECENUM_VALUE3NAME "Non Lethal To Target Unit"
 #define SPECENUM_BITVECTOR bv_action_sub_results
 #define SPECENUM_COUNT ACT_SUB_RES_COUNT
 #include "specenum_gen.h"
@@ -461,24 +491,29 @@ const char *ai_level_name_update_cb(const char *old);
 /* Used in the network protocol. */
 /* server/commands.c must match these */
 #define SPECENUM_NAME ai_level
-#define SPECENUM_VALUE0 AI_LEVEL_AWAY
-#define SPECENUM_VALUE0NAME N_("Away")
-#define SPECENUM_VALUE1 AI_LEVEL_RESTRICTED
-#define SPECENUM_VALUE1NAME N_("Restricted")
-#define SPECENUM_VALUE2 AI_LEVEL_NOVICE
-#define SPECENUM_VALUE2NAME N_("Novice")
-#define SPECENUM_VALUE3 AI_LEVEL_EASY
-#define SPECENUM_VALUE3NAME N_("Easy")
-#define SPECENUM_VALUE4 AI_LEVEL_NORMAL
-#define SPECENUM_VALUE4NAME N_("Normal")
-#define SPECENUM_VALUE5 AI_LEVEL_HARD
-#define SPECENUM_VALUE5NAME N_("Hard")
-#define SPECENUM_VALUE6 AI_LEVEL_CHEATING
-#define SPECENUM_VALUE6NAME N_("Cheating")
+#define SPECENUM_VALUE0 AI_LEVEL_RESTRICTED
+#define SPECENUM_VALUE0NAME N_("Restricted")
+#define SPECENUM_VALUE1 AI_LEVEL_NOVICE
+#define SPECENUM_VALUE1NAME N_("Novice")
+#define SPECENUM_VALUE2 AI_LEVEL_EASY
+#define SPECENUM_VALUE2NAME N_("Easy")
+#define SPECENUM_VALUE3 AI_LEVEL_NORMAL
+#define SPECENUM_VALUE3NAME N_("Normal")
+#define SPECENUM_VALUE4 AI_LEVEL_HARD
+#define SPECENUM_VALUE4NAME N_("Hard")
+#define SPECENUM_VALUE5 AI_LEVEL_CHEATING
+#define SPECENUM_VALUE5NAME N_("Cheating")
 
 #ifdef FREECIV_DEBUG
-#define SPECENUM_VALUE7 AI_LEVEL_EXPERIMENTAL
-#define SPECENUM_VALUE7NAME N_("Experimental")
+#define SPECENUM_VALUE6 AI_LEVEL_EXPERIMENTAL
+#define SPECENUM_VALUE6NAME N_("Experimental")
+/* Away must be the last, so ailevel_name() can terminate list
+ * of level names before it. */
+#define SPECENUM_VALUE7 AI_LEVEL_AWAY
+#define SPECENUM_VALUE7NAME N_("Away")
+#else  /* FREECIV_DEBUG */
+#define SPECENUM_VALUE6 AI_LEVEL_AWAY
+#define SPECENUM_VALUE6NAME N_("Away")
 #endif /* FREECIV_DEBUG */
 
 #define SPECENUM_COUNT AI_LEVEL_COUNT
@@ -511,6 +546,12 @@ const char *ai_level_name_update_cb(const char *old);
 #define SPECENUM_VALUE1NAME "Claimed"
 #define SPECENUM_VALUE2 CITYT_EXTRAS_OWNED
 #define SPECENUM_VALUE2NAME "Extras Owned"
+#define SPECENUM_VALUE3 CITYT_WORKED
+#define SPECENUM_VALUE3NAME "Worked"
+#define SPECENUM_VALUE4 CITYT_SAME_CONTINENT
+#define SPECENUM_VALUE4NAME "Same Continent"
+#define SPECENUM_VALUE5 CITYT_BORDERING_TCLASS_REGION
+#define SPECENUM_VALUE5NAME "Bordering TClass Region"
 #define SPECENUM_COUNT CITYT_LAST
 #include "specenum_gen.h"
 
@@ -522,9 +563,30 @@ const char *ai_level_name_update_cb(const char *old);
 #define SPECENUM_NAME citystatus_type
 #define SPECENUM_VALUE0 CITYS_OWNED_BY_ORIGINAL
 #define SPECENUM_VALUE0NAME "OwnedByOriginal"
+#define SPECENUM_VALUE1 CITYS_STARVED
+#define SPECENUM_VALUE1NAME "Starved"
+#define SPECENUM_VALUE2 CITYS_DISORDER
+#define SPECENUM_VALUE2NAME "Disorder"
+#define SPECENUM_VALUE3 CITYS_CELEBRATION
+#define SPECENUM_VALUE3NAME "Celebration"
+#define SPECENUM_VALUE4 CITYS_TRANSFERRED
+#define SPECENUM_VALUE4NAME "Transferred"
 #define SPECENUM_COUNT CITYS_LAST
 #include "specenum_gen.h"
 
+/*
+ * PlayerState requirement types.
+ *
+ * Used in the network protocol
+ */
+#define SPECENUM_NAME plrstate_type
+#define SPECENUM_VALUE0 PLRS_BARBARIAN
+#define SPECENUM_VALUE0NAME "Barbarian"
+#define SPECENUM_VALUE1 PLRS_HAS_CAPITAL
+#define SPECENUM_VALUE1NAME "HasCapital"
+#define SPECENUM_COUNT PLRS_LAST
+#include "specenum_gen.h"
+
 /*
  * UnitState requirement property types.
  *
@@ -548,21 +610,30 @@ const char *ai_level_name_update_cb(const char *old);
 #define SPECENUM_COUNT USP_COUNT
 #include "specenum_gen.h"
 
-/* Changing these values will break map_init_topology.
+/* Changing these values will break map_init_topology().
  * Changing the names will break file format compatibility. */
 #define SPECENUM_NAME topo_flag
 #define SPECENUM_BITWISE
-#define SPECENUM_VALUE0 TF_WRAPX
-#define SPECENUM_VALUE0NAME N_("WrapX")
-#define SPECENUM_VALUE1 TF_WRAPY
-#define SPECENUM_VALUE1NAME N_("WrapY")
-#define SPECENUM_VALUE2 TF_ISO
-#define SPECENUM_VALUE2NAME N_("ISO")
-#define SPECENUM_VALUE3 TF_HEX
-#define SPECENUM_VALUE3NAME N_("Hex")
+#define SPECENUM_VALUE0 TF_ISO
+#define SPECENUM_VALUE0NAME N_("ISO")
+#define SPECENUM_VALUE1 TF_HEX
+#define SPECENUM_VALUE1NAME N_("Hex")
+#define SPECENUM_VALUE2 TF_OLD_WRAPX
+#define SPECENUM_VALUE2NAME N_("WrapX")
+#define SPECENUM_VALUE3 TF_OLD_WRAPY
+#define SPECENUM_VALUE3NAME N_("WrapY")
 #define TOPO_FLAG_BITS  4
 #include "specenum_gen.h"
 
+#define SPECENUM_NAME wrap_flag
+#define SPECENUM_BITWISE
+#define SPECENUM_VALUE0 WRAP_X
+#define SPECENUM_VALUE0NAME N_("WrapX")
+#define SPECENUM_VALUE1 WRAP_Y
+#define SPECENUM_VALUE1NAME N_("WrapY")
+#define WRAP_FLAG_BITS  2
+#include "specenum_gen.h"
+
 /* Used in the network protocol. */
 #define SPECENUM_NAME impr_genus_id
 #define SPECENUM_VALUE0 IG_GREAT_WONDER
@@ -573,9 +644,53 @@ const char *ai_level_name_update_cb(const char *old);
 #define SPECENUM_VALUE2NAME "Improvement"
 #define SPECENUM_VALUE3 IG_SPECIAL
 #define SPECENUM_VALUE3NAME "Special"
+#define SPECENUM_VALUE4 IG_CONVERT
+#define SPECENUM_VALUE4NAME "Convert"
 #define SPECENUM_COUNT  IG_COUNT
 #include "specenum_gen.h"
 
+/* Used in the network protocol. */
+#define SPECENUM_NAME impr_flag_id
+/* Improvement should be visible to others without spying */
+#define SPECENUM_VALUE0 IF_VISIBLE_BY_OTHERS
+#define SPECENUM_VALUE0NAME "VisibleByOthers"
+/* This small wonder is moved to another city if game.savepalace is on. */
+#define SPECENUM_VALUE1 IF_SAVE_SMALL_WONDER
+#define SPECENUM_VALUE1NAME "SaveSmallWonder"
+/* When built, gives gold */
+#define SPECENUM_VALUE2 IF_GOLD
+#define SPECENUM_VALUE2NAME "Gold"
+/* Never destroyed by disasters */
+#define SPECENUM_VALUE3 IF_DISASTER_PROOF
+#define SPECENUM_VALUE3NAME "DisasterProof"
+#define SPECENUM_VALUE4 IF_USER_FLAG_1
+#define SPECENUM_VALUE5 IF_USER_FLAG_2
+#define SPECENUM_VALUE6 IF_USER_FLAG_3
+#define SPECENUM_VALUE7 IF_USER_FLAG_4
+#define SPECENUM_VALUE8 IF_USER_FLAG_5
+#define SPECENUM_VALUE9 IF_USER_FLAG_6
+#define SPECENUM_VALUE10 IF_USER_FLAG_7
+#define SPECENUM_VALUE11 IF_USER_FLAG_8
+#define SPECENUM_COUNT IF_COUNT
+#define SPECENUM_NAMEOVERRIDE
+#define SPECENUM_BITVECTOR bv_impr_flags
+#include "specenum_gen.h"
+
+#define IF_LAST_USER_FLAG IF_USER_FLAG_8
+#define MAX_NUM_USER_BUILDING_FLAGS (IF_LAST_USER_FLAG - IF_USER_FLAG_1 + 1)
+
+#define SPECENUM_NAME plr_flag_id
+#define SPECENUM_VALUE0 PLRF_AI
+#define SPECENUM_VALUE0NAME "ai"
+#define SPECENUM_VALUE1 PLRF_SCENARIO_RESERVED
+#define SPECENUM_VALUE1NAME "ScenarioReserved"
+/* TRUE if player has ever had a city. */
+#define SPECENUM_VALUE2 PLRF_FIRST_CITY
+#define SPECENUM_VALUE2NAME "FirstCity"
+#define SPECENUM_COUNT  PLRF_COUNT
+#define SPECENUM_BITVECTOR bv_plr_flags
+#include "specenum_gen.h"
+
 /* A server setting + its value. */
 typedef int ssetv;
 
@@ -596,10 +711,12 @@ enum req_problem_type {
  * Used in the network protocol. */
 typedef union {
   struct advance *advance;
+  struct counter *counter;
   struct government *govern;
   const struct impr_type *building;
   struct nation_type *nation;
   struct nation_type *nationality;
+  struct nation_type *origowner;
   struct specialist *specialist;
   struct terrain *terrain;
   struct unit_class *uclass;
@@ -614,6 +731,7 @@ typedef union {
   enum ai_level ai_level;
   enum citytile_type citytile;
   enum citystatus_type citystatus;
+  enum plrstate_type plrstate;
   int minsize;
   int minculture;
   int minforeignpct;
@@ -633,14 +751,19 @@ typedef union {
   enum ustate_prop unit_state;
   enum unit_activity activity;
   enum impr_genus_id impr_genus;
+  enum impr_flag_id impr_flag;
+  enum plr_flag_id plr_flag;
   int minmoves;
   int max_tile_units;
   int minveteran;
   int min_hit_points;
   int age;
+  int form_age;
   int min_techs;
+  int latitude;
 
   enum topo_flag topo_property;
+  enum wrap_flag wrap_property;
   ssetv ssetval;
 } universals_u;
 
@@ -750,6 +873,27 @@ typedef union {
 #define SPECENUM_VALUE47NAME "DiplRelUnitAny"
 #define SPECENUM_VALUE48 VUT_DIPLREL_UNITANY_O
 #define SPECENUM_VALUE48NAME "DiplRelUnitAnyOther"
+#define SPECENUM_VALUE49 VUT_MINLATITUDE
+#define SPECENUM_VALUE49NAME "MinLatitude"
+#define SPECENUM_VALUE50 VUT_MAXLATITUDE
+#define SPECENUM_VALUE50NAME "MaxLatitude"
+#define SPECENUM_VALUE51 VUT_COUNTER
+#define SPECENUM_VALUE51NAME "Counter"
+#define SPECENUM_VALUE52 VUT_ORIGINAL_OWNER
+#define SPECENUM_VALUE52NAME "OriginalOwner"
+#define SPECENUM_VALUE53 VUT_IMPR_FLAG
+#define SPECENUM_VALUE53NAME "BuildingFlag"
+#define SPECENUM_VALUE54 VUT_WRAP
+#define SPECENUM_VALUE54NAME "Wrap"
+#define SPECENUM_VALUE55 VUT_PLAYER_FLAG
+#define SPECENUM_VALUE55NAME "PlayerFlag"
+#define SPECENUM_VALUE56 VUT_PLAYER_STATE
+#define SPECENUM_VALUE56NAME "PlayerState"
+#define SPECENUM_VALUE57 VUT_FORM_AGE
+#define SPECENUM_VALUE57NAME "FormAge"
+#define SPECENUM_VALUE58 VUT_SITE
+#define SPECENUM_VALUE58NAME "Site"
+
 /* Keep this last. */
 #define SPECENUM_COUNT VUT_COUNT
 #include "specenum_gen.h"
@@ -757,7 +901,7 @@ typedef union {
 /* Used in the network protocol. */
 struct universal {
   universals_u value;
-  enum universals_n kind;		/* formerly .type and .is_unit */
+  enum universals_n kind;               /* Formerly .type and .is_unit */
 };
 
 /* Used in the network protocol. */
@@ -778,18 +922,20 @@ BV_DEFINE(bv_startpos_nations, MAX_NUM_STARTPOS_NATIONS);
 #define SPECENUM_VALUE2NAME "gtk3"
 #define SPECENUM_VALUE3 GUI_GTK3_22
 #define SPECENUM_VALUE3NAME "gtk3.22"
+#define SPECENUM_VALUE4 GUI_QT
+#define SPECENUM_VALUE4NAME "qt"
 /* GUI_SDL remains for now for keeping client options alive until
  * user has migrated them to sdl2-client */
-#define SPECENUM_VALUE4 GUI_SDL
-#define SPECENUM_VALUE4NAME "sdl"
-#define SPECENUM_VALUE5 GUI_QT
-#define SPECENUM_VALUE5NAME "qt"
+#define SPECENUM_VALUE5 GUI_SDL
+#define SPECENUM_VALUE5NAME "sdl"
 #define SPECENUM_VALUE6 GUI_SDL2
 #define SPECENUM_VALUE6NAME "sdl2"
-#define SPECENUM_VALUE7 GUI_WEB
-#define SPECENUM_VALUE7NAME "web"
-#define SPECENUM_VALUE8 GUI_GTK4
-#define SPECENUM_VALUE8NAME "gtk4"
+#define SPECENUM_VALUE7 GUI_SDL3
+#define SPECENUM_VALUE7NAME "sdl3"
+#define SPECENUM_VALUE8 GUI_WEB
+#define SPECENUM_VALUE8NAME "web"
+#define SPECENUM_VALUE9 GUI_GTK4
+#define SPECENUM_VALUE9NAME "gtk4"
 #include "specenum_gen.h"
 
 /* Used in the network protocol. */
@@ -980,14 +1126,12 @@ FC_STATIC_ASSERT(EC_COUNT < 16, extra_causes_over_limit);
 #define SPECENUM_NAME extra_rmcause
 #define SPECENUM_VALUE0 ERM_PILLAGE
 #define SPECENUM_VALUE0NAME "Pillage"
-#define SPECENUM_VALUE1 ERM_CLEANPOLLUTION
-#define SPECENUM_VALUE1NAME "CleanPollution"
-#define SPECENUM_VALUE2 ERM_CLEANFALLOUT
-#define SPECENUM_VALUE2NAME "CleanFallout"
-#define SPECENUM_VALUE3 ERM_DISAPPEARANCE
-#define SPECENUM_VALUE3NAME "Disappear"
-#define SPECENUM_VALUE4 ERM_ENTER
-#define SPECENUM_VALUE4NAME "Enter"
+#define SPECENUM_VALUE1 ERM_CLEAN
+#define SPECENUM_VALUE1NAME "Clean"
+#define SPECENUM_VALUE2 ERM_DISAPPEARANCE
+#define SPECENUM_VALUE2NAME "Disappear"
+#define SPECENUM_VALUE3 ERM_ENTER
+#define SPECENUM_VALUE3NAME "Enter"
 #define SPECENUM_COUNT ERM_COUNT
 #define SPECENUM_BITVECTOR bv_rmcauses
 #include "specenum_gen.h"
@@ -1025,6 +1169,10 @@ FC_STATIC_ASSERT(ERM_COUNT < 8, extra_rmcauses_over_limit);
 #define SPECENUM_VALUE8NAME "Literate"
 #define SPECENUM_VALUE9 ACHIEVEMENT_LAND_AHOY
 #define SPECENUM_VALUE9NAME "Land_Ahoy"
+#define SPECENUM_VALUE10 ACHIEVEMENT_KILLER
+#define SPECENUM_VALUE10NAME "Killer"
+#define SPECENUM_VALUE11 ACHIEVEMENT_RICH
+#define SPECENUM_VALUE11NAME "Rich"
 #define SPECENUM_COUNT ACHIEVEMENT_COUNT
 #include "specenum_gen.h"
 
@@ -1110,7 +1258,7 @@ enum road_compat { ROCO_ROAD, ROCO_RAILROAD, ROCO_RIVER, ROCO_NONE };
  * Maximum number of trade routes a city can have in any situation.
  * Changing this changes network protocol.
  */
-#define MAX_TRADE_ROUTES        5
+#define MAX_TRADE_ROUTES        20
 
 /* Used in the network protocol. */
 #define SPECENUM_NAME goods_selection_method
@@ -1234,6 +1382,8 @@ typedef float adv_want;
 #define SPECENUM_VALUE0NAME "Always"
 #define SPECENUM_VALUE1 WV_NEVER
 #define SPECENUM_VALUE1NAME "Never"
+#define SPECENUM_VALUE2 WV_EMBASSY
+#define SPECENUM_VALUE2NAME "Embassy"
 #include "specenum_gen.h"
 
 /* Used in the network protocol. */
@@ -1242,6 +1392,16 @@ typedef float adv_want;
 #define SPECENUM_VALUE0NAME "Alight"
 #define SPECENUM_VALUE1 TDT_BLOCKED
 #define SPECENUM_VALUE1NAME "Blocked"
+#define SPECENUM_VALUE2 TDT_ALWAYS
+#define SPECENUM_VALUE2NAME "Always"
+#include "specenum_gen.h"
+
+/* Used in the savegames, by numeric value. */
+#define SPECENUM_NAME city_acquire_type
+#define SPECENUM_VALUE0 CACQ_CONQUEST
+#define SPECENUM_VALUE0NAME "Conquest"
+#define SPECENUM_VALUE1 CACQ_FOUNDED
+#define SPECENUM_VALUE1NAME "Founded"
 #include "specenum_gen.h"
 
 #ifdef __cplusplus
