@@ -30,18 +30,23 @@
 #include "ai.h"
 #include "achievements.h"
 #include "actions.h"
+#include "actres.h"
 #include "city.h"
 #include "connection.h"
+#include "counters.h"
+#include "diptreaty.h"
 #include "disaster.h"
 #include "extras.h"
 #include "government.h"
 #include "idex.h"
 #include "map.h"
+#include "modpack.h"
 #include "multipliers.h"
 #include "nation.h"
 #include "packets.h"
 #include "player.h"
 #include "research.h"
+#include "rgbcolor.h"
 #include "spaceship.h"
 #include "specialist.h"
 #include "style.h"
@@ -230,7 +235,7 @@ static void game_defaults(bool keep_ruleset_value)
   game.control.preferred_tileset[0]    = '\0';
   game.control.preferred_soundset[0]   = '\0';
   game.control.preferred_musicset[0]   = '\0';
-  game.control.styles_count            = 0;
+  game.control.num_city_styles         = 0;
   game.control.terrain_count           = 0;
 
   game.ruleset_summary       = NULL;
@@ -298,6 +303,7 @@ static void game_defaults(bool keep_ruleset_value)
   game.info.warminglevel     = 0; /* set later */
   game.info.year_0_hack      = FALSE;
   game.info.year             = GAME_DEFAULT_START_YEAR;
+  game.info.top_cities_count = GAME_DEFAULT_TOP_CITIES_COUNT;
   BV_CLR_ALL(game.info.diplchance_initial_odds);
 
   /* The scenario packets. */
@@ -319,9 +325,11 @@ static void game_defaults(bool keep_ruleset_value)
   /* Veteran system. */
   game.veteran = NULL;
 
-  /* player colors */
+  /* Player colors */
   game.plr_bg_color = NULL;
 
+  game.lua_timeout = GAME_DEFAULT_LUA_TIMEOUT;
+
   if (is_server()) {
     /* All settings only used by the server (./server/ and ./ai/ */
     sz_strlcpy(game.server.allow_take, GAME_DEFAULT_ALLOW_TAKE);
@@ -401,7 +409,7 @@ static void game_defaults(bool keep_ruleset_value)
     game.server.scoreturn         = GAME_DEFAULT_SCORETURN - 1;
     game.server.seed              = GAME_DEFAULT_SEED;
     sz_strlcpy(game.server.start_units, GAME_DEFAULT_START_UNITS);
-    game.server.spaceship_travel_time = GAME_DEFAULT_SPACESHIP_TRAVEL_TIME;
+    game.server.spaceship_travel_pct = GAME_DEFAULT_SPACESHIP_TRAVEL_PCT;
     game.server.start_year        = GAME_DEFAULT_START_YEAR;
     game.server.tcptimeout        = GAME_DEFAULT_TCPTIMEOUT;
     game.server.techlost_donor    = GAME_DEFAULT_TECHLOST_DONOR;
@@ -416,6 +424,7 @@ static void game_defaults(bool keep_ruleset_value)
     game.server.turnblock         = GAME_DEFAULT_TURNBLOCK;
     game.server.unitwaittime      = GAME_DEFAULT_UNITWAITTIME;
     game.server.plr_colors        = NULL;
+    game.server.random_move_time  = NULL;
   } else {
     /* Client side takes care of itself in client_main() */
   }
@@ -428,6 +437,7 @@ static void game_defaults(bool keep_ruleset_value)
 **************************************************************************/
 void game_init(bool keep_ruleset_value)
 {
+  modpacks_init();
   game_defaults(keep_ruleset_value);
   player_slots_init();
   map_init(&wld.map, is_server());
@@ -437,6 +447,7 @@ void game_init(bool keep_ruleset_value)
   cm_init();
   researches_init();
   universal_found_functions_init();
+  treaties_init();
 }
 
 /**********************************************************************//**
@@ -458,6 +469,7 @@ void game_map_init(void)
 **************************************************************************/
 void game_free(void)
 {
+  treaties_free();
   player_slots_free();
   main_map_free();
   free_city_map_index();
@@ -466,6 +478,7 @@ void game_free(void)
   game_ruleset_free();
   researches_free();
   cm_free();
+  modpacks_free();
 }
 
 /**********************************************************************//**
@@ -502,6 +515,7 @@ void game_ruleset_init(void)
   ruleset_cache_init();
   disaster_types_init();
   achievements_init();
+  actres_init();
   actions_init();
   trade_route_types_init();
   terrains_init();
@@ -516,13 +530,16 @@ void game_ruleset_init(void)
   user_unit_type_flags_init();
   user_terrain_flags_init();
   user_extra_flags_init();
+  user_impr_flags_init();
   tech_classes_init();
   user_tech_flags_init();
   multipliers_init();
   clause_infos_init();
+  counters_init();
 
   if (is_server()) {
     game.server.luadata = NULL;
+    game.server.dbid = -1;
     game.server.ruledit.nationlist = NULL;
     game.server.ruledit.embedded_nations = NULL;
     game.server.ruledit.embedded_nations_count = 0;
@@ -570,16 +587,19 @@ void game_ruleset_free(void)
   city_styles_free();
   styles_free();
   actions_free();
+  actres_free();
   achievements_free();
   disaster_types_free();
   terrains_free();
   user_tech_flags_free();
   extra_flags_free();
+  impr_flags_free();
   user_terrain_flags_free();
   ruleset_cache_free();
   nation_sets_groups_free();
   multipliers_free();
   clause_infos_free();
+  counters_free();
 
   /* Destroy the default veteran system. */
   veteran_system_destroy(game.veteran);
