@@ -40,6 +40,8 @@ The improvement_types array is now setup in:
 **************************************************************************/
 static struct impr_type improvement_types[B_LAST];
 
+static struct user_flag user_impr_flags[MAX_NUM_USER_BUILDING_FLAGS];
+
 /**********************************************************************//**
   Initialize building structures.
 **************************************************************************/
@@ -307,8 +309,8 @@ int impr_buy_gold_cost(const struct city *pcity,
   int cost = 0;
   const int missing = impr_build_shield_cost(pcity, pimprove) - shields_in_stock;
 
-  if (improvement_has_flag(pimprove, IF_GOLD)) {
-    /* Can't buy capitalization. */
+  if (is_convert_improvement(pimprove)) {
+    /* Can't buy coinage-like improvements. */
     return 0;
   }
 
@@ -432,6 +434,8 @@ bool improvement_obsolete(const struct player *pplayer,
 static bool impr_provides_buildable_units(const struct city *pcity,
                                           const struct impr_type *pimprove)
 {
+  const struct civ_map *nmap = &(wld.map);
+
   /* Fast check */
   if (!pimprove->allows_units) {
     return FALSE;
@@ -439,7 +443,7 @@ static bool impr_provides_buildable_units(const struct city *pcity,
 
   unit_type_iterate(ut) {
     if (requirement_needs_improvement(pimprove, &ut->build_reqs)
-        && can_city_build_unit_now(pcity, ut)) {
+        && can_city_build_unit_now(nmap, pcity, ut)) {
       return TRUE;
     }
   } unit_type_iterate_end;
@@ -453,6 +457,7 @@ static bool impr_provides_buildable_units(const struct city *pcity,
 static bool impr_provides_buildable_extras(const struct city *pcity,
                                            const struct impr_type *pimprove)
 {
+  const struct civ_map *nmap = &(wld.map);
 
   /* Fast check */
   if (!pimprove->allows_extras) {
@@ -461,7 +466,7 @@ static bool impr_provides_buildable_extras(const struct city *pcity,
 
   extra_type_iterate(pextra) {
     if (requirement_needs_improvement(pimprove, &pextra->reqs)) {
-      city_tile_iterate(city_map_radius_sq_get(pcity),
+      city_tile_iterate(nmap, city_map_radius_sq_get(pcity),
                         city_tile(pcity), ptile) {
         if (player_can_build_extra(pextra, city_owner(pcity), ptile)) {
           return TRUE;
@@ -508,9 +513,10 @@ static bool impr_protects_vs_actions(const struct city *pcity,
     return FALSE;
   }
 
-  action_enablers_iterate(act) {
-    if (!requirement_fulfilled_by_improvement(pimprove, &act->target_reqs)
-        && !is_action_possible_on_city(act->action, NULL, pcity)) {
+  action_enablers_iterate(enabler) {
+    if (!requirement_fulfilled_by_improvement(pimprove, &enabler->target_reqs)
+        && !is_action_possible_on_city(enabler_get_action_id(enabler),
+                                       NULL, pcity)) {
       return TRUE;
     }
   } action_enablers_iterate_end;
@@ -519,22 +525,26 @@ static bool impr_protects_vs_actions(const struct city *pcity,
 }
 
 /**********************************************************************//**
-  Returns TRUE iff improvement allows its owner to perform an action
+  Returns TRUE iff improvement allows its owner to perform an action.
 **************************************************************************/
 static bool impr_allows_actions(const struct city *pcity,
                                 const struct impr_type *pimprove)
 {
+  const struct civ_map *nmap = &(wld.map);
+
   /* Fast check */
   if (!pimprove->allows_actions) {
     return FALSE;
   }
 
-  action_enablers_iterate(act) {
-    if (requirement_needs_improvement(pimprove, &act->actor_reqs)) {
-      switch (action_id_get_actor_kind(act->action)) {
+  action_enablers_iterate(enabler) {
+    if (requirement_needs_improvement(pimprove, &enabler->actor_reqs)) {
+      action_id act = enabler_get_action_id(enabler);
+
+      switch (action_id_get_actor_kind(act)) {
       case AAK_UNIT:
         unit_type_iterate(ut) {
-          if (!utype_can_do_action(ut, act->action)) {
+          if (!utype_can_do_action(ut, act)) {
             /* Not relevant */
             continue;
           }
@@ -544,14 +554,14 @@ static bool impr_allows_actions(const struct city *pcity,
             return TRUE;
           }
 
-          if (can_city_build_unit_now(pcity, ut)) {
+          if (can_city_build_unit_now(nmap, pcity, ut)) {
             /* This city can build a unit that uses the building */
             return TRUE;
           }
         } unit_type_iterate_end;
         break;
       case AAK_COUNT:
-        fc_assert(action_id_get_actor_kind(act->action) != AAK_COUNT);
+        fc_assert(action_id_get_actor_kind(act) != AAK_COUNT);
         break;
       }
     }
@@ -790,7 +800,21 @@ bool is_improvement(const struct impr_type *pimprove)
 **************************************************************************/
 bool is_special_improvement(const struct impr_type *pimprove)
 {
-  return pimprove->genus == IG_SPECIAL;
+  /* TODO: Find either a new term for traditional "special" improvements
+   * (maybe "project"?), or a new umbrella term for all improvements that
+   * can't be present in the city as a finished building (including special
+   * and convert improvements). */
+  return (pimprove->genus == IG_SPECIAL)
+      || is_convert_improvement(pimprove);
+}
+
+/**********************************************************************//**
+  Is this a coinage-like improvement that converts production into some
+  other form of output?
+**************************************************************************/
+bool is_convert_improvement(const struct impr_type *pimprove)
+{
+  return (pimprove->genus == IG_CONVERT);
 }
 
 /**********************************************************************//**
@@ -916,10 +940,15 @@ struct city *city_from_wonder(const struct player *pplayer,
 
 /**********************************************************************//**
   Can the player see wonder owned by the other player?
+
+  Embassy can be passed as parameter so that caller can make the somewhat
+  costly embassy detection just once even when calling this multiple
+  times (e.g. for number of different wonders)
 **************************************************************************/
 bool wonder_visible_to_player(const struct impr_type *wonder,
                               const struct player *pplayer,
-                              const struct player *owner)
+                              const struct player *owner,
+                              enum fc_tristate embassy)
 {
   if (pplayer == owner) {
     /* Can see all own wonders,
@@ -937,6 +966,9 @@ bool wonder_visible_to_player(const struct impr_type *wonder,
       return TRUE;
     case WV_NEVER:
       return FALSE;
+    case WV_EMBASSY:
+      return embassy == TRI_YES
+        || (embassy == TRI_MAYBE && team_has_embassy(pplayer->team, owner));
     }
 
     fc_assert(FALSE);
@@ -1062,7 +1094,8 @@ struct city *city_from_small_wonder(const struct player *pplayer,
 **************************************************************************/
 bool can_sell_building(const struct impr_type *pimprove)
 {
-  return (valid_improvement(pimprove) && is_improvement(pimprove));
+  return (valid_improvement(pimprove)
+          && is_building_sellable(pimprove));
 }
 
 /**********************************************************************//**
@@ -1071,7 +1104,16 @@ bool can_sell_building(const struct impr_type *pimprove)
 bool can_city_sell_building(const struct city *pcity,
                             const struct impr_type *pimprove)
 {
-  return (city_has_building(pcity, pimprove) && is_improvement(pimprove));
+  return (city_has_building(pcity, pimprove)
+          && is_building_sellable(pimprove));
+}
+
+/**********************************************************************//**
+  Return TRUE iff the building is sellable one.
+**************************************************************************/
+bool is_building_sellable(const struct impr_type *pimprove)
+{
+  return is_improvement(pimprove);
 }
 
 /**********************************************************************//**
@@ -1115,3 +1157,78 @@ const struct impr_type *improvement_replacement(const struct impr_type *pimprove
 
   return NULL;
 }
+
+/************************************************************************//**
+  Initialize user building flags.
+****************************************************************************/
+void user_impr_flags_init(void)
+{
+  int i;
+
+  for (i = 0; i < MAX_NUM_USER_BUILDING_FLAGS; i++) {
+    user_flag_init(&user_impr_flags[i]);
+  }
+}
+
+/************************************************************************//**
+  Frees the memory associated with all building flags
+****************************************************************************/
+void impr_flags_free(void)
+{
+  int i;
+
+  for (i = 0; i < MAX_NUM_USER_BUILDING_FLAGS; i++) {
+    user_flag_free(&user_impr_flags[i]);
+  }
+}
+
+/************************************************************************//**
+  Sets user defined name for building flag.
+****************************************************************************/
+void set_user_impr_flag_name(enum impr_flag_id id, const char *name,
+                              const char *helptxt)
+{
+  int bfid = id - IF_USER_FLAG_1;
+
+  fc_assert_ret(id >= IF_USER_FLAG_1 && id <= IF_LAST_USER_FLAG);
+
+  if (user_impr_flags[bfid].name != NULL) {
+    FC_FREE(user_impr_flags[bfid].name);
+    user_impr_flags[bfid].name = NULL;
+  }
+
+  if (name && name[0] != '\0') {
+    user_impr_flags[bfid].name = fc_strdup(name);
+  }
+
+  if (user_impr_flags[bfid].helptxt != NULL) {
+    free(user_impr_flags[bfid].helptxt);
+    user_impr_flags[bfid].helptxt = NULL;
+  }
+
+  if (helptxt && helptxt[0] != '\0') {
+    user_impr_flags[bfid].helptxt = fc_strdup(helptxt);
+  }
+}
+
+/************************************************************************//**
+  Building flag name callback, called from specenum code.
+****************************************************************************/
+const char *impr_flag_id_name_cb(enum impr_flag_id flag)
+{
+  if (flag < IF_USER_FLAG_1 || flag > IF_LAST_USER_FLAG) {
+    return NULL;
+  }
+
+  return user_impr_flags[flag - IF_USER_FLAG_1].name;
+}
+
+/************************************************************************//**
+  Return the (untranslated) help text of the user building flag.
+****************************************************************************/
+const char *impr_flag_helptxt(enum impr_flag_id id)
+{
+  fc_assert(id >= IF_USER_FLAG_1 && id <= IF_LAST_USER_FLAG);
+
+  return user_impr_flags[id - IF_USER_FLAG_1].helptxt;
+}
