@@ -22,14 +22,16 @@ extern "C" {
 /* utility */
 #include "bitvector.h"
 #include "iterator.h"
-#include "log.h"                /* fc_assert */
+#include "log.h"                /* fc_assert() */
 
 /* common */
 #include "fc_types.h"
 #include "game.h"
 #include "map_types.h"
-#include "tile.h"
 #include "packets.h"
+#include "world_object.h"
+
+struct tile;
 
 /* Parameters for terrain counting functions. */
 static const bool C_ADJACENT = FALSE;
@@ -40,15 +42,19 @@ static const bool C_PERCENT = TRUE;
 #define MAP_IS_ISOMETRIC (CURRENT_TOPOLOGY & (TF_ISO + TF_HEX))
 
 #define CURRENT_TOPOLOGY (wld.map.topology_id)
+#define CURRENT_WRAP (wld.map.wrap_id)
 
 #define topo_has_flag(topo, flag) (((topo) & (flag)) != 0)
 #define current_topo_has_flag(flag) topo_has_flag((CURRENT_TOPOLOGY), (flag))
 
+#define wrap_has_flag(wrap, flag) (((wrap) & (flag)) != 0)
+#define current_wrap_has_flag(flag) wrap_has_flag((CURRENT_WRAP), (flag))
+
 #define ALL_DIRECTIONS_CARDINAL() topo_has_flag((CURRENT_TOPOLOGY), TF_HEX)
 
 bool map_is_empty(void);
 void map_init(struct civ_map *imap, bool server_side);
-void map_init_topology(void);
+void map_init_topology(struct civ_map *nmap);
 void map_allocate(struct civ_map *amap);
 void main_map_allocate(void);
 void map_free(struct civ_map *fmap);
@@ -280,10 +286,10 @@ int tile_move_cost_ptrs(const struct civ_map *nmap,
                         const struct player *pplayer,
                         const struct tile *t1, const struct tile *t2);
 
-/***************************************************************
+/************************************************************************//**
   The cost to move punit from where it is to tile x,y.
   It is assumed the move is a valid one, e.g. the tiles are adjacent.
-***************************************************************/
+****************************************************************************/
 static inline int map_move_cost_unit(const struct civ_map *nmap,
                                      struct unit *punit,
                                      const struct tile *ptile)
@@ -293,9 +299,9 @@ static inline int map_move_cost_unit(const struct civ_map *nmap,
                              unit_tile(punit), ptile);
 }
 
-/***************************************************************
+/************************************************************************//**
   Move cost between two tiles
-***************************************************************/
+****************************************************************************/
 static inline int map_move_cost(const struct civ_map *nmap,
                                 const struct player *pplayer,
                                 const struct unit_type *punittype,
@@ -432,14 +438,14 @@ extern struct terrain_misc terrain_control;
 /* As adjc_iterate() but also set direction8 iterator variable dir_itr */
 #define adjc_dir_iterate(nmap, center_tile, itr_tile, dir_itr)              \
   adjc_dirlist_iterate(nmap, center_tile, itr_tile, dir_itr,                \
-		       wld.map.valid_dirs, wld.map.num_valid_dirs)
+                       (nmap)->valid_dirs, (nmap)->num_valid_dirs)
 
 #define adjc_dir_iterate_end adjc_dirlist_iterate_end
 
 /* Only set direction8 dir_itr (not tile) */
 #define adjc_dir_base_iterate(nmap, center_tile, dir_itr)                \
   adjc_dirlist_base_iterate(nmap, center_tile, dir_itr,                  \
-                            wld.map.valid_dirs, wld.map.num_valid_dirs)
+                            (nmap)->valid_dirs, (nmap)->num_valid_dirs)
 
 #define adjc_dir_base_iterate_end                                              \
   adjc_dirlist_base_iterate_end
@@ -449,21 +455,21 @@ extern struct terrain_misc terrain_control;
  * position.  The order of positions is unspecified. */
 #define cardinal_adjc_iterate(nmap, center_tile, itr_tile)                \
   adjc_dirlist_iterate(nmap, center_tile, itr_tile, _dir_itr##itr_tile,   \
-		       wld.map.cardinal_dirs, wld.map.num_cardinal_dirs)
+                       (nmap)->cardinal_dirs, (nmap)->num_cardinal_dirs)
 
 #define cardinal_adjc_iterate_end adjc_dirlist_iterate_end
 
 /* As cardinal_adjc_iterate but also set direction8 variable dir_itr */
 #define cardinal_adjc_dir_iterate(nmap, center_tile, itr_tile, dir_itr)  \
   adjc_dirlist_iterate(nmap, center_tile, itr_tile, dir_itr,             \
-		       wld.map.cardinal_dirs, wld.map.num_cardinal_dirs)
+                       (nmap)->cardinal_dirs, (nmap)->num_cardinal_dirs)
 
 #define cardinal_adjc_dir_iterate_end adjc_dirlist_iterate_end
 
 /* Only set direction8 dir_itr (not tile) */
 #define cardinal_adjc_dir_base_iterate(nmap, center_tile, dir_itr)       \
   adjc_dirlist_base_iterate(nmap, center_tile, dir_itr,                  \
-                            wld.map.cardinal_dirs, wld.map.num_cardinal_dirs)
+                            (nmap)->cardinal_dirs, (nmap)->num_cardinal_dirs)
 
 #define cardinal_adjc_dir_base_iterate_end                                     \
   adjc_dirlist_base_iterate_end
@@ -498,7 +504,7 @@ extern struct terrain_misc terrain_control;
   for (;								    \
        _tile##_index < (dircount);					    \
        _tile##_index++) {						    \
-    _dir = dirlist[_tile##_index];					    \
+    _dir = (dirlist)[_tile##_index];					    \
     DIRSTEP(_tile##_x, _tile##_y, _dir);				    \
     _tile##_x += _tile##_cx;                                                \
     _tile##_y += _tile##_cy;                                                \
@@ -523,7 +529,7 @@ extern struct terrain_misc terrain_control;
   for (;                                                                       \
        _tile##_index < (dircount);                                             \
        _tile##_index++) {                                                      \
-    _dir = dirlist[_tile##_index];                                             \
+    _dir = (dirlist)[_tile##_index];                                           \
     DIRSTEP(_tile##_x, _tile##_y, _dir);                                       \
     _tile##_x += _center##_x;                                                  \
     _tile##_y += _center##_y;                                                  \
@@ -565,8 +571,36 @@ bool is_cardinal_dir(enum direction8 dir);
 extern const int DIR_DX[8];
 extern const int DIR_DY[8];
 
+/* Latitude granularity, irrespective of map/generator settings */
+#define MAP_MAX_LATITUDE           1000
+
+#define MAP_MAX_LATITUDE_BOUND     (MAP_MAX_LATITUDE)
+#define MAP_MIN_LATITUDE_BOUND     (-MAP_MAX_LATITUDE)
+#define MAP_DEFAULT_NORTH_LATITUDE MAP_MAX_LATITUDE_BOUND
+#define MAP_DEFAULT_SOUTH_LATITUDE MAP_MIN_LATITUDE_BOUND
+
+/* Northernmost and southernmost latitude for the given map */
+#define MAP_NORTH_LATITUDE(_nmap) ((_nmap).north_latitude)
+#define MAP_SOUTH_LATITUDE(_nmap) ((_nmap).south_latitude)
+
+/* Maximum and minimum latitude present in the given map */
+#define MAP_MAX_REAL_LATITUDE(_nmap) \
+  MAX(MAP_NORTH_LATITUDE(_nmap), MAP_SOUTH_LATITUDE(_nmap))
+#define MAP_MIN_REAL_LATITUDE(_nmap) \
+  MIN(MAP_NORTH_LATITUDE(_nmap), MAP_SOUTH_LATITUDE(_nmap))
+#define MAP_REAL_LATITUDE_RANGE(_nmap) \
+  (MAP_MAX_REAL_LATITUDE(_nmap) - MAP_MIN_REAL_LATITUDE(_nmap))
+
+/* Maximum and minimum absolute latitude */
+#define MAP_MAX_ABS_LATITUDE(_nmap) \
+  MAX(MAP_MAX_REAL_LATITUDE(_nmap), -MAP_MIN_REAL_LATITUDE(_nmap))
+#define MAP_MIN_ABS_LATITUDE(_nmap) \
+  MAX(0, MAX(MAP_MIN_REAL_LATITUDE(_nmap), -MAP_MAX_REAL_LATITUDE(_nmap)))
+
+int map_signed_latitude(const struct tile *ptile);
+
 /* Used for network transmission; do not change. */
-#define MAP_TILE_OWNER_NULL	 MAX_UINT8
+#define MAP_TILE_OWNER_NULL	 MAX_UINT16
 
 #define MAP_DEFAULT_HUTS         15
 #define MAP_MIN_HUTS             0
@@ -615,9 +649,11 @@ moves. Includes MAP_MAX_LINEAR_SIZE because a map can be non wrapping. */
 #define MAP_ORIGINAL_TOPO        TF_WRAPX
 #ifdef FREECIV_WEB
 /* Freeciv-web doesn't support isometric maps yet. */
-#define MAP_DEFAULT_TOPO         TF_WRAPX
+#define MAP_DEFAULT_TOPO         0
+#define MAP_DEFAULT_WRAP         WRAP_X
 #else /* FREECIV_WEB */
-#define MAP_DEFAULT_TOPO         (TF_WRAPX|TF_ISO|TF_HEX)
+#define MAP_DEFAULT_TOPO         (TF_ISO|TF_HEX)
+#define MAP_DEFAULT_WRAP         (WRAP_X)
 #endif /* FREECIV_WEB */
 
 #define MAP_DEFAULT_SEED         0
@@ -656,14 +692,6 @@ moves. Includes MAP_MAX_LINEAR_SIZE because a map can be non wrapping. */
 #define MAP_MIN_FLATPOLES         0
 #define MAP_MAX_FLATPOLES         100
 
-#define MAP_DEFAULT_SINGLE_POLE    FALSE
-#define MAP_MIN_SINGLE_POLE        FALSE
-#define MAP_MAX_SINGLE_POLE        TRUE
-
-#define MAP_DEFAULT_ALLTEMPERATE   FALSE
-#define MAP_MIN_ALLTEMPERATE       FALSE
-#define MAP_MAX_ALLTEMPERATE       TRUE
-
 #define MAP_DEFAULT_TEMPERATURE   50
 #define MAP_MIN_TEMPERATURE       0
 #define MAP_MAX_TEMPERATURE       100
@@ -675,6 +703,9 @@ moves. Includes MAP_MAX_LINEAR_SIZE because a map can be non wrapping. */
  * elements defined above.
  */
 
+/************************************************************************//**
+  Convert map position to tile index.
+****************************************************************************/
 static inline int map_pos_to_index(struct civ_map *nmap, int map_x, int map_y)
 {
   /* Note: writing this as a macro is hard; it needs temp variables. */
@@ -682,28 +713,37 @@ static inline int map_pos_to_index(struct civ_map *nmap, int map_x, int map_y)
 
   CHECK_MAP_POS(map_x, map_y);
   MAP_TO_NATIVE_POS(&nat_x, &nat_y, map_x, map_y);
+
   return native_pos_to_index(nat_x, nat_y);
 }
 
+/************************************************************************//**
+  Convert tile index to x-coordinate of map position.
+****************************************************************************/
 static inline int index_to_map_pos_x(int mindex)
 {
   /* Note: writing this as a macro is hard; it needs temp variables. */
   int map_x, map_y;
 
   index_to_map_pos(&map_x, &map_y, mindex);
+
   return map_x;
 }
 
+/************************************************************************//**
+  Convert tile index to y-coordinate of map position.
+****************************************************************************/
 static inline int index_to_map_pos_y(int mindex)
 {
   /* Note: writing this as a macro is hard; it needs temp variables. */
   int map_x, map_y;
 
   index_to_map_pos(&map_x, &map_y, mindex);
+
   return map_y;
 }
 
-/****************************************************************************
+/************************************************************************//**
   A "border position" is any map position that _may have_ positions within
   real map distance dist that are non-normal.  To see its correctness,
   consider the case where dist is 1 or 0.
