@@ -137,7 +137,7 @@ int utype_unknown_move_cost(const struct unit_type *utype)
     };
     int max_effect_mc;
 
-    if (!utype_can_do_action(utype, paction->id)) {
+    if (!utype_can_do_action(utype, action_id(paction))) {
       /* Not relevant. */
       continue;
     }
@@ -166,10 +166,9 @@ int utype_unknown_move_cost(const struct unit_type *utype)
   return move_cost;
 }
 
-
 /************************************************************************//**
-  Return TRUE iff the unit can be a defender at its current location.  This
-  should be checked when looking for a defender - not all units on the
+  Return TRUE iff the unit can be a defender at its current location.
+  This should be checked when looking for a defender - not all units on the
   tile are valid defenders.
 ****************************************************************************/
 bool unit_can_defend_here(const struct civ_map *nmap, const struct unit *punit)
@@ -187,7 +186,9 @@ bool unit_can_defend_here(const struct civ_map *nmap, const struct unit *punit)
     return FALSE;
   case TDT_ALIGHT:
     return can_unit_exist_at_tile(nmap, punit, unit_tile(punit))
-      && can_unit_alight_or_be_unloaded(nmap, punit, ptrans);
+      && can_unit_deboard_or_be_unloaded(nmap, punit, ptrans);
+  case TDT_ALWAYS:
+    return TRUE;
   }
 
   fc_assert(FALSE);
@@ -196,26 +197,40 @@ bool unit_can_defend_here(const struct civ_map *nmap, const struct unit *punit)
 }
 
 /************************************************************************//**
- This unit can attack non-native tiles (eg. Ships ability to
- shore bombardment)
+  Returns TRUE iff a unit of this type can attack non-native tiles (eg.
+  Ships ability to shore bombardment) given that it can perform an attack
+  action.
 ****************************************************************************/
-bool can_attack_non_native(const struct unit_type *utype)
+bool can_attack_non_native_hard_reqs(const struct unit_type *utype)
 {
   return uclass_has_flag(utype_class(utype), UCF_ATTACK_NON_NATIVE)
-         && (utype_can_do_action_result(utype, ACTRES_ATTACK)
-             || utype_can_do_action_result(utype, ACTRES_BOMBARD)
-             || utype_can_do_action_result(utype, ACTRES_NUKE_UNITS))
          && !utype_has_flag(utype, UTYF_ONLY_NATIVE_ATTACK);
 }
 
 /************************************************************************//**
- This unit can attack from non-native tiles (Marines can attack from
- transport, ships from harbour cities)
+  This unit can attack non-native tiles (eg. Ships ability to
+  shore bombardment)
+****************************************************************************/
+bool can_attack_non_native(const struct unit_type *utype)
+{
+  return can_attack_non_native_hard_reqs(utype)
+         && (utype_can_do_action_result(utype, ACTRES_ATTACK)
+             || utype_can_do_action_result(utype, ACTRES_BOMBARD)
+             || utype_can_do_action_result(utype, ACTRES_WIPE_UNITS)
+             || utype_can_do_action_result(utype, ACTRES_NUKE_UNITS));
+}
+
+/************************************************************************//**
+  This unit can attack from non-native tiles (Marines can attack from
+  transport, ships from harbor cities)
 ****************************************************************************/
 bool can_attack_from_non_native(const struct unit_type *utype)
 {
   return (utype_can_do_action_result_when_ustate(utype, ACTRES_ATTACK,
                                                  USP_NATIVE_TILE, FALSE)
+          || utype_can_do_action_result_when_ustate(utype,
+                                                    ACTRES_WIPE_UNITS,
+                                                    USP_LIVABLE_TILE, FALSE)
           || utype_can_do_action_result_when_ustate(utype,
                                                     ACTRES_CONQUER_CITY,
                                                     USP_LIVABLE_TILE,
@@ -568,6 +583,24 @@ bool unit_can_move_to_tile(const struct civ_map *nmap,
                                           enter_enemy_city));
 }
 
+/************************************************************************//**
+  Returns whether the unit can teleport from its current tile to
+  the destination tile.
+
+  See unit_teleport_to_tile_test().
+****************************************************************************/
+bool unit_can_teleport_to_tile(const struct civ_map *nmap,
+                               const struct unit *punit,
+                               const struct tile *dst_tile,
+                               bool enter_transport,
+                               bool enter_enemy_city)
+{
+  return (MR_OK == unit_teleport_to_tile_test(nmap, punit, punit->activity,
+                                              unit_tile(punit), dst_tile,
+                                              enter_transport, NULL,
+                                              enter_enemy_city));
+}
+
 /************************************************************************//**
   Returns whether the unit can move from its current tile to the
   destination tile. An enumerated value is returned indication the error
@@ -576,20 +609,22 @@ bool unit_can_move_to_tile(const struct civ_map *nmap,
   The unit can move if:
     1) The unit is idle or on server goto.
     2) Unit is not prohibited from moving by scenario
-    3) The target location is next to the unit.
-    4) There are no non-allied units on the target tile.
-    5) Animals cannot move out from home terrains
-    6) Unit can move to a tile where it can't survive on its own if there
+    3) Unit is not a "random movement only" one, or this is random movement
+    4) The target location is next to the unit.
+    5) There are no non-allied units on the target tile.
+    6) Animals cannot move out from home terrains
+    7) Unit can move to a tile where it can't survive on its own if there
        is free transport capacity.
-    7) There are no peaceful but non-allied units on the target tile.
-    8) There is not a non-allied city on the target tile when
+    8) There are no peaceful but non-allied units on the target tile.
+    9) There is not a non-allied city on the target tile when
        enter_enemy_city is false. When enter_enemy_city is true a non
        peaceful city is also accepted.
-    9) There is no non-allied unit blocking (zoc) [or igzoc is true].
-   10) Triremes cannot move out of sight from land.
-   11) It is not the territory of a player we are at peace with.
-   12) The unit is unable to disembark from current transporter.
-   13) The unit is making a non-native move (e.g. lack of road)
+   10) There is no non-allied unit blocking (zoc) [or igzoc is true].
+   11) Triremes cannot move out of sight from land.
+   12) It is not the territory of a player we are at peace with,
+       or it's terrain where borders don't count
+   13) The unit is unable to disembark from current transporter.
+   14) The unit is making a non-native move (e.g. lack of road)
 ****************************************************************************/
 enum unit_move_result
 unit_move_to_tile_test(const struct civ_map *nmap,
@@ -618,25 +653,31 @@ unit_move_to_tile_test(const struct civ_map *nmap,
   }
 
   /* 3) */
+  if ((!is_server() || game.server.random_move_time != puowner)
+      && utype_has_flag(punittype, UTYF_RANDOM_MOVEMENT)) {
+    return MR_RANDOM_ONLY;
+  }
+
+  /* 4) */
   if (!is_tiles_adjacent(src_tile, dst_tile)) {
     /* Of course you can only move to adjacent positions. */
     return MR_BAD_DESTINATION;
   }
 
-  /* 4) */
+  /* 5) */
   if (is_non_allied_unit_tile(dst_tile, puowner)) {
     /* You can't move onto a tile with non-allied units on it (try
      * attacking instead). */
     return MR_DESTINATION_OCCUPIED_BY_NON_ALLIED_UNIT;
   }
 
-  /* 5) */
+  /* 6) */
   if (puowner->ai_common.barbarian_type == ANIMAL_BARBARIAN
       && dst_tile->terrain->animal != punittype) {
     return MR_ANIMAL_DISALLOWED;
   }
 
-  /* 6) */
+  /* 7) */
   if (embark_to != NULL) {
     if (!could_unit_load(punit, embark_to)) {
       return MR_NO_TRANSPORTER_CAPACITY;
@@ -647,7 +688,7 @@ unit_move_to_tile_test(const struct civ_map *nmap,
     return MR_NO_TRANSPORTER_CAPACITY;
   }
 
-  /* 7) */
+  /* 8) */
   if (is_non_attack_unit_tile(dst_tile, puowner)) {
     /* You can't move into a non-allied tile.
      *
@@ -656,7 +697,7 @@ unit_move_to_tile_test(const struct civ_map *nmap,
     return MR_NO_WAR;
   }
 
-  /* 8) */
+  /* 9) */
   if ((pcity = tile_city(dst_tile))) {
     if (enter_enemy_city) {
       if (pplayers_non_attack(city_owner(pcity), puowner)) {
@@ -674,7 +715,7 @@ unit_move_to_tile_test(const struct civ_map *nmap,
     }
   }
 
-  /* 9) */
+  /* 10) */
   zoc = igzoc
     || can_step_taken_wrt_to_zoc(punittype, puowner, src_tile, dst_tile, nmap);
   if (!zoc) {
@@ -682,25 +723,25 @@ unit_move_to_tile_test(const struct civ_map *nmap,
     return MR_ZOC;
   }
 
-  /* 10) */
+  /* 11) */
   if (utype_has_flag(punittype, UTYF_COAST_STRICT)
       && !pcity && !is_safe_ocean(nmap, dst_tile)) {
     return MR_TRIREME;
   }
 
-  /* 11) */
+  /* 12) */
   if (!utype_has_flag(punittype, UTYF_CIVILIAN)
       && !player_can_invade_tile(puowner, dst_tile)) {
     return MR_PEACE;
   }
 
-  /* 12) */
+  /* 13) */
   if (unit_transported(punit)
      && !can_unit_unload(punit, unit_transport_get(punit))) {
     return MR_CANNOT_DISEMBARK;
   }
 
-  /* 13) */
+  /* 14) */
   if (!(is_native_move(nmap, utype_class(punittype), src_tile, dst_tile)
         /* Allow non-native moves into cities or boarding transport. */
         || pcity
@@ -726,7 +767,8 @@ unit_move_to_tile_test(const struct civ_map *nmap,
        enter_enemy_city is false. When enter_enemy_city is true a non
        peaceful city is also accepted.
     6) Triremes cannot move out of sight from land.
-    7) It is not the territory of a player we are at peace with.
+    7) It is not the territory of a player we are at peace with,
+       or it's terrain where borders don't count
 ****************************************************************************/
 enum unit_move_result
 unit_teleport_to_tile_test(const struct civ_map *nmap,
