@@ -1,11 +1,12 @@
+ /**************************************************************************
+ *                         THIS FILE WAS GENERATED                         *
+ * Script: common/generate_packets.py                                      *
+ * Input:  common/networking/packets.def                                   *
+ *                         DO NOT CHANGE THIS FILE                         *
+ **************************************************************************/
 
- /****************************************************************************
- *                       THIS FILE WAS GENERATED                             *
- * Script: common/generate_packets.py                                        *
- * Input:  common/networking/packets.def                                     *
- *                       DO NOT CHANGE THIS FILE                             *
- ****************************************************************************/
-
+#ifndef FC__PACKETS_GEN_H
+#define FC__PACKETS_GEN_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -21,25 +22,19 @@ extern "C" {
 #include "cm.h"
 
 struct packet_processing_started {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_processing_finished {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_investigate_started {
-  int unit_id16;
-  int unit_id32;
-  int city_id16;
-  int city_id32;
+  int city_id;
 };
 
 struct packet_investigate_finished {
-  int unit_id16;
-  int unit_id32;
-  int city_id16;
-  int city_id32;
+  int city_id;
 };
 
 struct packet_server_join_req {
@@ -69,7 +64,7 @@ struct packet_authentication_reply {
 };
 
 struct packet_server_shutdown {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_nation_select_req {
@@ -105,8 +100,7 @@ struct packet_tile_info {
   enum known_type known;
   int owner;
   int extras_owner;
-  int worked16;
-  int worked32;
+  int worked;
   Terrain_type_id terrain;
   Resource_type_id resource;
   bv_extras extras;
@@ -126,6 +120,7 @@ struct packet_game_info {
   int angrycitizen;
   int base_pollution;
   int base_tech_cost;
+  int min_tech_cost;
   int tech_leak_pct;
   int border_city_radius_sq;
   int border_size_effect;
@@ -141,6 +136,7 @@ struct packet_game_info {
   bool changable_tax;
   int pop_report_zeroes;
   bool citizen_nationality;
+  bool unit_builders_nationality;
   int citizen_convert_speed;
   int conquest_convert_pct;
   int citizen_partisans_pct;
@@ -158,6 +154,7 @@ struct packet_game_info {
   int fulltradesize;
   int trade_world_rel_pct;
   int min_trade_route_val;
+  bool reveal_trade_partner;
   enum goods_selection_method goods_selection;
   int global_advance_count;
   bool global_advances[A_LAST];
@@ -165,6 +162,7 @@ struct packet_game_info {
   int globalwarming;
   int gold;
   enum gold_upkeep_style gold_upkeep_style;
+  bool homeless_gold_upkeep;
   int infrapoints;
   enum revolen_type revolentype;
   Government_type_id default_government_id;
@@ -242,6 +240,7 @@ struct packet_game_info {
   int warminglevel;
   int year;
   bool year_0_hack;
+  int top_cities_count;
   int fragment_count;
   bool civil_war_enabled;
   int civil_war_bonus_celebrating;
@@ -267,6 +266,9 @@ struct packet_map_info {
   int xsize;
   int ysize;
   int topology_id;
+  int wrap_id;
+  int north_latitude;
+  int south_latitude;
 };
 
 struct packet_nuke_tile_info {
@@ -319,13 +321,11 @@ struct packet_server_info {
 };
 
 struct packet_city_remove {
-  int city_id16;
-  int city_id32;
+  int city_id;
 };
 
 struct packet_city_info {
-  int id16;
-  int id32;
+  int id;
   int tile;
   int owner;
   int original;
@@ -367,6 +367,7 @@ struct packet_city_info {
   bool did_buy;
   bool did_sell;
   bool was_happy;
+  bool had_famine;
   bool diplomat_investigate;
   int walls;
   int city_image;
@@ -374,22 +375,29 @@ struct packet_city_info {
   struct worklist worklist;
   bv_imprs improvements;
   bv_city_options city_options;
+  enum city_wl_cancel_behavior wl_cb;
+  enum city_acquire_type acquire_type;
   char name[MAX_LEN_CITYNAME];
 };
 
 struct packet_city_nationalities {
-  int id16;
-  int id32;
+  int id;
   int nationalities_count;
   int nation_id[MAX_CITY_NATIONALITIES];
   int nation_citizens[MAX_CITY_NATIONALITIES];
 };
 
+struct packet_city_update_counters {
+  int city;
+  int count;
+  int counters[MAX_COUNTERS];
+};
+
 struct packet_city_short_info {
-  int id16;
-  int id32;
+  int id;
   int tile;
   int owner;
+  int original;
   int size;
   int style;
   enum capital_type capital;
@@ -403,100 +411,84 @@ struct packet_city_short_info {
 };
 
 struct packet_trade_route_info {
-  int city16;
-  int city32;
+  int city;
   int index;
-  int partner16;
-  int partner32;
+  int partner;
   int value;
   enum route_direction direction;
   Goods_type_id goods;
 };
 
 struct packet_city_sell {
-  int city_id16;
-  int city_id32;
+  int city_id;
   int build_id;
 };
 
 struct packet_city_buy {
-  int city_id16;
-  int city_id32;
+  int city_id;
 };
 
 struct packet_city_change {
-  int city_id16;
-  int city_id32;
+  int city_id;
   int production_kind;
   int production_value;
 };
 
 struct packet_city_worklist {
-  int city_id16;
-  int city_id32;
+  int city_id;
   struct worklist worklist;
 };
 
 struct packet_city_make_specialist {
-  int city_id16;
-  int city_id32;
+  int city_id;
   int tile_id;
 };
 
 struct packet_city_make_worker {
-  int city_id16;
-  int city_id32;
+  int city_id;
   int tile_id;
 };
 
 struct packet_city_change_specialist {
-  int city_id16;
-  int city_id32;
+  int city_id;
   Specialist_type_id from;
   Specialist_type_id to;
 };
 
 struct packet_city_rename {
-  int city_id16;
-  int city_id32;
+  int city_id;
   char name[MAX_LEN_CITYNAME];
 };
 
 struct packet_city_options_req {
-  int city_id16;
-  int city_id32;
+  int city_id;
   bv_city_options options;
+  enum city_wl_cancel_behavior wl_cb;
 };
 
 struct packet_city_refresh {
-  int city_id16;
-  int city_id32;
+  int city_id;
 };
 
 struct packet_city_name_suggestion_req {
-  int unit_id16;
-  int unit_id32;
+  int unit_id;
 };
 
 struct packet_city_name_suggestion_info {
-  int unit_id16;
-  int unit_id32;
+  int unit_id;
   char name[MAX_LEN_CITYNAME];
 };
 
 struct packet_city_sabotage_list {
-  int actor_id16;
-  int actor_id32;
-  int city_id16;
-  int city_id32;
+  int actor_id;
+  int city_id;
   bv_imprs improvements;
   action_id act_id;
   int request_kind;
 };
 
 struct packet_city_rally_point {
-  int city_id16;
-  int city_id32;
+  int id;
   int length;
   bool persistent;
   bool vigilant;
@@ -504,8 +496,7 @@ struct packet_city_rally_point {
 };
 
 struct packet_worker_task {
-  int city_id16;
-  int city_id32;
+  int city_id;
   int tile_id;
   enum unit_activity activity;
   int tgt;
@@ -526,7 +517,7 @@ struct packet_player_info {
   bool was_created;
   Government_type_id government;
   Government_type_id target_government;
-  bool real_embassy[MAX_NUM_PLAYER_SLOTS];
+  bv_player real_embassy;
   enum mood_type mood;
   int style;
   int music_style;
@@ -537,6 +528,7 @@ struct packet_player_info {
   int nturns_idle;
   int turns_alive;
   bool is_alive;
+  int autoselect_weight;
   int gold;
   int tax;
   int science;
@@ -549,6 +541,7 @@ struct packet_player_info {
   enum ai_level ai_skill_level;
   enum barbarian_type barbarian_type;
   bv_player gives_shared_vision;
+  bv_player gives_shared_tiles;
   int history;
   int culture;
   int love[MAX_NUM_PLAYER_SLOTS];
@@ -585,7 +578,7 @@ struct packet_player_place_infra {
 };
 
 struct packet_player_attribute_block {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_player_attribute_chunk {
@@ -635,19 +628,16 @@ struct packet_player_tech_goal {
 };
 
 struct packet_unit_remove {
-  int unit_id16;
-  int unit_id32;
+  int unit_id;
 };
 
 struct packet_unit_info {
-  int id16;
-  int id32;
+  int id;
   int owner;
   int nationality;
   int tile;
   enum direction8 facing;
-  int homecity16;
-  int homecity32;
+  int homecity;
   int upkeep[O_LAST];
   int veteran;
   enum server_side_agent ssa_controller;
@@ -656,9 +646,10 @@ struct packet_unit_info {
   bool transported;
   bool done_moving;
   bool stay;
+  int birth_turn;
+  int current_form_turn;
   Unit_type_id type;
-  int transported_by16;
-  int transported_by32;
+  int transported_by;
   int carrying;
   int movesleft;
   int hp;
@@ -682,8 +673,7 @@ struct packet_unit_info {
 };
 
 struct packet_unit_short_info {
-  int id16;
-  int id32;
+  int id;
   int owner;
   int tile;
   enum direction8 facing;
@@ -694,18 +684,14 @@ struct packet_unit_short_info {
   int hp;
   int activity;
   int activity_tgt;
-  int transported_by16;
-  int transported_by32;
+  int transported_by;
   int packet_use;
-  int info_city_id16;
-  int info_city_id32;
+  int info_city_id;
 };
 
 struct packet_unit_combat_info {
-  int attacker_unit_id16;
-  int attacker_unit_id32;
-  int defender_unit_id16;
-  int defender_unit_id32;
+  int attacker_unit_id;
+  int defender_unit_id;
   int attacker_hp;
   int defender_hp;
   bool make_att_veteran;
@@ -713,15 +699,13 @@ struct packet_unit_combat_info {
 };
 
 struct packet_unit_sscs_set {
-  int unit_id16;
-  int unit_id32;
+  int unit_id;
   enum unit_ss_data_type type;
   int value;
 };
 
 struct packet_unit_orders {
-  int unit_id16;
-  int unit_id32;
+  int unit_id;
   int src_tile;
   int length;
   bool repeat;
@@ -731,14 +715,12 @@ struct packet_unit_orders {
 };
 
 struct packet_unit_server_side_agent_set {
-  int unit_id16;
-  int unit_id32;
+  int unit_id;
   enum server_side_agent agent;
 };
 
 struct packet_unit_action_query {
-  int actor_id16;
-  int actor_id32;
+  int actor_id;
   int target_id;
   action_id action_type;
   int request_kind;
@@ -749,8 +731,7 @@ struct packet_unit_type_upgrade {
 };
 
 struct packet_unit_do_action {
-  int actor_id16;
-  int actor_id32;
+  int actor_id;
   int target_id;
   int sub_tgt_id;
   char name[MAX_LEN_NAME];
@@ -758,8 +739,7 @@ struct packet_unit_do_action {
 };
 
 struct packet_unit_action_answer {
-  int actor_id16;
-  int actor_id32;
+  int actor_id;
   int target_id;
   int cost;
   action_id action_type;
@@ -767,22 +747,17 @@ struct packet_unit_action_answer {
 };
 
 struct packet_unit_get_actions {
-  int actor_unit_id16;
-  int actor_unit_id32;
-  int target_unit_id16;
-  int target_unit_id32;
+  int actor_unit_id;
+  int target_unit_id;
   int target_tile_id;
   int target_extra_id;
   int request_kind;
 };
 
 struct packet_unit_actions {
-  int actor_unit_id16;
-  int actor_unit_id32;
-  int target_unit_id16;
-  int target_unit_id32;
-  int target_city_id16;
-  int target_city_id32;
+  int actor_unit_id;
+  int target_unit_id;
+  int target_city_id;
   int target_tile_id;
   int target_extra_id;
   int request_kind;
@@ -790,8 +765,7 @@ struct packet_unit_actions {
 };
 
 struct packet_unit_change_activity {
-  int unit_id16;
-  int unit_id32;
+  int unit_id;
   enum unit_activity activity;
   int target;
 };
@@ -892,15 +866,15 @@ struct packet_conn_ping_info {
 };
 
 struct packet_conn_ping {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_conn_pong {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_client_heartbeat {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_client_info {
@@ -910,7 +884,7 @@ struct packet_client_info {
 };
 
 struct packet_end_phase {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_start_phase {
@@ -924,23 +898,23 @@ struct packet_new_year {
 };
 
 struct packet_begin_turn {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_end_turn {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_freeze_client {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_thaw_client {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_spaceship_launch {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_spaceship_place {
@@ -975,6 +949,7 @@ struct packet_ruleset_unit {
   char rule_name[MAX_LEN_NAME];
   char graphic_str[MAX_LEN_NAME];
   char graphic_alt[MAX_LEN_NAME];
+  char graphic_alt2[MAX_LEN_NAME];
   char sound_move[MAX_LEN_NAME];
   char sound_move_alt[MAX_LEN_NAME];
   char sound_fight[MAX_LEN_NAME];
@@ -985,7 +960,6 @@ struct packet_ruleset_unit {
   int attack_strength;
   int defense_strength;
   int move_rate;
-  int tech_requirement;
   int build_reqs_count;
   struct requirement build_reqs[MAX_NUM_REQS];
   int vision_radius_sq;
@@ -1114,6 +1088,9 @@ struct packet_ruleset_government {
   char rule_name[MAX_LEN_NAME];
   char graphic_str[MAX_LEN_NAME];
   char graphic_alt[MAX_LEN_NAME];
+  char sound_str[MAX_LEN_NAME];
+  char sound_alt[MAX_LEN_NAME];
+  char sound_alt2[MAX_LEN_NAME];
   char helptext[MAX_LEN_PACKET];
 };
 
@@ -1133,7 +1110,7 @@ struct packet_ruleset_terrain_control {
 };
 
 struct packet_rulesets_ready {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_ruleset_nation_sets {
@@ -1207,6 +1184,7 @@ struct packet_ruleset_building {
   char rule_name[MAX_LEN_NAME];
   char graphic_str[MAX_LEN_NAME];
   char graphic_alt[MAX_LEN_NAME];
+  char graphic_alt2[MAX_LEN_NAME];
   int reqs_count;
   struct requirement reqs[MAX_NUM_REQS];
   int obs_count;
@@ -1217,9 +1195,16 @@ struct packet_ruleset_building {
   bv_impr_flags flags;
   char soundtag[MAX_LEN_NAME];
   char soundtag_alt[MAX_LEN_NAME];
+  char soundtag_alt2[MAX_LEN_NAME];
   char helptext[MAX_LEN_PACKET];
 };
 
+struct packet_ruleset_impr_flag {
+  int id;
+  char name[MAX_LEN_NAME];
+  char helptxt[MAX_LEN_PACKET];
+};
+
 struct packet_ruleset_terrain {
   Terrain_type_id id;
   int tclass;
@@ -1229,11 +1214,13 @@ struct packet_ruleset_terrain {
   char rule_name[MAX_LEN_NAME];
   char graphic_str[MAX_LEN_NAME];
   char graphic_alt[MAX_LEN_NAME];
+  char graphic_alt2[MAX_LEN_NAME];
   int movement_cost;
   int defense_bonus;
   int output[O_LAST];
   int num_resources;
-  Resource_type_id resources[MAX_RESOURCE_TYPES];
+  Resource_type_id resources[MAX_EXTRA_TYPES];
+  int resource_freq[MAX_EXTRA_TYPES];
   int road_output_incr_pct[O_LAST];
   int base_time;
   int road_time;
@@ -1249,9 +1236,9 @@ struct packet_ruleset_terrain {
   Terrain_type_id transform_result;
   int transform_time;
   int placing_time;
-  int clean_pollution_time;
-  int clean_fallout_time;
   int pillage_time;
+  int extra_count;
+  int extra_removal_times[MAX_EXTRA_TYPES];
   int color_red;
   int color_green;
   int color_blue;
@@ -1287,6 +1274,7 @@ struct packet_ruleset_extra {
   char act_gfx_alt2[MAX_LEN_NAME];
   char rmact_gfx[MAX_LEN_NAME];
   char rmact_gfx_alt[MAX_LEN_NAME];
+  char rmact_gfx_alt2[MAX_LEN_NAME];
   char graphic_str[MAX_LEN_NAME];
   char graphic_alt[MAX_LEN_NAME];
   int reqs_count;
@@ -1314,6 +1302,7 @@ struct packet_ruleset_extra {
   bv_extras hidden_by;
   bv_extras bridged_over;
   bv_extras conflicts;
+  int no_aggr_near_city;
   char helptext[MAX_LEN_PACKET];
 };
 
@@ -1418,6 +1407,16 @@ struct packet_ruleset_action_auto {
   action_id alternatives[MAX_NUM_ACTIONS];
 };
 
+struct packet_ruleset_counter {
+  char name[MAX_LEN_NAME];
+  char rule_name[MAX_LEN_NAME];
+  char helptext[MAX_LEN_PACKET];
+  int def;
+  int checkpoint;
+  enum counter_target type;
+  enum counter_behavior behavior;
+};
+
 struct packet_ruleset_music {
   int id;
   char music_peaceful[MAX_LEN_NAME];
@@ -1469,7 +1468,7 @@ struct packet_ruleset_control {
   int num_music_styles;
   int government_count;
   int nation_count;
-  int styles_count;
+  int num_city_styles;
   int terrain_count;
   int num_specialist_types;
   int num_nation_groups;
@@ -1481,8 +1480,8 @@ struct packet_ruleset_control {
   char name[MAX_LEN_NAME];
   char version[MAX_LEN_NAME];
   char alt_dir[MAX_LEN_NAME];
-  int desc_length16;
-  int desc_length32;
+  int desc_length;
+  int num_counters;
 };
 
 struct packet_ruleset_summary {
@@ -1506,6 +1505,10 @@ struct packet_ruleset_choices {
   char rulesets[MAX_NUM_RULESETS][MAX_RULESET_NAME_LENGTH];
 };
 
+struct packet_ruleset_select {
+  char modpack[MAX_RULESET_NAME_LENGTH];
+};
+
 struct packet_game_load {
   bool load_successful;
   char load_filename[MAX_LEN_PACKET];
@@ -1585,6 +1588,7 @@ struct packet_server_setting_bitwise {
 
 struct packet_set_topology {
   int topology_id;
+  int wrap_id;
 };
 
 struct packet_ruleset_effect {
@@ -1661,17 +1665,21 @@ struct packet_edit_mode {
 };
 
 struct packet_edit_recalculate_borders {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_edit_check_tiles {
-  char __dummy;			/* to avoid malloc(0); */
+  char __dummy;                 /* to avoid malloc(0); */
 };
 
 struct packet_edit_toggle_fogofwar {
   int player;
 };
 
+struct packet_edit_fogofwar_state {
+  bool enabled;
+};
+
 struct packet_edit_tile_terrain {
   int tile;
   Terrain_type_id terrain;
@@ -1724,17 +1732,14 @@ struct packet_edit_unit_remove {
 };
 
 struct packet_edit_unit_remove_by_id {
-  int id16;
-  int id32;
+  int id;
 };
 
 struct packet_edit_unit {
-  int id16;
-  int id32;
+  int id;
   Unit_type_id utype;
   int owner;
-  int homecity16;
-  int homecity32;
+  int homecity;
   int moves_left;
   int hp;
   int veteran;
@@ -1746,8 +1751,7 @@ struct packet_edit_unit {
   bool moved;
   bool paradropped;
   bool done_moving;
-  int transported_by16;
-  int transported_by32;
+  int transported_by;
   bool stay;
 };
 
@@ -1759,13 +1763,11 @@ struct packet_edit_city_create {
 };
 
 struct packet_edit_city_remove {
-  int id16;
-  int id32;
+  int id;
 };
 
 struct packet_edit_city {
-  int id16;
-  int id32;
+  int id;
   char name[MAX_LEN_CITYNAME];
   int owner;
   int original;
@@ -1784,6 +1786,7 @@ struct packet_edit_city {
   bool did_buy;
   bool did_sell;
   bool was_happy;
+  bool had_famine;
   int anarchy;
   int rapture;
   int steal;
@@ -1792,7 +1795,6 @@ struct packet_edit_city {
   int built[B_LAST];
   int production_kind;
   int production_value;
-  bv_city_options city_options;
 };
 
 struct packet_edit_player_create {
@@ -1818,8 +1820,10 @@ struct packet_edit_player {
   int nturns_idle;
   bool is_alive;
   int revolution_finishes;
+  int autoselect_weight;
   bv_player embassy;
   int gold;
+  int infrapoints;
   int tax;
   int science;
   int luxury;
@@ -1863,11 +1867,38 @@ struct packet_play_music {
   char tag[MAX_LEN_NAME];
 };
 
+struct packet_popup_image {
+  char tag[MAX_LEN_NAME];
+};
+
+struct packet_sync_serial {
+  int serial;
+};
+
+struct packet_sync_serial_reply {
+  int serial;
+};
+
 struct packet_web_city_info_addition {
-  int id16;
-  int id32;
+  int id;
+  bool cma_enabled;
+  struct cm_parameter cm_parameter;
   int granary_size;
   int granary_turns;
+  bv_utypes can_build_unit;
+  bv_imprs can_build_improvement;
+  int output_food[MAX_CITY_TILES + 1];
+  int output_shield[MAX_CITY_TILES + 1];
+  int output_trade[MAX_CITY_TILES + 1];
+};
+
+struct packet_web_cma_set {
+  int id;
+  struct cm_parameter cm_parameter;
+};
+
+struct packet_web_cma_clear {
+  int id;
 };
 
 struct packet_web_player_info_addition {
@@ -1899,7 +1930,8 @@ enum packet_type {
   PACKET_MAP_INFO,
   PACKET_NUKE_TILE_INFO,
   PACKET_TEAM_NAME_INFO,
-  PACKET_INVESTIGATE_STARTED = 21,
+  PACKET_RULESET_IMPR_FLAG,              /* 20 */
+  PACKET_INVESTIGATE_STARTED,
   PACKET_INVESTIGATE_FINISHED,
   PACKET_CHAT_MSG = 25,
   PACKET_CHAT_MSG_REQ,
@@ -2004,6 +2036,7 @@ enum packet_type {
   PACKET_SERVER_SETTING_STR,
   PACKET_SERVER_SETTING_ENUM,
   PACKET_SERVER_SETTING_BITWISE,         /* 170 */
+  PACKET_RULESET_SELECT,
   PACKET_RULESET_EFFECT = 175,
   PACKET_RULESET_RESOURCE = 177,
   PACKET_SCENARIO_INFO = 180,            /* 180 */
@@ -2071,9 +2104,17 @@ enum packet_type {
   PACKET_CLIENT_HEARTBEAT,
   PACKET_CALENDAR_INFO,
   PACKET_WEB_CITY_INFO_ADDITION,
+  PACKET_WEB_CMA_SET,
+  PACKET_WEB_CMA_CLEAR,
   PACKET_WEB_PLAYER_INFO_ADDITION,
-  PACKET_WEB_RULESET_UNIT_ADDITION,
+  PACKET_WEB_RULESET_UNIT_ADDITION,      /* 260 */
   PACKET_RULESET_CLAUSE = 512,
+  PACKET_RULESET_COUNTER,
+  PACKET_CITY_UPDATE_COUNTERS,
+  PACKET_POPUP_IMAGE,
+  PACKET_EDIT_FOGOFWAR_STATE,
+  PACKET_SYNC_SERIAL,
+  PACKET_SYNC_SERIAL_REPLY,
 
   PACKET_LAST  /* leave this last */
 };
@@ -2083,10 +2124,14 @@ int send_packet_processing_started(struct connection *pc);
 int send_packet_processing_finished(struct connection *pc);
 
 int send_packet_investigate_started(struct connection *pc, const struct packet_investigate_started *packet);
-int dsend_packet_investigate_started(struct connection *pc, int unit_id16, int unit_id32, int city_id16, int city_id32);
+void lsend_packet_investigate_started(struct conn_list *dest, const struct packet_investigate_started *packet);
+int dsend_packet_investigate_started(struct connection *pc, int city_id);
+void dlsend_packet_investigate_started(struct conn_list *dest, int city_id);
 
 int send_packet_investigate_finished(struct connection *pc, const struct packet_investigate_finished *packet);
-int dsend_packet_investigate_finished(struct connection *pc, int unit_id16, int unit_id32, int city_id16, int city_id32);
+void lsend_packet_investigate_finished(struct conn_list *dest, const struct packet_investigate_finished *packet);
+int dsend_packet_investigate_finished(struct connection *pc, int city_id);
+void dlsend_packet_investigate_finished(struct conn_list *dest, int city_id);
 
 int send_packet_server_join_req(struct connection *pc, const struct packet_server_join_req *packet);
 int dsend_packet_server_join_req(struct connection *pc, const char *username, const char *capability, const char *version_label, int major_version, int minor_version, int patch_version);
@@ -2153,8 +2198,8 @@ int dsend_packet_server_info(struct connection *pc, const char *version_label, i
 
 int send_packet_city_remove(struct connection *pc, const struct packet_city_remove *packet);
 void lsend_packet_city_remove(struct conn_list *dest, const struct packet_city_remove *packet);
-int dsend_packet_city_remove(struct connection *pc, int city_id16, int city_id32);
-void dlsend_packet_city_remove(struct conn_list *dest, int city_id16, int city_id32);
+int dsend_packet_city_remove(struct connection *pc, int city_id);
+void dlsend_packet_city_remove(struct conn_list *dest, int city_id);
 
 int send_packet_city_info(struct connection *pc, const struct packet_city_info *packet, bool force_to_send);
 void lsend_packet_city_info(struct conn_list *dest, const struct packet_city_info *packet, bool force_to_send);
@@ -2162,6 +2207,9 @@ void lsend_packet_city_info(struct conn_list *dest, const struct packet_city_inf
 int send_packet_city_nationalities(struct connection *pc, const struct packet_city_nationalities *packet, bool force_to_send);
 void lsend_packet_city_nationalities(struct conn_list *dest, const struct packet_city_nationalities *packet, bool force_to_send);
 
+int send_packet_city_update_counters(struct connection *pc, const struct packet_city_update_counters *packet);
+void lsend_packet_city_update_counters(struct conn_list *dest, const struct packet_city_update_counters *packet);
+
 int send_packet_city_short_info(struct connection *pc, const struct packet_city_short_info *packet);
 void lsend_packet_city_short_info(struct conn_list *dest, const struct packet_city_short_info *packet);
 
@@ -2169,42 +2217,42 @@ int send_packet_trade_route_info(struct connection *pc, const struct packet_trad
 void lsend_packet_trade_route_info(struct conn_list *dest, const struct packet_trade_route_info *packet);
 
 int send_packet_city_sell(struct connection *pc, const struct packet_city_sell *packet);
-int dsend_packet_city_sell(struct connection *pc, int city_id16, int city_id32, int build_id);
+int dsend_packet_city_sell(struct connection *pc, int city_id, int build_id);
 
 int send_packet_city_buy(struct connection *pc, const struct packet_city_buy *packet);
-int dsend_packet_city_buy(struct connection *pc, int city_id16, int city_id32);
+int dsend_packet_city_buy(struct connection *pc, int city_id);
 
 int send_packet_city_change(struct connection *pc, const struct packet_city_change *packet);
-int dsend_packet_city_change(struct connection *pc, int city_id16, int city_id32, int production_kind, int production_value);
+int dsend_packet_city_change(struct connection *pc, int city_id, int production_kind, int production_value);
 
 int send_packet_city_worklist(struct connection *pc, const struct packet_city_worklist *packet);
-int dsend_packet_city_worklist(struct connection *pc, int city_id16, int city_id32, const struct worklist *worklist);
+int dsend_packet_city_worklist(struct connection *pc, int city_id, const struct worklist *worklist);
 
 int send_packet_city_make_specialist(struct connection *pc, const struct packet_city_make_specialist *packet);
-int dsend_packet_city_make_specialist(struct connection *pc, int city_id16, int city_id32, int tile_id);
+int dsend_packet_city_make_specialist(struct connection *pc, int city_id, int tile_id);
 
 int send_packet_city_make_worker(struct connection *pc, const struct packet_city_make_worker *packet);
-int dsend_packet_city_make_worker(struct connection *pc, int city_id16, int city_id32, int tile_id);
+int dsend_packet_city_make_worker(struct connection *pc, int city_id, int tile_id);
 
 int send_packet_city_change_specialist(struct connection *pc, const struct packet_city_change_specialist *packet);
-int dsend_packet_city_change_specialist(struct connection *pc, int city_id16, int city_id32, Specialist_type_id from, Specialist_type_id to);
+int dsend_packet_city_change_specialist(struct connection *pc, int city_id, Specialist_type_id from, Specialist_type_id to);
 
 int send_packet_city_rename(struct connection *pc, const struct packet_city_rename *packet);
-int dsend_packet_city_rename(struct connection *pc, int city_id16, int city_id32, const char *name);
+int dsend_packet_city_rename(struct connection *pc, int city_id, const char *name);
 
 int send_packet_city_options_req(struct connection *pc, const struct packet_city_options_req *packet);
-int dsend_packet_city_options_req(struct connection *pc, int city_id16, int city_id32, bv_city_options options);
+int dsend_packet_city_options_req(struct connection *pc, int city_id, bv_city_options options, enum city_wl_cancel_behavior wl_cb);
 
 int send_packet_city_refresh(struct connection *pc, const struct packet_city_refresh *packet);
-int dsend_packet_city_refresh(struct connection *pc, int city_id16, int city_id32);
+int dsend_packet_city_refresh(struct connection *pc, int city_id);
 
 int send_packet_city_name_suggestion_req(struct connection *pc, const struct packet_city_name_suggestion_req *packet);
-int dsend_packet_city_name_suggestion_req(struct connection *pc, int unit_id16, int unit_id32);
+int dsend_packet_city_name_suggestion_req(struct connection *pc, int unit_id);
 
 int send_packet_city_name_suggestion_info(struct connection *pc, const struct packet_city_name_suggestion_info *packet);
 void lsend_packet_city_name_suggestion_info(struct conn_list *dest, const struct packet_city_name_suggestion_info *packet);
-int dsend_packet_city_name_suggestion_info(struct connection *pc, int unit_id16, int unit_id32, const char *name);
-void dlsend_packet_city_name_suggestion_info(struct conn_list *dest, int unit_id16, int unit_id32, const char *name);
+int dsend_packet_city_name_suggestion_info(struct connection *pc, int unit_id, const char *name);
+void dlsend_packet_city_name_suggestion_info(struct conn_list *dest, int unit_id, const char *name);
 
 int send_packet_city_sabotage_list(struct connection *pc, const struct packet_city_sabotage_list *packet);
 void lsend_packet_city_sabotage_list(struct conn_list *dest, const struct packet_city_sabotage_list *packet);
@@ -2253,8 +2301,8 @@ int dsend_packet_player_tech_goal(struct connection *pc, int tech);
 
 int send_packet_unit_remove(struct connection *pc, const struct packet_unit_remove *packet);
 void lsend_packet_unit_remove(struct conn_list *dest, const struct packet_unit_remove *packet);
-int dsend_packet_unit_remove(struct connection *pc, int unit_id16, int unit_id32);
-void dlsend_packet_unit_remove(struct conn_list *dest, int unit_id16, int unit_id32);
+int dsend_packet_unit_remove(struct connection *pc, int unit_id);
+void dlsend_packet_unit_remove(struct conn_list *dest, int unit_id);
 
 int send_packet_unit_info(struct connection *pc, const struct packet_unit_info *packet);
 void lsend_packet_unit_info(struct conn_list *dest, const struct packet_unit_info *packet);
@@ -2266,33 +2314,33 @@ int send_packet_unit_combat_info(struct connection *pc, const struct packet_unit
 void lsend_packet_unit_combat_info(struct conn_list *dest, const struct packet_unit_combat_info *packet);
 
 int send_packet_unit_sscs_set(struct connection *pc, const struct packet_unit_sscs_set *packet);
-int dsend_packet_unit_sscs_set(struct connection *pc, int unit_id16, int unit_id32, enum unit_ss_data_type type, int value);
+int dsend_packet_unit_sscs_set(struct connection *pc, int unit_id, enum unit_ss_data_type type, int value);
 
 int send_packet_unit_orders(struct connection *pc, const struct packet_unit_orders *packet);
 
 int send_packet_unit_server_side_agent_set(struct connection *pc, const struct packet_unit_server_side_agent_set *packet);
-int dsend_packet_unit_server_side_agent_set(struct connection *pc, int unit_id16, int unit_id32, enum server_side_agent agent);
+int dsend_packet_unit_server_side_agent_set(struct connection *pc, int unit_id, enum server_side_agent agent);
 
 int send_packet_unit_action_query(struct connection *pc, const struct packet_unit_action_query *packet);
-int dsend_packet_unit_action_query(struct connection *pc, int actor_id16, int actor_id32, int target_id, action_id action_type, int request_kind);
+int dsend_packet_unit_action_query(struct connection *pc, int actor_id, int target_id, action_id action_type, int request_kind);
 
 int send_packet_unit_type_upgrade(struct connection *pc, const struct packet_unit_type_upgrade *packet);
 int dsend_packet_unit_type_upgrade(struct connection *pc, Unit_type_id type);
 
 int send_packet_unit_do_action(struct connection *pc, const struct packet_unit_do_action *packet);
-int dsend_packet_unit_do_action(struct connection *pc, int actor_id16, int actor_id32, int target_id, int sub_tgt_id, const char *name, action_id action_type);
+int dsend_packet_unit_do_action(struct connection *pc, int actor_id, int target_id, int sub_tgt_id, const char *name, action_id action_type);
 
 int send_packet_unit_action_answer(struct connection *pc, const struct packet_unit_action_answer *packet);
-int dsend_packet_unit_action_answer(struct connection *pc, int actor_id16, int actor_id32, int target_id, int cost, action_id action_type, int request_kind);
+int dsend_packet_unit_action_answer(struct connection *pc, int actor_id, int target_id, int cost, action_id action_type, int request_kind);
 
 int send_packet_unit_get_actions(struct connection *pc, const struct packet_unit_get_actions *packet);
-int dsend_packet_unit_get_actions(struct connection *pc, int actor_unit_id16, int actor_unit_id32, int target_unit_id16, int target_unit_id32, int target_tile_id, int target_extra_id, int request_kind);
+int dsend_packet_unit_get_actions(struct connection *pc, int actor_unit_id, int target_unit_id, int target_tile_id, int target_extra_id, int request_kind);
 
 int send_packet_unit_actions(struct connection *pc, const struct packet_unit_actions *packet);
-int dsend_packet_unit_actions(struct connection *pc, int actor_unit_id16, int actor_unit_id32, int target_unit_id16, int target_unit_id32, int target_city_id16, int target_city_id32, int target_tile_id, int target_extra_id, int request_kind, const struct act_prob *action_probabilities);
+int dsend_packet_unit_actions(struct connection *pc, int actor_unit_id, int target_unit_id, int target_city_id, int target_tile_id, int target_extra_id, int request_kind, const struct act_prob *action_probabilities);
 
 int send_packet_unit_change_activity(struct connection *pc, const struct packet_unit_change_activity *packet);
-int dsend_packet_unit_change_activity(struct connection *pc, int unit_id16, int unit_id32, enum unit_activity activity, int target);
+int dsend_packet_unit_change_activity(struct connection *pc, int unit_id, enum unit_activity activity, int target);
 
 int send_packet_diplomacy_init_meeting_req(struct connection *pc, const struct packet_diplomacy_init_meeting_req *packet);
 int dsend_packet_diplomacy_init_meeting_req(struct connection *pc, int counterpart);
@@ -2451,6 +2499,9 @@ void lsend_packet_ruleset_city(struct conn_list *dest, const struct packet_rules
 int send_packet_ruleset_building(struct connection *pc, const struct packet_ruleset_building *packet);
 void lsend_packet_ruleset_building(struct conn_list *dest, const struct packet_ruleset_building *packet);
 
+int send_packet_ruleset_impr_flag(struct connection *pc, const struct packet_ruleset_impr_flag *packet);
+void lsend_packet_ruleset_impr_flag(struct conn_list *dest, const struct packet_ruleset_impr_flag *packet);
+
 int send_packet_ruleset_terrain(struct connection *pc, const struct packet_ruleset_terrain *packet);
 void lsend_packet_ruleset_terrain(struct conn_list *dest, const struct packet_ruleset_terrain *packet);
 
@@ -2493,6 +2544,9 @@ void lsend_packet_ruleset_action_enabler(struct conn_list *dest, const struct pa
 int send_packet_ruleset_action_auto(struct connection *pc, const struct packet_ruleset_action_auto *packet);
 void lsend_packet_ruleset_action_auto(struct conn_list *dest, const struct packet_ruleset_action_auto *packet);
 
+int send_packet_ruleset_counter(struct connection *pc, const struct packet_ruleset_counter *packet);
+void lsend_packet_ruleset_counter(struct conn_list *dest, const struct packet_ruleset_counter *packet);
+
 int send_packet_ruleset_music(struct connection *pc, const struct packet_ruleset_music *packet);
 void lsend_packet_ruleset_music(struct conn_list *dest, const struct packet_ruleset_music *packet);
 
@@ -2520,6 +2574,8 @@ int dsend_packet_single_want_hack_reply(struct connection *pc, bool you_have_hac
 
 int send_packet_ruleset_choices(struct connection *pc, const struct packet_ruleset_choices *packet);
 
+int send_packet_ruleset_select(struct connection *pc, const struct packet_ruleset_select *packet);
+
 int send_packet_game_load(struct connection *pc, const struct packet_game_load *packet);
 void lsend_packet_game_load(struct conn_list *dest, const struct packet_game_load *packet);
 int dsend_packet_game_load(struct connection *pc, bool load_successful, const char *load_filename);
@@ -2574,6 +2630,11 @@ int send_packet_edit_check_tiles(struct connection *pc);
 int send_packet_edit_toggle_fogofwar(struct connection *pc, const struct packet_edit_toggle_fogofwar *packet);
 int dsend_packet_edit_toggle_fogofwar(struct connection *pc, int player);
 
+int send_packet_edit_fogofwar_state(struct connection *pc, const struct packet_edit_fogofwar_state *packet);
+void lsend_packet_edit_fogofwar_state(struct conn_list *dest, const struct packet_edit_fogofwar_state *packet);
+int dsend_packet_edit_fogofwar_state(struct connection *pc, bool enabled);
+void dlsend_packet_edit_fogofwar_state(struct conn_list *dest, bool enabled);
+
 int send_packet_edit_tile_terrain(struct connection *pc, const struct packet_edit_tile_terrain *packet);
 int dsend_packet_edit_tile_terrain(struct connection *pc, int tile, Terrain_type_id terrain, int size);
 
@@ -2594,7 +2655,7 @@ int send_packet_edit_unit_remove(struct connection *pc, const struct packet_edit
 int dsend_packet_edit_unit_remove(struct connection *pc, int owner, int tile, Unit_type_id type, int count);
 
 int send_packet_edit_unit_remove_by_id(struct connection *pc, const struct packet_edit_unit_remove_by_id *packet);
-int dsend_packet_edit_unit_remove_by_id(struct connection *pc, int id16, int id32);
+int dsend_packet_edit_unit_remove_by_id(struct connection *pc, int id);
 
 int send_packet_edit_unit(struct connection *pc, const struct packet_edit_unit *packet);
 
@@ -2602,7 +2663,7 @@ int send_packet_edit_city_create(struct connection *pc, const struct packet_edit
 int dsend_packet_edit_city_create(struct connection *pc, int owner, int tile, int size, int tag);
 
 int send_packet_edit_city_remove(struct connection *pc, const struct packet_edit_city_remove *packet);
-int dsend_packet_edit_city_remove(struct connection *pc, int id16, int id32);
+int dsend_packet_edit_city_remove(struct connection *pc, int id);
 
 int send_packet_edit_city(struct connection *pc, const struct packet_edit_city *packet);
 
@@ -2628,18 +2689,32 @@ int dsend_packet_edit_object_created(struct connection *pc, int tag, int id);
 int send_packet_play_music(struct connection *pc, const struct packet_play_music *packet);
 void lsend_packet_play_music(struct conn_list *dest, const struct packet_play_music *packet);
 
+int send_packet_popup_image(struct connection *pc, const struct packet_popup_image *packet);
+void lsend_packet_popup_image(struct conn_list *dest, const struct packet_popup_image *packet);
+
+int send_packet_sync_serial(struct connection *pc, const struct packet_sync_serial *packet);
+int dsend_packet_sync_serial(struct connection *pc, int serial);
+
+int send_packet_sync_serial_reply(struct connection *pc, const struct packet_sync_serial_reply *packet);
+int dsend_packet_sync_serial_reply(struct connection *pc, int serial);
+
 int send_packet_web_city_info_addition(struct connection *pc, const struct packet_web_city_info_addition *packet, bool force_to_send);
 void lsend_packet_web_city_info_addition(struct conn_list *dest, const struct packet_web_city_info_addition *packet, bool force_to_send);
 
+int send_packet_web_cma_set(struct connection *pc, const struct packet_web_cma_set *packet);
+
+int send_packet_web_cma_clear(struct connection *pc, const struct packet_web_cma_clear *packet);
+
 int send_packet_web_player_info_addition(struct connection *pc, const struct packet_web_player_info_addition *packet);
 
 int send_packet_web_ruleset_unit_addition(struct connection *pc, const struct packet_web_ruleset_unit_addition *packet);
 void lsend_packet_web_ruleset_unit_addition(struct conn_list *dest, const struct packet_web_ruleset_unit_addition *packet);
 
-
 void delta_stats_report(void);
 void delta_stats_reset(void);
 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
+
+#endif /* FC__PACKETS_GEN_H */
