@@ -32,6 +32,7 @@
 #include "idex.h"
 #include "improvement.h"
 #include "map.h"
+#include "nation.h"
 #include "research.h"
 #include "rgbcolor.h"
 #include "tech.h"
@@ -67,7 +68,6 @@ static void player_diplstate_destroy(const struct player *plr1,
 enum diplstate_type cancel_pact_result(enum diplstate_type oldstate)
 {
   switch (oldstate) {
-  case DS_NO_CONTACT: /* possible if someone declares war on our ally */
   case DS_WAR: /* no change */
   case DS_ARMISTICE:
   case DS_CEASEFIRE:
@@ -77,10 +77,16 @@ enum diplstate_type cancel_pact_result(enum diplstate_type oldstate)
     return DS_ARMISTICE;
   case DS_TEAM: /* no change */
     return DS_TEAM;
-  default:
-    log_error("non-pact diplstate %d in cancel_pact_result", oldstate);
-    return DS_WAR; /* arbitrary */
+  case DS_NO_CONTACT:     /* Possible if someone declares war on our ally */
+    return DS_NO_CONTACT; /* Can't cancel lack of contact */
+  case DS_LAST:
+    fc_assert(oldstate != DS_LAST);
+    return DS_WAR; /* Arbitrary */
   }
+
+  fc_assert(FALSE);
+
+  return DS_WAR; /* Arbitrary */
 }
 
 /*******************************************************************//**
@@ -268,6 +274,7 @@ bool player_can_invade_tile(const struct player *pplayer,
 
   return (!ptile_owner
           || ptile_owner == pplayer
+          || terrain_has_flag(tile_terrain(ptile), TER_ENTER_BORDERS)
           || !players_non_invade(pplayer, ptile_owner));
 }
 
@@ -609,7 +616,9 @@ static void player_defaults(struct player *pplayer)
   pplayer->is_connected = FALSE;
   pplayer->current_conn = NULL;
   pplayer->connections = conn_list_new();
+  pplayer->autoselect_weight = -1;
   BV_CLR_ALL(pplayer->gives_shared_vision);
+  BV_CLR_ALL(pplayer->gives_shared_tiles);
   for (i = 0; i < B_LAST; i++) {
     pplayer->wonders[i] = WONDER_NOT_BUILT;
   }
@@ -1076,10 +1085,21 @@ bool can_player_see_unit_at(const struct player *pplayer,
                                           unit_type_get(punit)->vlayer);
 }
 
+/**********************************************************************//**
+  Returns TRUE iff the specified player can see the specified tile.
+**************************************************************************/
+bool can_player_see_tile(const struct player *plr,
+                         const struct tile *ptile)
+{
+  return plr != nullptr
+    && ptile != nullptr
+    && (tile_get_known(ptile, plr) == TILE_KNOWN_SEEN);
+}
+
 /*******************************************************************//**
   Checks if a unit can be seen by pplayer at its current location.
 
-  See can_player_see_unit_at.
+  See can_player_see_unit_at().
 ***********************************************************************/
 bool can_player_see_unit(const struct player *pplayer,
 			 const struct unit *punit)
@@ -1089,25 +1109,25 @@ bool can_player_see_unit(const struct player *pplayer,
 }
 
 /*******************************************************************//**
-  Return TRUE iff the player can see units in the city.  Either they
+  Return TRUE iff the player can see units in the city. Either they
   can see all units or none.
 
   If the player can see units in the city, then the server sends the
-  unit info for units in the city to the client.  The client uses the
-  tile's unitlist to determine whether to show the city occupied flag.  Of
-  course the units will be visible to the player as well, if they click on
-  them.
+  unit info for units in the city to the client. The client uses the
+  tile's unitlist to determine whether to show the city occupied flag.
+  Of course the units will be visible to the player as well, if they
+  click on them.
 
   If the player can't see units in the city, then the server doesn't send
-  the unit info for these units.  The client therefore uses the "occupied"
+  the unit info for these units. The client therefore uses the "occupied"
   flag sent in the short city packet to determine whether to show the city
   occupied flag.
 
-  Note that can_player_see_city_internals => can_player_see_units_in_city.
+  Note that can_player_see_city_internals() => can_player_see_units_in_city().
   Otherwise the player would not know anything about the city's units at
   all, since the full city packet has no "occupied" flag.
 
-  Returns TRUE if given a NULL player.  This is used by the client when in
+  Returns TRUE if given a NULL player. This is used by the client when in
   observer mode.
 ***********************************************************************/
 bool can_player_see_units_in_city(const struct player *pplayer,
@@ -1119,11 +1139,11 @@ bool can_player_see_units_in_city(const struct player *pplayer,
 }
 
 /*******************************************************************//**
-  Return TRUE iff the player can see the city's internals.  This means the
+  Return TRUE iff the player can see the city's internals. This means the
   full city packet is sent to the client, who should then be able to popup
   a dialog for it.
 
-  Returns TRUE if given a NULL player.  This is used by the client when in
+  Returns TRUE if given a NULL player. This is used by the client when in
   observer mode.
 ***********************************************************************/
 bool can_player_see_city_internals(const struct player *pplayer,
@@ -1137,11 +1157,13 @@ bool can_player_see_city_internals(const struct player *pplayer,
   target_city.
 
   A city's external features are visible to its owner, to players that
-  currently sees the tile it is located at and to players that has it as
-  a trade partner.
+  currently sees the tile it is located at.
+  If ruleset has reveal_trade_partner enabled, also anyone trading
+  with the city sees it.
 ***********************************************************************/
 bool player_can_see_city_externals(const struct player *pow_player,
-                                   const struct city *target_city) {
+                                   const struct city *target_city)
+{
   fc_assert_ret_val(target_city, FALSE);
   fc_assert_ret_val(pow_player, FALSE);
 
@@ -1157,12 +1179,14 @@ bool player_can_see_city_externals(const struct player *pow_player,
 
   fc_assert_ret_val(target_city->routes, FALSE);
 
-  trade_partners_iterate(target_city, trade_city) {
-    if (city_owner(trade_city) == pow_player) {
-      /* Revealed because of the trade route. */
-      return TRUE;
-    }
-  } trade_partners_iterate_end;
+  if (game.info.reveal_trade_partner) {
+    trade_partners_iterate(target_city, trade_city) {
+      if (city_owner(trade_city) == pow_player) {
+        /* Revealed because of the trade route. */
+        return TRUE;
+      }
+    } trade_partners_iterate_end;
+  }
 
   return FALSE;
 }
@@ -1463,6 +1487,14 @@ bool gives_shared_vision(const struct player *me, const struct player *them)
   return BV_ISSET(me->gives_shared_vision, player_index(them));
 }
 
+/*******************************************************************//**
+  Return TRUE iff the player me gives shared tiles to player them.
+***********************************************************************/
+bool gives_shared_tiles(const struct player *me, const struct player *them)
+{
+  return BV_ISSET(me->gives_shared_tiles, player_index(them));
+}
+
 /*******************************************************************//**
   Return TRUE iff the two diplstates are equal.
 ***********************************************************************/
@@ -1500,8 +1532,12 @@ bool is_diplrel_between(const struct player *player1,
     return gives_shared_vision(player2, player1);
   case DRO_HOSTS_EMBASSY:
     return player_has_embassy(player2, player1);
+  case DRO_HOSTS_TEAM_EMBASSY:
+    return team_has_embassy(player2->team, player1);
   case DRO_HAS_EMBASSY:
     return player_has_embassy(player1, player2);
+  case DRO_HAS_TEAM_EMBASSY:
+    return team_has_embassy(player1->team, player2);
   case DRO_HOSTS_REAL_EMBASSY:
     return player_has_real_embassy(player2, player1);
   case DRO_HAS_REAL_EMBASSY:
@@ -1836,7 +1872,7 @@ bv_diplrel_all_reqs diplrel_req_contradicts(const struct requirement *req)
 
 /*******************************************************************//**
   Return the number of pplayer2's visible units in pplayer's territory,
-  from the point of view of pplayer.  Units that cannot be seen by pplayer
+  from the point of view of pplayer. Units that cannot be seen by pplayer
   will not be found (this function doesn't cheat).
 ***********************************************************************/
 int player_in_territory(const struct player *pplayer,
@@ -1844,11 +1880,11 @@ int player_in_territory(const struct player *pplayer,
 {
   int in_territory = 0;
 
-  /* This algorithm should work at server or client.  It only returns the
+  /* This algorithm should work at server or client. It only returns the
    * number of visible units (a unit can potentially hide inside the
    * transport of a different player).
    *
-   * Note this may be quite slow.  An even slower alternative is to iterate
+   * Note this may be quite slow. An even slower alternative is to iterate
    * over the entire map, checking all units inside the player's territory
    * to see if they're owned by the enemy. */
   unit_list_iterate(pplayer2->units, punit) {
@@ -1857,7 +1893,7 @@ int player_in_territory(const struct player *pplayer,
 
     if (owner == pplayer && can_player_see_unit(pplayer, punit)) {
       /* Found one! */
-      in_territory += 1;
+      in_territory++;
     }
   } unit_list_iterate_end;
 
@@ -1865,7 +1901,7 @@ int player_in_territory(const struct player *pplayer,
 }
 
 /*******************************************************************//**
-  Returns whether this is a valid username.  This is used by the server to
+  Returns whether this is a valid username. This is used by the server to
   validate usernames and should be used by the client to avoid invalid
   ones.
 ***********************************************************************/
@@ -1955,3 +1991,23 @@ bool player_has_flag(const struct player *pplayer, enum plr_flag_id flag)
 {
   return BV_ISSET(pplayer->flags, flag);
 }
+
+/*******************************************************************//**
+  Check if player has given state
+***********************************************************************/
+bool player_has_state(const struct player *pplayer,
+                      enum plrstate_type state)
+{
+  switch (state) {
+  case PLRS_BARBARIAN:
+    return is_barbarian(pplayer);
+  case PLRS_HAS_CAPITAL:
+    return player_primary_capital(pplayer) != NULL;
+  case PLRS_LAST:
+    fc_assert(state != PLRS_LAST);
+    break;
+  }
+
+  fc_assert(plrstate_type_is_valid(state));
+  return FALSE;
+}
