@@ -184,11 +184,11 @@ struct advance *valid_advance_by_number(const Tech_type_id id)
 **************************************************************************/
 struct advance *advance_by_translated_name(const char *name)
 {
-  advance_iterate(A_NONE, padvance) {
+  advance_iterate_all(padvance) {
     if (0 == strcmp(advance_name_translation(padvance), name)) {
       return padvance;
     }
-  } advance_iterate_end;
+  } advance_iterate_all_end;
 
   return NULL;
 }
@@ -201,11 +201,11 @@ struct advance *advance_by_rule_name(const char *name)
 {
   const char *qname = Qn_(name);
 
-  advance_iterate(A_NONE, padvance) {
+  advance_iterate_all(padvance) {
     if (0 == fc_strcasecmp(advance_rule_name(padvance), qname)) {
       return padvance;
     }
-  } advance_iterate_end;
+  } advance_iterate_all_end;
 
   return NULL;
 }
@@ -227,7 +227,7 @@ void techs_precalc_data(void)
   fc_assert_msg(tech_cost_style_is_valid(game.info.tech_cost_style),
                 "Invalid tech_cost_style %d", game.info.tech_cost_style);
 
-  advance_iterate(A_FIRST, padvance) {
+  advance_iterate(padvance) {
     int num_reqs = 0;
     bool min_req = TRUE;
 
@@ -264,8 +264,8 @@ void techs_precalc_data(void)
       break;
     }
 
-    if (min_req && padvance->cost < game.info.base_tech_cost) {
-      padvance->cost = game.info.base_tech_cost;
+    if (min_req && padvance->cost < game.info.min_tech_cost) {
+      padvance->cost = game.info.min_tech_cost;
     }
 
     /* Class cost */
