@@ -2,12 +2,12 @@
 
 # build_appimages.sh: Build freeciv AppImages
 #
-# (c) 2024 Freeciv team
+# (c) 2024-2025 Freeciv team
 #
 # This script is licensed under Gnu General Public License version 2 or later.
 # See COPYING available from the same location you got this script.
 
-LINUXDEPLOY_VERSION="2.0.0-alpha-1-20241106"
+LINUXDEPLOY_VERSION="1-alpha-20250213-2"
 
 if test "$1" != "" ; then
   echo "Usage: $0"
@@ -26,6 +26,7 @@ fi
 # $1 - Client type
 # $2 - Client configuration name
 # $3 - Client part of the AppImage name as produced by linuxdeploy
+# $4 - Extra configure options
 client_appimage() {
   if ! mkdir "AppDir/$1" || ! mkdir "build/$1" ; then
     echo "Failed to create $1 directories!" >&2
@@ -33,8 +34,7 @@ client_appimage() {
   fi
 
   cd "build/$1"
-  if ! meson setup -Dack_experimental=true -Dappimage=true -Dprefix=/usr -Ddefault_library=static \
-                   -Dclients=$2 -Dfcmp=[] -Druledit=false "${SRC_ROOT}"
+  if ! meson setup -Dappimage=true -Dprefix=/usr -Ddefault_library=static -Dclients=$2 -Dfcmp=[] -Dtools=[] $4 "${SRC_ROOT}"
   then
     echo "$1 setup with meson failed!" >&2
     return 1
@@ -66,8 +66,7 @@ ruledit_appimage() {
   fi
 
   cd "build/ruledit-$1"
-  if ! meson setup -Dack_experimental=true -Dappimage=true -Dprefix=/usr -Ddefault_library=static \
-                   -Dclients=[] -Dfcmp=[] -Druledit=true -Dqtver=$1 "${SRC_ROOT}"
+  if ! meson setup -Dappimage=true -Dprefix=/usr -Ddefault_library=static -Dclients=[] -Dfcmp=[] -Dtools='ruledit' -Dqtver=$1 "${SRC_ROOT}"
   then
     echo "ruledit-$1 setup with meson failed!" >&2
     return 1
@@ -93,6 +92,11 @@ ruledit_appimage() {
 
 FCVER="$("${SRC_ROOT}/fc_version")"
 
+if ! command -v wget2 >/dev/null ; then
+  echo "No wget2 command found!" >&2
+  exit 1
+fi
+
 if ! mkdir tools ||
    ! mkdir -p AppDir/server ||
    ! mkdir -p build/server
@@ -102,7 +106,7 @@ then
 fi
 
 if ! ( cd tools &&
-       wget "https://github.com/linuxdeploy/linuxdeploy/releases/download/${LINUXDEPLOY_VERSION}/linuxdeploy-x86_64.AppImage" )
+       wget2 "https://github.com/linuxdeploy/linuxdeploy/releases/download/${LINUXDEPLOY_VERSION}/linuxdeploy-x86_64.AppImage" )
 then
   echo "Failed to download linuxdeploy!" >&2
   exit 1
@@ -110,8 +114,7 @@ fi
 chmod u+x tools/linuxdeploy-x86_64.AppImage
 
 cd build/server
-if ! meson setup -Dack_experimental=true -Dappimage=true -Dprefix=/usr -Ddefault_library=static \
-                 -Dclients=[] -Dfcmp=[] -Druledit=false "${SRC_ROOT}"
+if ! meson setup -Dappimage=true -Dprefix=/usr -Ddefault_library=static -Dclients=[] -Dfcmp=[] -Dtools=[] "${SRC_ROOT}"
 then
   echo "Server setup with meson failed!" >&2
   exit 1
@@ -137,7 +140,8 @@ fi
 if ! client_appimage gtk4    gtk4    ""        ||
    ! client_appimage sdl2    sdl2    "_(SDL2)" ||
    ! client_appimage qt6     qt      "_(Qt)"   ||
-   ! client_appimage gtk3.22 gtk3.22 ""
+   ! client_appimage gtk3.22 gtk3.22 ""        ||
+   ! client_appimage sdl3    sdl3    "_(SDL3)" "-Daudio=none"
 then
   exit 1
 fi
