@@ -20,7 +20,6 @@
 #include <string.h>
 
 /* utility */
-#include "capability.h"
 #include "fcintl.h"
 #include "log.h"
 #include "mem.h"
@@ -57,22 +56,15 @@
   suggested name and with same id which was passed in (either unit id
   for city builder or existing city id for rename, we don't care here).
 **************************************************************************/
-void handle_city_name_suggestion_req(struct player *pplayer, int unit_id16,
-                                     int unit_id32)
+void handle_city_name_suggestion_req(struct player *pplayer, int unit_id)
 {
-  struct unit *punit;
+  struct unit *punit = player_unit_by_number(pplayer, unit_id);
   const struct civ_map *nmap = &(wld.map);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    unit_id32 = unit_id16;
-  }
-
-  punit = player_unit_by_number(pplayer, unit_id32);
-
   if (NULL == punit) {
     /* Probably died or bribed. */
     log_verbose("handle_city_name_suggestion_req() invalid unit %d",
-                unit_id32);
+                unit_id);
     return;
   }
 
@@ -80,8 +72,7 @@ void handle_city_name_suggestion_req(struct player *pplayer, int unit_id16,
                                                unit_tile(punit), NULL))) {
     log_verbose("handle_city_name_suggest_req(unit_pos (%d, %d))",
                 TILE_XY(unit_tile(punit)));
-    dlsend_packet_city_name_suggestion_info(pplayer->connections,
-                                            unit_id32, unit_id32,
+    dlsend_packet_city_name_suggestion_info(pplayer->connections, unit_id,
         city_name_suggestion(pplayer, unit_tile(punit)));
 
     /* The rest of this function is error handling. */
@@ -98,20 +89,13 @@ void handle_city_name_suggestion_req(struct player *pplayer, int unit_id16,
 /**********************************************************************//**
   Handle request to change specialist type
 **************************************************************************/
-void handle_city_change_specialist(struct player *pplayer,
-                                   int city_id16, int city_id32,
+void handle_city_change_specialist(struct player *pplayer, int city_id,
 				   Specialist_type_id from,
 				   Specialist_type_id to)
 {
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, city_id);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
-
-  if (pcity == NULL) {
+  if (!pcity) {
     return;
   }
 
@@ -137,22 +121,15 @@ void handle_city_change_specialist(struct player *pplayer,
   Handle request to change city worker in to specialist.
 **************************************************************************/
 void handle_city_make_specialist(struct player *pplayer,
-                                 int city_id16, int city_id32, int tile_id)
+                                 int city_id, int tile_id)
 {
-  struct tile *ptile;
-  struct city *pcity;
-
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  ptile = index_to_tile(&(wld.map), tile_id);
-  pcity = player_city_by_number(pplayer, city_id32);
+  struct tile *ptile = index_to_tile(&(wld.map), tile_id);
+  struct city *pcity = player_city_by_number(pplayer, city_id);
 
   if (NULL == pcity) {
     /* Probably lost. */
     log_verbose("handle_city_make_specialist() bad city number %d.",
-                city_id32);
+                city_id);
     return;
   }
 
@@ -167,6 +144,9 @@ void handle_city_make_specialist(struct player *pplayer,
     return;
   }
 
+  /* Disable server side governor being overridden */
+  handle_web_cma_clear(pplayer, pcity->id);
+
   if (is_free_worked(pcity, ptile)) {
     auto_arrange_workers(pcity);
   } else if (tile_worked(ptile) == pcity) {
@@ -188,20 +168,14 @@ void handle_city_make_specialist(struct player *pplayer,
   from first available specialist.
 **************************************************************************/
 void handle_city_make_worker(struct player *pplayer,
-                             int city_id16, int city_id32, int tile_id)
+                             int city_id, int tile_id)
 {
   struct tile *ptile = index_to_tile(&(wld.map), tile_id);
-  struct city *pcity;
-
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
+  struct city *pcity = player_city_by_number(pplayer, city_id);
 
   if (NULL == pcity) {
     /* Probably lost. */
-    log_verbose("handle_city_make_worker() bad city number %d.", city_id32);
+    log_verbose("handle_city_make_worker() bad city number %d.",city_id);
     return;
   }
 
@@ -217,6 +191,9 @@ void handle_city_make_worker(struct player *pplayer,
   }
 
   if (is_free_worked(pcity, ptile)) {
+    /* Disable server side governor being overridden */
+    handle_web_cma_clear(pplayer, pcity->id);
+
     auto_arrange_workers(pcity);
     sync_cities();
     return;
@@ -240,6 +217,9 @@ void handle_city_make_worker(struct player *pplayer,
     return;
   }
 
+  /* Disable server side governor being overridden */
+  handle_web_cma_clear(pplayer, pcity->id);
+
   city_map_update_worker(pcity, ptile);
 
   specialist_type_iterate(i) {
@@ -276,7 +256,7 @@ void really_handle_city_sell(struct player *pplayer, struct city *pcity,
     return;
   }
 
-  pcity->did_sell=TRUE;
+  pcity->did_sell = TRUE;
   price = impr_sell_gold(pimprove);
   notify_player(pplayer, pcity->tile, E_IMP_SOLD, ftc_server,
                 PL_("You sell %s in %s for %d gold.",
@@ -296,22 +276,14 @@ void really_handle_city_sell(struct player *pplayer, struct city *pcity,
   Handle improvement selling request. This function does check its
   parameters as they may come from untrusted source over the network.
 **************************************************************************/
-void handle_city_sell(struct player *pplayer, int city_id16, int city_id32,
-                      int build_id)
+void handle_city_sell(struct player *pplayer, int city_id, int build_id)
 {
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, city_id);
   struct impr_type *pimprove = improvement_by_number(build_id);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
-
   if (!pcity || !pimprove) {
     return;
   }
-
   really_handle_city_sell(pplayer, pcity, pimprove);
 }
 
@@ -339,7 +311,7 @@ void really_handle_city_buy(struct player *pplayer, struct city *pcity)
     return;
   }
 
-  if (city_production_has_flag(pcity, IF_GOLD)) {
+  if (city_production_is_genus(pcity, IG_CONVERT)) {
     notify_player(pplayer, pcity->tile, E_BAD_COMMAND, ftc_server,
                   _("You don't buy %s!"),
                   improvement_name_translation(pcity->production.value.building));
@@ -381,7 +353,7 @@ void really_handle_city_buy(struct player *pplayer, struct city *pcity)
     /* As we never put penalty on disbanded_shields, we can
      * fully well add the missing shields there. */
     pcity->disbanded_shields += total - pcity->shield_stock;
-    pcity->shield_stock=total; /* AI wants this -- Syela */
+    pcity->shield_stock = total; /* AI wants this -- Syela */
     pcity->did_buy = TRUE;	/* !PS: no need to set buy flag otherwise */
   }
   city_refresh(pcity);
@@ -409,18 +381,12 @@ void really_handle_city_buy(struct player *pplayer, struct city *pcity)
 /**********************************************************************//**
   Handle city worklist update request
 **************************************************************************/
-void handle_city_worklist(struct player *pplayer, int city_id16, int city_id32,
+void handle_city_worklist(struct player *pplayer, int city_id,
                           const struct worklist *worklist)
 {
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, city_id);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
-
-  if (pcity == NULL) {
+  if (!pcity) {
     return;
   }
 
@@ -433,17 +399,11 @@ void handle_city_worklist(struct player *pplayer, int city_id16, int city_id32,
   Handle buying request. This function does properly check its input as
   it may come from untrusted source over the network.
 **************************************************************************/
-void handle_city_buy(struct player *pplayer, int city_id16, int city_id32)
+void handle_city_buy(struct player *pplayer, int city_id)
 {
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, city_id);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
-
-  if (pcity == NULL) {
+  if (!pcity) {
     return;
   }
 
@@ -453,16 +413,12 @@ void handle_city_buy(struct player *pplayer, int city_id16, int city_id32)
 /**********************************************************************//**
   Handle city refresh request
 **************************************************************************/
-void handle_city_refresh(struct player *pplayer, int city_id16, int city_id32)
+void handle_city_refresh(struct player *pplayer, int city_id)
 {
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
+  if (city_id != 0) {
+    struct city *pcity = player_city_by_number(pplayer, city_id);
 
-  if (city_id32 != 0) {
-    struct city *pcity = player_city_by_number(pplayer, city_id32);
-
-    if (pcity == NULL) {
+    if (!pcity) {
       return;
     }
 
@@ -476,19 +432,13 @@ void handle_city_refresh(struct player *pplayer, int city_id16, int city_id32)
 /**********************************************************************//**
   Handle request to change current production.
 **************************************************************************/
-void handle_city_change(struct player *pplayer, int city_id16, int city_id32,
+void handle_city_change(struct player *pplayer, int city_id,
                         int production_kind, int production_value)
 {
   struct universal prod;
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, city_id);
   const struct civ_map *nmap = &(wld.map);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
-
   if (!universals_n_is_valid(production_kind)) {
     log_error("[%s] bad production_kind %d.", __FUNCTION__,
               production_kind);
@@ -504,7 +454,7 @@ void handle_city_change(struct player *pplayer, int city_id16, int city_id32,
     }
   }
 
-  if (pcity == NULL) {
+  if (!pcity) {
     return;
   }
 
@@ -532,18 +482,12 @@ void handle_city_change(struct player *pplayer, int city_id16, int city_id32,
 /**********************************************************************//**
   Handle city rename request packet.
 **************************************************************************/
-void handle_city_rename(struct player *pplayer, int city_id16, int city_id32,
+void handle_city_rename(struct player *pplayer, int city_id,
                         const char *name)
 {
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, city_id);
   char message[1024];
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
-
   if (pcity == NULL) {
     return;
   }
@@ -563,23 +507,18 @@ void handle_city_rename(struct player *pplayer, int city_id16, int city_id32,
   Handles a packet from the client that requests the city options for the
   given city be changed.
 **************************************************************************/
-void handle_city_options_req(struct player *pplayer,
-                             int city_id16, int city_id32,
-			     bv_city_options options)
+void handle_city_options_req(struct player *pplayer, int city_id,
+			     bv_city_options options,
+                             enum city_wl_cancel_behavior wlcb)
 {
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, city_id);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    city_id32 = city_id16;
-  }
-
-  pcity = player_city_by_number(pplayer, city_id32);
-
-  if (pcity == NULL) {
+  if (!pcity) {
     return;
   }
 
   pcity->city_options = options;
+  pcity->wlcb = wlcb;
 
   send_city_info(pplayer, pcity);
 }
@@ -590,16 +529,52 @@ void handle_city_options_req(struct player *pplayer,
 void handle_city_rally_point(struct player *pplayer,
                              const struct packet_city_rally_point *packet)
 {
-  struct city *pcity;
+  struct city *pcity = player_city_by_number(pplayer, packet->id);
 
-  if (!has_capability("ids32", pplayer->current_conn->capability)) {
-    pcity = player_city_by_number(pplayer, packet->city_id16);
-  } else {
-    pcity = player_city_by_number(pplayer, packet->city_id32);
-  }
-
-  if (pcity != NULL) {
+  if (NULL != pcity) {
     city_rally_point_receive(packet, pcity);
     send_city_info(pplayer, pcity);
   }
 }
+
+/**********************************************************************//**
+  Handles a request to change city CMA settings.
+**************************************************************************/
+void handle_web_cma_set(struct player *pplayer, int id,
+                        const struct cm_parameter *param)
+{
+  /* Supported only in freeciv-web builds for now -
+   * Let's be cautious for now, and not give any chance
+   * of client requests of server side CMA to overload
+   * server from a standard build. */
+#ifdef FREECIV_WEB
+  struct city *pcity = player_city_by_number(pplayer, id);
+
+  if (pcity != NULL) {
+    if (pcity->cm_parameter == NULL) {
+      pcity->cm_parameter = fc_calloc(1, sizeof(struct cm_parameter));
+    }
+
+    cm_copy_parameter(pcity->cm_parameter, param);
+    pcity->server.synced = FALSE;
+
+    auto_arrange_workers(pcity);
+
+    sync_cities();
+  }
+#endif /* FREECIV_WEB */
+}
+
+/**********************************************************************//**
+  Handles a request to clear city CMA settings.
+**************************************************************************/
+void handle_web_cma_clear(struct player *pplayer, int id)
+{
+  struct city *pcity = player_city_by_number(pplayer, id);
+
+  if (pcity != NULL && pcity->cm_parameter != NULL) {
+    free(pcity->cm_parameter);
+    pcity->cm_parameter = NULL;
+    send_city_info(pplayer, pcity);
+  }
+}
