@@ -42,6 +42,9 @@ class edit_gov : public values_dlg
     struct government *gov;
     QLineEdit *gfx_tag;
     QLineEdit *gfx_tag_alt;
+    QLineEdit *sound_tag;
+    QLineEdit *sound_tag_alt;
+    QLineEdit *sound_tag_alt2;
 
   protected:
     void closeEvent(QCloseEvent *cevent);
@@ -49,6 +52,9 @@ class edit_gov : public values_dlg
   private slots:
     void gfx_tag_given();
     void gfx_tag_alt_given();
+    void sound_tag_given();
+    void sound_tag_alt_given();
+    void sound_tag_alt2_given();
     void helptext();
 };
 
