@@ -44,7 +44,6 @@ edit_utype::edit_utype(ruledit_gui *ui_in, struct unit_type *utype_in) : values_
   QGridLayout *unit_layout = new QGridLayout();
   QLabel *label;
   QPushButton *button;
-  QMenu *req;
   QMenu *menu;
   int row = 0;
   int rowcount;
@@ -58,21 +57,6 @@ edit_utype::edit_utype(ruledit_gui *ui_in, struct unit_type *utype_in) : values_
 
   setWindowTitle(QString::fromUtf8(utype_rule_name(utype)));
 
-  label = new QLabel(QString::fromUtf8(R__("Requirement")));
-  label->setParent(this);
-
-  req = new QMenu();
-  req_button = new QToolButton();
-  req_button->setParent(this);
-  req_button->setToolButtonStyle(Qt::ToolButtonTextOnly);
-  req_button->setPopupMode(QToolButton::MenuButtonPopup);
-  req_button->setMenu(req);
-  tab_tech::techs_to_menu(req);
-  connect(req_button, SIGNAL(triggered(QAction *)), this, SLOT(req_menu(QAction *)));
-
-  unit_layout->addWidget(label, row, 0);
-  unit_layout->addWidget(req_button, row++, 1);
-
   label = new QLabel(QString::fromUtf8(R__("Class")));
   label->setParent(this);
   class_button = new QToolButton();
@@ -180,6 +164,15 @@ edit_utype::edit_utype(ruledit_gui *ui_in, struct unit_type *utype_in) : values_
   unit_layout->addWidget(label, row, 0);
   unit_layout->addWidget(gfx_tag_alt, row++, 1);
 
+  label = new QLabel(QString::fromUtf8(R__("Second alt gfx tag")));
+  label->setParent(this);
+
+  gfx_tag_alt2 = new QLineEdit(this);
+  connect(gfx_tag_alt2, SIGNAL(returnPressed()), this, SLOT(gfx_tag_alt2_given()));
+
+  unit_layout->addWidget(label, row, 0);
+  unit_layout->addWidget(gfx_tag_alt2, row++, 1);
+
   label = new QLabel(QString::fromUtf8(R__("Move sound tag")));
   label->setParent(this);
 
@@ -276,6 +269,7 @@ void edit_utype::closeEvent(QCloseEvent *cevent)
   // Save values from text fields.
   gfx_tag_given();
   gfx_tag_alt_given();
+  gfx_tag_alt2_given();
   sound_move_tag_given();
   sound_move_tag_alt_given();
   sound_fight_tag_given();
@@ -314,7 +308,6 @@ void edit_utype::closeEvent(QCloseEvent *cevent)
 **************************************************************************/
 void edit_utype::refresh()
 {
-  req_button->setText(tab_tech::tech_name(utype->require_advance));
   class_button->setText(uclass_rule_name(utype->uclass));
   bcost->setValue(utype->build_cost);
   attack->setValue(utype->attack_strength);
@@ -325,30 +318,13 @@ void edit_utype::refresh()
   cargo_capacity->setValue(utype->transport_capacity);
   gfx_tag->setText(utype->graphic_str);
   gfx_tag_alt->setText(utype->graphic_alt);
+  gfx_tag_alt2->setText(utype->graphic_alt2);
   sound_move_tag->setText(utype->sound_move);
   sound_move_tag_alt->setText(utype->sound_move_alt);
   sound_fight_tag->setText(utype->sound_fight);
   sound_fight_tag_alt->setText(utype->sound_fight_alt);
 }
 
-/**********************************************************************//**
-  User selected tech to be req of utype
-**************************************************************************/
-void edit_utype::req_menu(QAction *action)
-{
-  struct advance *padv;
-  QByteArray an_bytes;
-
-  an_bytes = action->text().toUtf8();
-  padv = advance_by_rule_name(an_bytes.data());
-
-  if (padv != nullptr) {
-    utype->require_advance = padv;
-
-    refresh();
-  }
-}
-
 /**********************************************************************//**
   Read build cost value from spinbox
 **************************************************************************/
@@ -425,6 +401,16 @@ void edit_utype::gfx_tag_alt_given()
   sz_strlcpy(utype->graphic_alt, tag_bytes);
 }
 
+/**********************************************************************//**
+  User entered new secondary alternative graphics tag.
+**************************************************************************/
+void edit_utype::gfx_tag_alt2_given()
+{
+  QByteArray tag_bytes = gfx_tag_alt2->text().toUtf8();
+
+  sz_strlcpy(utype->graphic_alt2, tag_bytes);
+}
+
 /**********************************************************************//**
   User entered new move sound tag.
 **************************************************************************/
