@@ -96,6 +96,7 @@ tab_enabler::tab_enabler(ruledit_gui *ui_in) : QWidget()
   QGridLayout *enabler_layout = new QGridLayout();
   QLabel *label;
   QPushButton *add_button;
+  int row = 0;
 
   ui = ui_in;
   connect(ui, SIGNAL(req_vec_may_have_changed(const requirement_vector *)),
@@ -112,7 +113,7 @@ tab_enabler::tab_enabler(ruledit_gui *ui_in) : QWidget()
 
   label = new QLabel(QString::fromUtf8(R__("Type")));
   label->setParent(this);
-  enabler_layout->addWidget(label, 0, 0);
+  enabler_layout->addWidget(label, row, 0);
 
   type_button = new QToolButton();
   type_menu = new QMenu();
@@ -131,14 +132,14 @@ tab_enabler::tab_enabler(ruledit_gui *ui_in) : QWidget()
   type_button->setText(R__("None"));
 
   type_button->setEnabled(false);
-  enabler_layout->addWidget(type_button, 0, 2);
+  enabler_layout->addWidget(type_button, row++, 1);
 
   act_reqs_button
       = new QPushButton(QString::fromUtf8(R__("Actor Requirements")), this);
   connect(act_reqs_button, SIGNAL(pressed()),
           this, SLOT(edit_actor_reqs()));
   act_reqs_button->setEnabled(false);
-  enabler_layout->addWidget(act_reqs_button, 1, 2);
+  enabler_layout->addWidget(act_reqs_button, row++, 1);
 
   tgt_reqs_button
       = new QPushButton(QString::fromUtf8(R__("Target Requirements")),
@@ -146,24 +147,22 @@ tab_enabler::tab_enabler(ruledit_gui *ui_in) : QWidget()
   connect(tgt_reqs_button, SIGNAL(pressed()),
           this, SLOT(edit_target_reqs()));
   tgt_reqs_button->setEnabled(false);
-  enabler_layout->addWidget(tgt_reqs_button, 2, 2);
+  enabler_layout->addWidget(tgt_reqs_button, row++, 1);
 
   add_button = new QPushButton(QString::fromUtf8(R__("Add Enabler")), this);
   connect(add_button, SIGNAL(pressed()), this, SLOT(add_now()));
-  enabler_layout->addWidget(add_button, 3, 0);
-  show_experimental(add_button);
+  enabler_layout->addWidget(add_button, row, 0);
 
   delete_button = new QPushButton(QString::fromUtf8(R__("Remove this Enabler")), this);
   connect(delete_button, SIGNAL(pressed()), this, SLOT(delete_now()));
   delete_button->setEnabled(false);
-  enabler_layout->addWidget(delete_button, 3, 2);
-  show_experimental(delete_button);
+  enabler_layout->addWidget(delete_button, row++, 1);
 
   repair_button = new QPushButton(this);
   connect(repair_button, SIGNAL(pressed()), this, SLOT(repair_now()));
   repair_button->setEnabled(false);
   repair_button->setText(QString::fromUtf8(R__("Enabler Issues")));
-  enabler_layout->addWidget(repair_button, 3, 1);
+  enabler_layout->addWidget(repair_button, row++, 1);
 
   refresh();
 
@@ -222,15 +221,15 @@ void tab_enabler::update_enabler_info(struct action_enabler *enabler)
 
     switch (enabler_problem_level(selected)) {
     case RVPS_REPAIR:
-      /* Offer to repair the enabler if it has a problem. */
-      /* TRANS: Fix an error in an action enabler. */
+      // Offer to repair the enabler if it has a problem.
+      // TRANS: Fix an error in an action enabler.
       repair_button->setText(QString::fromUtf8(R__("Repair Enabler")));
       repair_button->setEnabled(TRUE);
       break;
     case RVPS_IMPROVE:
-        /* TRANS: Fix a non error issue in an action enabler. */
-        repair_button->setText(QString::fromUtf8(R__("Improve Enabler")));
-        repair_button->setEnabled(true);
+      // TRANS: Fix a non error issue in an action enabler.
+      repair_button->setText(QString::fromUtf8(R__("Improve Enabler")));
+      repair_button->setEnabled(true);
       break;
     case RVPS_NO_PROBLEM:
       repair_button->setText(QString::fromUtf8(R__("Enabler Issues")));
@@ -250,7 +249,7 @@ void tab_enabler::update_enabler_info(struct action_enabler *enabler)
     delete_button->setEnabled(false);
   }
 
-  /* The enabler may have gotten (rid of) a problem. */
+  // The enabler may have gotten (rid of) a problem.
   action_enablers_iterate(other_enabler) {
     QListWidgetItem *item = enabler_list->item(i++);
 
@@ -297,6 +296,8 @@ void tab_enabler::delete_now()
 **************************************************************************/
 bool tab_enabler::initialize_new_enabler(struct action_enabler *enabler)
 {
+  enabler->ruledit_disabled = false;
+
   return true;
 }
 
@@ -311,7 +312,6 @@ void tab_enabler::add_now()
   action_enablers_iterate(enabler) {
     if (enabler->ruledit_disabled) {
       if (initialize_new_enabler(enabler)) {
-        enabler->ruledit_disabled = false;
         update_enabler_info(enabler);
         refresh();
       }
@@ -338,7 +338,7 @@ void tab_enabler::add_now()
 void tab_enabler::repair_now()
 {
   if (selected == nullptr) {
-    /* Nothing to repair */
+    // Nothing to repair
     return;
   }
 
@@ -370,12 +370,12 @@ void tab_enabler::edit_type(QAction *action)
   paction = action_by_rule_name(an_bytes.data());
 
   if (selected != nullptr && paction != nullptr) {
-    /* Must remove and add back because enablers are stored by action. */
+    // Must remove and add back because enablers are stored by action.
     action_enabler_remove(selected);
-    selected->action = paction->id;
+    selected->action = action_id(paction);
     action_enabler_add(selected);
 
-    /* Show the changes. */
+    // Show the changes.
     update_enabler_info(selected);
     refresh();
   }
@@ -410,20 +410,20 @@ void tab_enabler::edit_actor_reqs()
 fix_enabler_item::fix_enabler_item(struct action_enabler *enabler)
 {
   char buf[MAX_LEN_NAME * 2];
-  struct action *paction = action_by_number(enabler->action);
+  struct action *paction = enabler_get_action(enabler);
 
-  fc_assert_ret(paction);
+  fc_assert_ret(paction != NULL);
 
   /* Can't use QString::asprintf() as msys libintl.h defines asprintf()
    * as a macro */
   fc_snprintf(buf, sizeof(buf),
               R__("action enabler for %s"), action_rule_name(paction));
 
-  /* Don't modify the original until the user accepts */
+  // Don't modify the original until the user accepts
   local_copy = action_enabler_copy(enabler);
   current_enabler = enabler;
 
-  /* As precise a title as possible */
+  // As precise a title as possible
   my_name = QString(buf);
 }
 
@@ -497,8 +497,9 @@ struct req_vec_problem *fix_enabler_item::find_next_problem(void)
 **************************************************************************/
 void fix_enabler_item::apply_accepted_changes()
 {
-  /* The user has approved the solution */
+  // The user has approved the solution
   current_enabler->action = local_copy->action;
+
   requirement_vector_copy(&current_enabler->actor_reqs,
                           &local_copy->actor_reqs);
   requirement_vector_copy(&current_enabler->target_reqs,
@@ -512,8 +513,9 @@ void fix_enabler_item::apply_accepted_changes()
 **************************************************************************/
 void fix_enabler_item::undo_accepted_changes()
 {
-  /* The user has rejected all solutions */
+  // The user has rejected all solutions
   local_copy->action = current_enabler->action;
+
   requirement_vector_copy(&local_copy->actor_reqs,
                           &current_enabler->actor_reqs);
   requirement_vector_copy(&local_copy->target_reqs,
@@ -522,6 +524,7 @@ void fix_enabler_item::undo_accepted_changes()
 
 /********************************************************************//**
   Returns the number of requirement vectors in this item.
+
   @return the number of requirement vectors the item has.
 ************************************************************************/
 int fix_enabler_item::num_vectors()
@@ -533,6 +536,7 @@ int fix_enabler_item::num_vectors()
   Returns a function pointer to a function that names this item kind's
   requirement vector number number. Useful when there is more than one
   requirement vector.
+
   @return the requirement vector namer for ruleset items of this kind.
 ************************************************************************/
 requirement_vector_namer fix_enabler_item::vector_namer()
@@ -544,6 +548,7 @@ requirement_vector_namer fix_enabler_item::vector_namer()
   Returns a function pointer to a function that returns a writable
   pointer to the specified requirement vector in the specified parent
   item.
+
   @return a writable pointer to the requirement vector getter function.
 ************************************************************************/
 requirement_vector_by_number fix_enabler_item::vector_getter()
@@ -553,6 +558,7 @@ requirement_vector_by_number fix_enabler_item::vector_getter()
 
 /**********************************************************************//**
   Check if the specified vector belongs to this item
+
   @param vec the requirement vector that may belong to this item.
   @return true iff the vector belongs to this item.
 **************************************************************************/
