@@ -1,21 +1,21 @@
 #!/bin/sh
 
-# ./create-freeciv-gtk-qt-nsi.sh <Freeciv files directory> <version> <gui id> <gui name> <win32|win64|win> [mp gui] [exe id] [uninstall setup script]
+# ./create-freeciv-gtk-qt-nsi.sh <freeciv files dir> <output dir> <version> <gui id> <gui name> <win32|win64|win> [mp gui] [exe id] [uninstall setup script]
 
-if test "x$7" != "x" ; then
-  EXE_ID="$7"
+if test "$8" != "" ; then
+  EXE_ID="$8"
 else
-  EXE_ID="$3"
+  EXE_ID="$4"
 fi
 
-if test "x$6" != "x" ; then
-  MPEXE_ID="$6"
+if test "$7" != "" ; then
+  MPEXE_ID="$7"
 else
   MPEXE_ID="$EXE_ID"
 fi
 
-if test "x$8" != "x" && ! test -x "$8" ; then
-  echo "$8 not an executable script" >&2
+if test "$9" != "" && ! test -x "$9" ; then
+  echo "$9 not an executable script" >&2
   exit 1
 fi
 
@@ -30,12 +30,12 @@ Unicode true
 SetCompressor /SOLID lzma
 
 !define APPNAME "Freeciv"
-!define VERSION $2
-!define GUI_ID $3
+!define VERSION $3
+!define GUI_ID $4
 !define EXE_ID $EXE_ID
 !define MPEXE_ID $MPEXE_ID
-!define GUI_NAME $4
-!define WIN_ARCH $5
+!define GUI_NAME $5
+!define WIN_ARCH $6
 !define ARCH_KEY_PART ${ARCH_KEY_PART}
 !define ARCH_INST_PART ${ARCH_INST_PART}
 !define KEYROOT "Freeciv"
@@ -60,7 +60,7 @@ SetCompressor /SOLID lzma
 ; General
 
 Name "\${APPNAME} \${VERSION} (\${GUI_NAME} client)"
-OutFile "Output/\${APPNAME}-\${VERSION}-\${WIN_ARCH}-\${GUI_ID}-setup.exe"
+OutFile "$2/\${APPNAME}-\${VERSION}-\${WIN_ARCH}-\${GUI_ID}-setup.exe"
 
 ; Variables
 
@@ -78,7 +78,7 @@ Page custom DefaultLanguage DefaultLanguageLeave
 !insertmacro MUI_PAGE_DIRECTORY
 
 ; Start Menu Folder Page Configuration
-!define MUI_STARTMENUPAGE_REGISTRY_ROOT "SHCTX" 
+!define MUI_STARTMENUPAGE_REGISTRY_ROOT "SHCTX"
 !define MUI_STARTMENUPAGE_REGISTRY_KEY "Software\\\${KEYROOT}\\\${VERSION}\\\${ARCH_KEY_PART}\\\${APP_KEY_PART}"
 !define MUI_STARTMENUPAGE_REGISTRY_VALUENAME "Start Menu Folder"
 !define MUI_STARTMENUPAGE_DEFAULTFOLDER "\$(^Name)"
@@ -175,7 +175,7 @@ cat <<EOF
   CreateShortCut "\$SMPROGRAMS\\\$STARTMENU_FOLDER\Freeciv Modpack Installer.lnk" "\$INSTDIR\freeciv-mp-\${MPEXE_ID}.cmd" "\$DefaultLanguageCode" "\$INSTDIR\freeciv-mp-\${MPEXE_ID}.exe" 0 SW_SHOWMINIMIZED
 EOF
 
-if test "x$3" = "xqt6" ; then
+if test "$4" = "qt6" ; then
   echo "  CreateShortCut \"\$SMPROGRAMS\\\$STARTMENU_FOLDER\\Freeciv Ruleset Editor.lnk\" \"\$INSTDIR\\\\freeciv-ruledit.cmd\" \"\$DefaultLanguageCode\" \"\$INSTDIR\\\\freeciv-ruledit.exe\" 0 SW_SHOWMINIMIZED"
 fi
 
@@ -192,7 +192,7 @@ cat <<EOF
   WriteRegDWORD "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\\\${APPID}" "NoModify" 1
   WriteRegDWORD "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\\\${APPID}" "NoRepair" 1
   WriteUninstaller "uninstall.exe"
-  
+
   SetOutPath \$INSTDIR
 SectionEnd
 
@@ -351,7 +351,7 @@ EOF
 
 find $1 -type f |
 grep -v '/$' |
-sed 's|[^/]*||' |
+sed "s|$1||" |
 while read -r name
 do
 echo "  Delete \"\$INSTDIR$name\"" | sed 's,/,\\,g'
@@ -359,7 +359,7 @@ done
 
 find $1 -type l |
 grep -v '/$' |
-sed 's|[^/]*||' |
+sed "s|$1||" |
 while read -r name
 do
 echo "  Delete \"\$INSTDIR$name\"" | sed 's,/,\\,g'
@@ -367,14 +367,14 @@ done
 
 find $1 -depth -type d |
 grep -v '/$' |
-sed 's|[^/]*||' |
+sed "s|$1||" |
 while read -r name
 do
 echo "  RMDir \"\$INSTDIR$name\"" | sed 's,/,\\,g'
 done
 
-if test "x$8" != "x" ; then
-  $8
+if test "$9" != "" ; then
+  $9
 fi
 
 cat <<EOF
