@@ -43,7 +43,7 @@ add_gtk_common_env() {
   cp $1/bin/libgmodule-2.0-0.dll $2/ &&
   cp $1/bin/libpangowin32-1.0-0.dll $2/ &&
   cp $1/bin/libfontconfig-1.dll $2/ &&
-  cp $1/bin/libxml2-2.dll $2/ &&
+  cp $1/bin/libxml2-16.dll $2/ &&
   cp $1/bin/libjpeg-9.dll $2/ &&
   mkdir -p $2/bin &&
   cp $1/bin/gdk-pixbuf-query-loaders.exe $2/bin/
@@ -102,24 +102,26 @@ add_common_env() {
   cp $1/bin/libsqlite3-0.dll  $2/ &&
   cp $1/bin/libiconv-2.dll    $2/ &&
   cp $1/bin/libz.dll.1.3.1    $2/ &&
-  cp $1/lib/icuuc66.dll       $2/ &&
-  cp $1/lib/icudt66.dll       $2/ &&
+  cp $1/bin/icuuc71.dll       $2/ &&
+  cp $1/bin/icudt71.dll       $2/ &&
   cp $1/bin/libpng16-16.dll   $2/ &&
   cp $1/bin/libfreetype-6.dll $2/ &&
   cp $1/bin/libharfbuzz-0.dll $2/ &&
+  cp $1/bin/libharfbuzz-subset-0.dll $2/ &&
   cp $1/bin/libpsl-5.dll      $2/ &&
   cp $1/bin/libMagickWand-7.Q16HDRI-10.dll $2/ &&
   cp $1/bin/libMagickCore-7.Q16HDRI-10.dll $2/ &&
   add_glib_env $1 $2
 }
 
-if test "x$1" = x || test "x$1" = "x-h" || test "x$1" = "x--help" || test "x$2" = "x" ; then
+if test "$1" = x || test "$1" = "-h" || test "$1" = "--help" || test "$2" = "" ; then
   echo "Usage: $0 <crosser dir> <gui>"
   exit 1
 fi
 
 DLLSPATH="$1"
 GUI="$2"
+NAMEP="-client-${GUI}"
 
 case $GUI in
   gtk3.22)
@@ -138,13 +140,14 @@ case $GUI in
     GUINAME="GTK4"
     MPGUI="gtk4"
     FCMP="gtk4" ;;
-  ruledit) ;;
+  ruledit)
+    NAMEP="-ruledit" ;;
   *)
     echo "Unknown gui type \"$GUI\"" >&2
     exit 1 ;;
 esac
 
-if test "x$CLIENT" = "x" ; then
+if test "$CLIENT" = "" ; then
   CLIENT="$GUI"
 fi
 
@@ -161,18 +164,18 @@ SETUP=$(grep "CrosserSetup=" $DLLSPATH/crosser.txt | sed -e 's/CrosserSetup="//'
 
 VERREV="$(../../fc_version)"
 
-if test "x$INST_CROSS_MODE" != "xrelease" ; then
+if test "$INST_CROSS_MODE" != "release" ; then
   if test -d ../../.git || test -f ../../.git ; then
     VERREV="$VERREV-$(cd ../.. && git rev-parse --short HEAD)"
     GITREVERT=true
   fi
 fi
 
-INSTDIR="freeciv-$SETUP-${VERREV}-${GUI}"
+INSTDIR="autotools/install/freeciv-$SETUP-${VERREV}${NAMEP}"
 
 if test "$GUI" = "ruledit" ; then
-  if ! make -C build-${SETUP}-${GUI}/translations/ruledit update-po ||
-     ! make -C build-${SETUP}-${GUI}/bootstrap langstat_ruledit.txt
+  if ! make -C autotools/build/${SETUP}-${GUI}/translations/ruledit update-po ||
+     ! make -C autotools/build/${SETUP}-${GUI}/bootstrap langstat_ruledit.txt
   then
     echo "Langstat creation failed!" >&2
     exit 1
@@ -181,8 +184,8 @@ if test "$GUI" = "ruledit" ; then
     git checkout ../../translations/ruledit
   fi
 else
-  if ! make -C build-${SETUP}-${GUI}/translations/core update-po ||
-     ! make -C build-${SETUP}-${GUI}/bootstrap langstat_core.txt
+  if ! make -C autotools/build/${SETUP}-client-${GUI}/translations/core update-po ||
+     ! make -C autotools/build/${SETUP}-client-${GUI}/bootstrap langstat_core.txt
   then
     echo "Langstat creation failed!" >&2
     exit 1
@@ -209,7 +212,18 @@ if ! add_common_env $DLLSPATH $INSTDIR ; then
   exit 1
 fi
 
-if test "x$GUI" = "xruledit" ; then
+NSI_DIR="autotools/nsi"
+
+if ! mkdir -p "$NSI_DIR" ; then
+  echo "Cannot create \"$NSI_DIR\" directory" >&2
+  exit 1
+fi
+if ! mkdir -p autotools/output ; then
+  echo "Cannot create autotools/output directory" >&2
+  exit 1
+fi
+
+if test "$GUI" = "ruledit" ; then
   if ! cp freeciv-ruledit.cmd "${INSTDIR}/"
   then
     echo "Adding cmd-file failed!" >&2
@@ -222,17 +236,13 @@ if test "x$GUI" = "xruledit" ; then
   fi
 
   if ! ./create-freeciv-ruledit-nsi.sh \
-         "${INSTDIR}" "${VERREV}" "qt6" "Qt6" "${SETUP}" \
-           > "Freeciv-ruledit-${SETUP}-${VERREV}.nsi"
+         "${INSTDIR}" "autotools/output" "${VERREV}" "qt6" "Qt6" "${SETUP}" \
+           > "${NSI_DIR}/ruledit-${SETUP}-${VERREV}.nsi"
   then
     exit 1
   fi
 
-  if ! mkdir -p Output ; then
-    echo "Cannot create Output directory" >&2
-    exit 1
-  fi
-  if ! makensis Freeciv-ruledit-$SETUP-$VERREV.nsi
+  if ! makensis -NOCD "${NSI_DIR}/ruledit-${SETUP}-${VERREV}.nsi"
   then
     echo "Creating installer failed!" >&2
     exit 1
@@ -281,35 +291,35 @@ else
       fi ;;
   esac
 
-  if test "x$GUI" = "xsdl2" ; then
-    if ! ./create-freeciv-sdl2-nsi.sh $INSTDIR $VERREV $SETUP helpers/uninstaller-helper-gtk3.sh \
-           > Freeciv-$SETUP-$VERREV-$GUI.nsi
+  if test "$GUI" = "sdl2" ; then
+    if ! ./create-freeciv-sdl2-nsi.sh \
+           "$INSTDIR" "autotools/output" "$VERREV" "$SETUP" \
+           "helpers/uninstaller-helper-gtk3.sh" \
+             > "${NSI_DIR}/client-${SETUP}-${VERREV}-${GUI}.nsi"
     then
       exit 1
     fi
   else
-    if test "x$GUI" = "xqt6" ; then
+    if test "${GUI}" = "qt6" ; then
       EXE_ID="qt"
     else
-      EXE_ID="$GUI"
+      EXE_ID="${GUI}"
     fi
-    if test "x$GUI" = "xgtk3.22" || test "x$GUI" = "xgtk4" ; then
+    if test "$GUI" = "gtk3.22" || test "$GUI" = "gtk4" ; then
       UNINSTALLER="helpers/uninstaller-helper-gtk3.sh"
     else
       UNINSTALLER=""
     fi
-    if ! ./create-freeciv-gtk-qt-nsi.sh $INSTDIR $VERREV $GUI $GUINAME \
-         $SETUP $MPGUI $EXE_ID $UNINSTALLER > Freeciv-$SETUP-$VERREV-$GUI.nsi
+    if ! ./create-freeciv-gtk-qt-nsi.sh \
+           "$INSTDIR" "autotools/output" "$VERREV" "$GUI" "$GUINAME" \
+           "$SETUP" "$MPGUI" "$EXE_ID" "$UNINSTALLER" \
+             > "${NSI_DIR}/client-${SETUP}-${VERREV}-${GUI}.nsi"
     then
       exit 1
     fi
   fi
 
-  if ! mkdir -p Output ; then
-    echo "Cannot create Output directory" >&2
-    exit 1
-  fi
-  if ! makensis Freeciv-$SETUP-$VERREV-$GUI.nsi
+  if ! makensis -NOCD "${NSI_DIR}/client-${SETUP}-${VERREV}-${GUI}.nsi"
   then
     echo "Creating installer failed!" >&2
     exit 1
